/* eslint-disable @typescript-eslint/no-unused-vars */
/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { AbstractClient } from "../../../common/abstract_client"
import { ClientConfig } from "../../../common/interface"
import {
  DescribeImageStatRequest,
  TrendCount,
  Location,
  LabelDetailItem,
  ImageModerationResponse,
  ImageModerationRequest,
  DescribeImsListResponse,
  OcrResult,
  User,
  LabelResult,
  Device,
  ImsDetail,
  EvilCount,
  ObjectResult,
  OcrTextDetail,
  ObjectDetail,
  Filter,
  DescribeImageStatResponse,
  DescribeImsListRequest,
  LibResult,
  Overview,
  LibDetail,
  Filters,
} from "./ims_models"

/**
 * ims client
 * @class
 */
export class Client extends AbstractClient {
  constructor(clientConfig: ClientConfig) {
    super("ims.tencentcloudapi.com", "2020-07-13", clientConfig)
  }

  /**
     * 图片内容检测服务（Image Moderation, IM）能自动扫描图片，识别可能令人反感、不安全或不适宜的内容，同时支持用户配置图片黑名单，打击自定义识别类型的图片。

<div class="rno-api-explorer" style="margin-bottom:20px">
    <div class="rno-api-explorer-inner">
        <div class="rno-api-explorer-hd">
            <div class="rno-api-explorer-title">
                关于版本迭代的描述
            </div>
        </div>
        <div class="rno-api-explorer-body">
            <div class="rno-api-explorer-cont">
                <p>当前页面版本为图片内容安全2020版本，2020.11.3日前接入的图片内容安全接口为2019版本，在此时间前接入的用户可直接访问以下链接进行维护操作：<a href="https://cloud.tencent.com/document/product/1125/38206" target="_blank">图片内容安全-2019版本</a></p>
                <p>2020版本相对2019版本进行了升级，支持更灵活的多场景业务策略配置以及更丰富的识别回调信息，满足不同业务的识别需求，建议按照2020版本接入指引进行接口升级；同时，2019版本也会持续维护直至用户不再使用为止。</p>
            </div>
        </div>
    </div>
</div>
     */
  async ImageModeration(
    req: ImageModerationRequest,
    cb?: (error: string, rep: ImageModerationResponse) => void
  ): Promise<ImageModerationResponse> {
    return this.request("ImageModeration", req, cb)
  }

  /**
   * 图片机器审核明细
   */
  async DescribeImsList(
    req: DescribeImsListRequest,
    cb?: (error: string, rep: DescribeImsListResponse) => void
  ): Promise<DescribeImsListResponse> {
    return this.request("DescribeImsList", req, cb)
  }

  /**
   * 控制台识别统计
   */
  async DescribeImageStat(
    req: DescribeImageStatRequest,
    cb?: (error: string, rep: DescribeImageStatResponse) => void
  ): Promise<DescribeImageStatResponse> {
    return this.request("DescribeImageStat", req, cb)
  }
}
