/**
 * CreateNetworkAcl返回参数结构体
 */
export interface CreateNetworkAclResponse {
    /**
      * 网络ACL实例。
      */
    NetworkAcl: NetworkAcl;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 网络ACL
 */
export interface NetworkAcl {
    /**
      * `VPC`实例`ID`。
      */
    VpcId: string;
    /**
      * 网络ACL实例`ID`。
      */
    NetworkAclId: string;
    /**
      * 网络ACL名称，最大长度为60。
      */
    NetworkAclName: string;
    /**
      * 创建时间。
      */
    CreatedTime: string;
    /**
      * 网络ACL关联的子网数组。
      */
    SubnetSet: Array<Subnet>;
    /**
      * 网络ACl入站规则。
      */
    IngressEntries: Array<NetworkAclEntry>;
    /**
      * 网络ACL出站规则。
      */
    EgressEntries: Array<NetworkAclEntry>;
}
/**
 * ModifyAddressTemplateAttribute返回参数结构体
 */
export interface ModifyAddressTemplateAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateDhcpIpWithAddressIp请求参数结构体
 */
export interface DisassociateDhcpIpWithAddressIpRequest {
    /**
      * `DhcpIp`唯一`ID`，形如：`dhcpip-9o233uri`。必须是已绑定`EIP`的`DhcpIp`。
      */
    DhcpIpId: string;
}
/**
 * 用户安全组配额限制。
 */
export interface SecurityGroupLimitSet {
    /**
      * 每个项目每个地域可创建安全组数
      */
    SecurityGroupLimit: number;
    /**
      * 安全组下的最大规则数
      */
    SecurityGroupPolicyLimit: number;
    /**
      * 安全组下嵌套安全组规则数
      */
    ReferedSecurityGroupLimit: number;
    /**
      * 单安全组关联实例数
      */
    SecurityGroupInstanceLimit: number;
    /**
      * 实例关联安全组数
      */
    InstanceSecurityGroupLimit: number;
}
/**
 * LockCcns请求参数结构体
 */
export declare type LockCcnsRequest = null;
/**
 * CreateRoutes请求参数结构体
 */
export interface CreateRoutesRequest {
    /**
      * 路由表实例ID。
      */
    RouteTableId: string;
    /**
      * 路由策略对象。
      */
    Routes: Array<Route>;
}
/**
 * DescribeHaVips返回参数结构体
 */
export interface DescribeHaVipsResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount: number;
    /**
      * `HAVIP`对象数组。
      */
    HaVipSet: Array<HaVip>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 安全组关联的实例统计
 */
export interface SecurityGroupAssociationStatistics {
    /**
      * 安全组实例ID。
      */
    SecurityGroupId: string;
    /**
      * 云服务器实例数。
      */
    CVM: number;
    /**
      * MySQL数据库实例数。
      */
    CDB: number;
    /**
      * 弹性网卡实例数。
      */
    ENI: number;
    /**
      * 被安全组引用数。
      */
    SG: number;
    /**
      * 负载均衡实例数。
      */
    CLB: number;
    /**
      * 全量实例的绑定统计。
      */
    InstanceStatistics: Array<InstanceStatistic>;
    /**
      * 所有资源的总计数（不包含被安全组引用数）。
      */
    TotalCount: number;
}
/**
 * DeleteServiceTemplate返回参数结构体
 */
export interface DeleteServiceTemplateResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateServiceTemplate请求参数结构体
 */
export interface CreateServiceTemplateRequest {
    /**
      * 协议端口模板名称
      */
    ServiceTemplateName: string;
    /**
      * 支持单个端口、多个端口、连续端口及所有端口，协议支持：TCP、UDP、ICMP、GRE 协议。Services与ServicesExtra必填其一。
      */
    Services?: Array<string>;
    /**
      * 支持添加备注，单个端口、多个端口、连续端口及所有端口，协议支持：TCP、UDP、ICMP、GRE 协议。Services与ServicesExtra必填其一。
      */
    ServicesExtra?: Array<ServicesInfo>;
}
/**
 * DescribeIp6TranslatorQuota返回参数结构体
 */
export interface DescribeIp6TranslatorQuotaResponse {
    /**
      * 账户在指定地域的IPV6转换实例及规则配额信息
QUOTAID属性是TOTAL_TRANSLATOR_QUOTA，表示账户在指定地域的IPV6转换实例配额信息；QUOTAID属性是IPV6转换实例唯一ID（形如ip6-xxxxxxxx），表示账户在该转换实例允许创建的转换规则配额
      */
    QuotaSet?: Array<Quota>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateCcn返回参数结构体
 */
export interface CreateCcnResponse {
    /**
      * 云联网（CCN）对象。
      */
    Ccn: CCN;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpnConnections请求参数结构体
 */
export interface DescribeVpnConnectionsRequest {
    /**
      * VPN通道实例ID。形如：vpnx-f49l6u0z。每次请求的实例的上限为100。参数不支持同时指定VpnConnectionIds和Filters。
      */
    VpnConnectionIds?: Array<string>;
    /**
      * 过滤条件。每次请求的Filters的上限为10，Filter.Values的上限为5。参数不支持同时指定VpnConnectionIds和Filters。
<li>vpc-id - String - VPC实例ID，形如：`vpc-0a36uwkr`。</li>
<li>vpn-gateway-id - String - VPN网关实例ID，形如：`vpngw-p4lmqawn`。</li>
<li>customer-gateway-id - String - 对端网关实例ID，形如：`cgw-l4rblw63`。</li>
<li>vpn-connection-name - String - 通道名称，形如：`test-vpn`。</li>
<li>vpn-connection-id - String - 通道实例ID，形如：`vpnx-5p7vkch8"`。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于Offset的更进一步介绍请参考 API 简介中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * CreateAssistantCidr请求参数结构体
 */
export interface CreateAssistantCidrRequest {
    /**
      * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
      */
    VpcId: string;
    /**
      * CIDR数组，格式如["10.0.0.0/16", "172.16.0.0/16"]
      */
    CidrBlocks: Array<string>;
}
/**
 * DescribeNetworkInterfaces请求参数结构体
 */
export interface DescribeNetworkInterfacesRequest {
    /**
      * 弹性网卡实例ID查询。形如：eni-pxir56ns。每次请求的实例的上限为100。参数不支持同时指定NetworkInterfaceIds和Filters。
      */
    NetworkInterfaceIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定NetworkInterfaceIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-f49l6u0z。</li>
<li>subnet-id - String - （过滤条件）所属子网实例ID，形如：subnet-f49l6u0z。</li>
<li>network-interface-id - String - （过滤条件）弹性网卡实例ID，形如：eni-5k56k7k7。</li>
<li>attachment.instance-id - String - （过滤条件）绑定的云服务器实例ID，形如：ins-3nqpdn3i。</li>
<li>groups.security-group-id - String - （过滤条件）绑定的安全组实例ID，例如：sg-f9ekbxeq。</li>
<li>network-interface-name - String - （过滤条件）网卡实例名称。</li>
<li>network-interface-description - String - （过滤条件）网卡实例描述。</li>
<li>address-ip - String - （过滤条件）内网IPv4地址，单IP后缀模糊匹配，多IP精确匹配。可以与`ip-exact-match`配合做单IP的精确匹配查询。</li>
<li>ip-exact-match - Boolean - （过滤条件）内网IPv4精确匹配查询，存在多值情况，只取第一个。</li>
<li>tag-key - String -是否必填：否- （过滤条件）按照标签键进行过滤。使用请参考示例2</li>
<li>tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例3。</li>
<li>is-primary - Boolean - 是否必填：否 - （过滤条件）按照是否主网卡进行过滤。值为true时，仅过滤主网卡；值为false时，仅过滤辅助网卡；此过滤参数未提供时，同时过滤主网卡和辅助网卡。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * DescribeVpcLimits请求参数结构体
 */
export interface DescribeVpcLimitsRequest {
    /**
      * 配额名称。每次最大查询100个配额类型。
      */
    LimitTypes: Array<string>;
}
/**
 * ReleaseIp6AddressesBandwidth返回参数结构体
 */
export interface ReleaseIp6AddressesBandwidthResponse {
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId?: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcIpv6Addresses请求参数结构体
 */
export interface DescribeVpcIpv6AddressesRequest {
    /**
      * `VPC`实例`ID`，形如：`vpc-f49l6u0z`。
      */
    VpcId: string;
    /**
      * `IP`地址列表，批量查询单次请求最多支持`10`个。
      */
    Ipv6Addresses?: Array<string>;
    /**
      * 偏移量。
      */
    Offset?: number;
    /**
      * 返回数量。
      */
    Limit?: number;
}
/**
 * SSL-VPN-CLIENT 出参
 */
export interface SslVpnClient {
    /**
      * VPC实例ID
      */
    VpcId: string;
    /**
      * SSL-VPN-SERVER 实例ID
      */
    SslVpnServerId: string;
    /**
      * 证书状态.
0:创建中
1:正常
2:已停用
3.已过期
4.创建出错
      */
    CertStatus: number;
    /**
      * SSL-VPN-CLIENT 实例ID
      */
    SslVpnClientId: string;
    /**
      * 证书开始时间
      */
    CertBeginTime: string;
    /**
      * 证书到期时间
      */
    CertEndTime: string;
    /**
      * CLIENT NAME
      */
    Name: string;
    /**
      * 创建CLIENT 状态。
0 创建中
1 创建出错
2 更新中
3 更新出错
4 销毁中
5 销毁出粗
6 已连通
7 未知
      */
    State: string;
}
/**
 * NAT的SNAT规则
 */
export interface SourceIpTranslationNatRule {
    /**
      * 资源ID
      */
    ResourceId: string;
    /**
      * 资源类型，目前包含SUBNET、NETWORKINTERFACE
注意：此字段可能返回 null，表示取不到有效值。
      */
    ResourceType: string;
    /**
      * 源IP/网段
      */
    PrivateIpAddress: string;
    /**
      * 弹性IP地址池
      */
    PublicIpAddresses: Array<string>;
    /**
      * 描述
      */
    Description: string;
    /**
      * Snat规则ID
      */
    NatGatewaySnatId?: string;
    /**
      * NAT网关的ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NatGatewayId?: string;
    /**
      * 私有网络VPC的ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    VpcId?: string;
    /**
      * NAT网关SNAT规则创建时间。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CreatedTime?: string;
}
/**
 * DisableCcnRoutes请求参数结构体
 */
export interface DisableCcnRoutesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * CCN路由策略唯一ID。形如：ccnr-f49l6u0z。
      */
    RouteIds: Array<string>;
}
/**
 * ModifyNatGatewayDestinationIpPortTranslationNatRule返回参数结构体
 */
export interface ModifyNatGatewayDestinationIpPortTranslationNatRuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyIp6Rule返回参数结构体
 */
export interface ModifyIp6RuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyCcnRegionBandwidthLimitsType返回参数结构体
 */
export interface ModifyCcnRegionBandwidthLimitsTypeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpnGateways返回参数结构体
 */
export interface DescribeVpnGatewaysResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * VPN网关实例详细信息列表。
      */
    VpnGatewaySet?: Array<VpnGateway>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 协议端口模板集合
 */
export interface ServiceTemplateGroup {
    /**
      * 协议端口模板集合实例ID，例如：ppmg-2klmrefu。
      */
    ServiceTemplateGroupId: string;
    /**
      * 协议端口模板集合名称。
      */
    ServiceTemplateGroupName: string;
    /**
      * 协议端口模板实例ID。
      */
    ServiceTemplateIdSet: Array<string>;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * 协议端口模板实例信息。
      */
    ServiceTemplateSet: Array<ServiceTemplate>;
}
/**
 * CreateDhcpIp返回参数结构体
 */
export interface CreateDhcpIpResponse {
    /**
      * 新创建的`DhcpIp`信息
      */
    DhcpIpSet: Array<DhcpIp>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpnGatewaySslServer返回参数结构体
 */
export interface DeleteVpnGatewaySslServerResponse {
    /**
      * 异步任务ID。
      */
    TaskId: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeIpGeolocationInfos请求参数结构体
 */
export interface DescribeIpGeolocationInfosRequest {
    /**
      * 需查询的IP地址列表，目前仅支持IPv4地址。查询的IP地址数量上限为100个。
      */
    AddressIps: Array<string>;
    /**
      * 需查询的IP地址的字段信息。
      */
    Fields?: IpField;
}
/**
 * AddTemplateMember返回参数结构体
 */
export interface AddTemplateMemberResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateDefaultSecurityGroup请求参数结构体
 */
export interface CreateDefaultSecurityGroupRequest {
    /**
      * 项目ID，默认0。可在qcloud控制台项目管理页面查询到。
      */
    ProjectId?: string;
}
/**
 * DescribeServiceTemplateGroups返回参数结构体
 */
export interface DescribeServiceTemplateGroupsResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * 协议端口模板集合。
      */
    ServiceTemplateGroupSet?: Array<ServiceTemplateGroup>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcEndPoint请求参数结构体
 */
export interface DescribeVpcEndPointRequest {
    /**
      * 过滤条件。
<li> end-point-service-id- String - （过滤条件）终端节点服务ID。</li>
<li>end-point-name - String - （过滤条件）终端节点实例名称。</li>
<li> end-point-id- String - （过滤条件）终端节点实例ID。</li>
<li> vpc-id- String - （过滤条件）VPC实例ID。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 单页返回数量，默认为20，最大值为100。
      */
    Limit?: number;
    /**
      * 终端节点ID列表。
      */
    EndPointId?: Array<string>;
}
/**
 * DetachClassicLinkVpc请求参数结构体
 */
export interface DetachClassicLinkVpcRequest {
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * CVM实例ID查询。形如：ins-r8hr2upy。
      */
    InstanceIds: Array<string>;
}
/**
 * DescribeBandwidthPackageBillUsage返回参数结构体
 */
export interface DescribeBandwidthPackageBillUsageResponse {
    /**
      * 当前计费用量
      */
    BandwidthPackageBillBandwidthSet: Array<BandwidthPackageBillBandwidth>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteBandwidthPackage返回参数结构体
 */
export interface DeleteBandwidthPackageResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNatGatewayAttribute请求参数结构体
 */
export interface ModifyNatGatewayAttributeRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * NAT网关的名称，形如：`test_nat`。
      */
    NatGatewayName?: string;
    /**
      * NAT网关最大外网出带宽(单位:Mbps)。
      */
    InternetMaxBandwidthOut?: number;
    /**
      * 是否修改NAT网关绑定的安全组。
      */
    ModifySecurityGroup?: boolean;
    /**
      * NAT网关绑定的安全组列表，最终状态，空列表表示删除所有安全组，形如: `['sg-1n232323', 'sg-o4242424']`
      */
    SecurityGroupIds?: Array<string>;
}
/**
 * DescribeLocalGateway请求参数结构体
 */
export interface DescribeLocalGatewayRequest {
    /**
      * 查询条件：
vpc-id：按照VPCID过滤，local-gateway-name：按照本地网关名称过滤，名称支持模糊搜索，local-gateway-id：按照本地网关实例ID过滤，cdc-id：按照cdc实例ID过滤查询。
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于`Offset`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Limit?: number;
}
/**
 * 流日志
 */
export interface FlowLog {
    /**
      * 私用网络ID或者统一ID，建议使用统一ID。
      */
    VpcId?: string;
    /**
      * 流日志唯一ID。
      */
    FlowLogId?: string;
    /**
      * 流日志实例名字。
      */
    FlowLogName?: string;
    /**
      * 流日志所属资源类型，VPC|SUBNET|NETWORKINTERFACE|CCN|NAT|DCG。
      */
    ResourceType?: string;
    /**
      * 资源唯一ID。
      */
    ResourceId?: string;
    /**
      * 流日志采集类型，ACCEPT|REJECT|ALL。
      */
    TrafficType?: string;
    /**
      * 流日志存储ID。
      */
    CloudLogId?: string;
    /**
      * 流日志存储ID状态。
      */
    CloudLogState?: string;
    /**
      * 流日志描述信息。
      */
    FlowLogDescription?: string;
    /**
      * 流日志创建时间。
      */
    CreatedTime?: string;
    /**
      * 标签列表，例如：[{"Key": "city", "Value": "shanghai"}]。
      */
    TagSet: Array<Tag>;
    /**
      * 是否启用，true-启用，false-停用。
      */
    Enable: boolean;
    /**
      * 消费端类型：cls、ckafka。
注意：此字段可能返回 null，表示取不到有效值。
      */
    StorageType: string;
    /**
      * 消费端信息，当消费端类型为ckafka时返回
注意：此字段可能返回 null，表示取不到有效值。
      */
    FlowLogStorage: FlowLogStorage;
}
/**
 * DescribeVpcLimits返回参数结构体
 */
export interface DescribeVpcLimitsResponse {
    /**
      * 私有网络配额
      */
    VpcLimitSet?: Array<VpcLimit>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * IP在线查询的字段信息
 */
export interface IpField {
    /**
      * 国家字段信息
      */
    Country?: boolean;
    /**
      * 省、州、郡一级行政区域字段信息
      */
    Province?: boolean;
    /**
      * 市一级行政区域字段信息
      */
    City?: boolean;
    /**
      * 市内区域字段信息
      */
    Region?: boolean;
    /**
      * 接入运营商字段信息
      */
    Isp?: boolean;
    /**
      * 骨干运营商字段信息
      */
    AsName?: boolean;
    /**
      * 骨干As号
      */
    AsId?: boolean;
    /**
      * 注释字段
      */
    Comment?: boolean;
}
/**
 * AddBandwidthPackageResources请求参数结构体
 */
export interface AddBandwidthPackageResourcesRequest {
    /**
      * 资源唯一ID，当前支持EIP资源和LB资源，形如'eip-xxxx', 'lb-xxxx'
      */
    ResourceIds: Array<string>;
    /**
      * 带宽包唯一标识ID，形如'bwp-xxxx'
      */
    BandwidthPackageId?: string;
    /**
      * 带宽包类型，当前支持'BGP'类型，表示内部资源是BGP IP。
      */
    NetworkType?: string;
    /**
      * 资源类型，包括'Address', 'LoadBalance'
      */
    ResourceType?: string;
    /**
      * 带宽包协议类型。当前支持'ipv4'和'ipv6'协议类型。
      */
    Protocol?: string;
}
/**
 * AssignIpv6SubnetCidrBlock请求参数结构体
 */
export interface AssignIpv6SubnetCidrBlockRequest {
    /**
      * 子网所在私有网络`ID`。形如：`vpc-f49l6u0z`。
      */
    VpcId: string;
    /**
      * 分配 `IPv6` 子网段列表。
      */
    Ipv6SubnetCidrBlocks: Array<Ipv6SubnetCidrBlock>;
}
/**
 * DeleteVpnGatewaySslClient返回参数结构体
 */
export interface DeleteVpnGatewaySslClientResponse {
    /**
      * 异步任务ID。
      */
    TaskId: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpc返回参数结构体
 */
export interface CreateVpcResponse {
    /**
      * Vpc对象。
      */
    Vpc?: Vpc;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * VPC辅助CIDR信息。
 */
export interface AssistantCidr {
    /**
      * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
      */
    VpcId: string;
    /**
      * 辅助CIDR。形如：`172.16.0.0/16`
      */
    CidrBlock: string;
    /**
      * 辅助CIDR类型（0：普通辅助CIDR，1：容器辅助CIDR），默认都是0。
      */
    AssistantType: number;
    /**
      * 辅助CIDR拆分的子网。
注意：此字段可能返回 null，表示取不到有效值。
      */
    SubnetSet: Array<Subnet>;
}
/**
 * ModifyNetworkAclEntries请求参数结构体
 */
export interface ModifyNetworkAclEntriesRequest {
    /**
      * 网络ACL实例ID。例如：acl-12345678。
      */
    NetworkAclId: string;
    /**
      * 网络ACL规则集。
      */
    NetworkAclEntrySet: NetworkAclEntrySet;
}
/**
 * DescribeVpcPrivateIpAddresses请求参数结构体
 */
export interface DescribeVpcPrivateIpAddressesRequest {
    /**
      * `VPC`实例`ID`，形如：`vpc-f49l6u0z`。
      */
    VpcId: string;
    /**
      * 内网`IP`地址列表，批量查询单次请求最多支持`10`个。
      */
    PrivateIpAddresses: Array<string>;
}
/**
 * IP地址模板
 */
export interface AddressTemplate {
    /**
      * IP地址模板名称。
      */
    AddressTemplateName: string;
    /**
      * IP地址模板实例唯一ID。
      */
    AddressTemplateId: string;
    /**
      * IP地址信息。
      */
    AddressSet: Array<string>;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * 带备注的IP地址信息。
      */
    AddressExtraSet: Array<AddressInfo>;
}
/**
 * IKE配置（Internet Key Exchange，因特网密钥交换），IKE具有一套自我保护机制，用户配置网络安全协议
 */
export interface IKEOptionsSpecification {
    /**
      * 加密算法，可选值：'3DES-CBC', 'AES-CBC-128', 'AES-CBS-192', 'AES-CBC-256', 'DES-CBC'，'SM4', 默认为3DES-CBC
      */
    PropoEncryAlgorithm?: string;
    /**
      * 认证算法：可选值：'MD5', 'SHA1'，'SHA-256' 默认为MD5
      */
    PropoAuthenAlgorithm?: string;
    /**
      * 协商模式：可选值：'AGGRESSIVE', 'MAIN'，默认为MAIN
      */
    ExchangeMode?: string;
    /**
      * 本端标识类型：可选值：'ADDRESS', 'FQDN'，默认为ADDRESS
      */
    LocalIdentity?: string;
    /**
      * 对端标识类型：可选值：'ADDRESS', 'FQDN'，默认为ADDRESS
      */
    RemoteIdentity?: string;
    /**
      * 本端标识，当LocalIdentity选为ADDRESS时，LocalAddress必填。localAddress默认为vpn网关公网IP
      */
    LocalAddress?: string;
    /**
      * 对端标识，当RemoteIdentity选为ADDRESS时，RemoteAddress必填
      */
    RemoteAddress?: string;
    /**
      * 本端标识，当LocalIdentity选为FQDN时，LocalFqdnName必填
      */
    LocalFqdnName?: string;
    /**
      * 对端标识，当remoteIdentity选为FQDN时，RemoteFqdnName必填
      */
    RemoteFqdnName?: string;
    /**
      * DH group，指定IKE交换密钥时使用的DH组，可选值：'GROUP1', 'GROUP2', 'GROUP5', 'GROUP14', 'GROUP24'，
      */
    DhGroupName?: string;
    /**
      * IKE SA Lifetime，单位：秒，设置IKE SA的生存周期，取值范围：60-604800
      */
    IKESaLifetimeSeconds?: number;
    /**
      * IKE版本
      */
    IKEVersion?: string;
}
/**
 * VPN网关配额对象
 */
export interface VpnGatewayQuota {
    /**
      * 带宽配额
      */
    Bandwidth: number;
    /**
      * 配额中文名称
      */
    Cname: string;
    /**
      * 配额英文名称
      */
    Name: string;
}
/**
 * DescribeBandwidthPackageBillUsage请求参数结构体
 */
export interface DescribeBandwidthPackageBillUsageRequest {
    /**
      * 后付费共享带宽包的唯一ID
      */
    BandwidthPackageId: string;
}
/**
 * UnassignIpv6Addresses返回参数结构体
 */
export interface UnassignIpv6AddressesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateIp6Translators返回参数结构体
 */
export interface CreateIp6TranslatorsResponse {
    /**
      * 转换实例的唯一ID数组，形如"ip6-xxxxxxxx"
      */
    Ip6TranslatorSet: Array<string>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeFlowLogs请求参数结构体
 */
export interface DescribeFlowLogsRequest {
    /**
      * 私用网络ID或者统一ID，建议使用统一ID
      */
    VpcId?: string;
    /**
      * 流日志唯一ID
      */
    FlowLogId?: string;
    /**
      * 流日志实例名字
      */
    FlowLogName?: string;
    /**
      * 流日志所属资源类型，VPC|SUBNET|NETWORKINTERFACE
      */
    ResourceType?: string;
    /**
      * 资源唯一ID
      */
    ResourceId?: string;
    /**
      * 流日志采集类型，ACCEPT|REJECT|ALL
      */
    TrafficType?: string;
    /**
      * 流日志存储ID
      */
    CloudLogId?: string;
    /**
      * 流日志存储ID状态
      */
    CloudLogState?: string;
    /**
      * 按某个字段排序,支持字段：flowLogName,createTime，默认按createTime
      */
    OrderField?: string;
    /**
      * 升序（asc）还是降序（desc）,默认：desc
      */
    OrderDirection?: string;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 每页行数，默认为10
      */
    Limit?: number;
    /**
      * 过滤条件，参数不支持同时指定FlowLogIds和Filters。
<li>tag-key - String -是否必填：否- （过滤条件）按照标签键进行过滤。</li>
<li>tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。</li>
      */
    Filters?: Filter;
}
/**
 * DeleteTemplateMember请求参数结构体
 */
export interface DeleteTemplateMemberRequest {
    /**
      * 参数模板实例ID，支持IP地址、协议端口、IP地址组、协议端口组四种参数模板的实例ID。
      */
    TemplateId: string;
    /**
      * 需要添加的参数模板成员信息，支持IP地址、协议端口、IP地址组、协议端口组四种类型，类型需要与TemplateId参数类型一致。
      */
    TemplateMember: Array<MemberInfo>;
}
/**
 * CloneSecurityGroup请求参数结构体
 */
export interface CloneSecurityGroupRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 安全组名称，可任意命名，但不得超过60个字符。未提供参数时，克隆后的安全组名称和SecurityGroupId对应的安全组名称相同。
      */
    GroupName?: string;
    /**
      * 安全组备注，最多100个字符。未提供参数时，克隆后的安全组备注和SecurityGroupId对应的安全组备注相同。
      */
    GroupDescription?: string;
    /**
      * 项目ID，默认0。可在qcloud控制台项目管理页面查询到。
      */
    ProjectId?: string;
    /**
      * 源Region,跨地域克隆安全组时，需要传入源安全组所属地域信息，例如：克隆广州的安全组到上海，则这里需要传入广州安全的地域信息：ap-guangzhou。
      */
    RemoteRegion?: string;
}
/**
 * AssociateNatGatewayAddress请求参数结构体
 */
export interface AssociateNatGatewayAddressRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * 需要申请的弹性IP个数，系统会按您的要求生产N个弹性IP, 其中AddressCount和PublicAddresses至少传递一个。
      */
    AddressCount?: number;
    /**
      * 绑定NAT网关的弹性IP数组，其中AddressCount和PublicAddresses至少传递一个。
      */
    PublicIpAddresses?: Array<string>;
    /**
      * 弹性IP可用区，自动分配弹性IP时传递。
      */
    Zone?: string;
    /**
      * 绑定NAT网关的弹性IP带宽大小（单位Mbps），默认为当前用户类型所能使用的最大值。
      */
    StockPublicIpAddressesBandwidthOut?: number;
    /**
      * 需要申请公网IP带宽大小（单位Mbps），默认为当前用户类型所能使用的最大值。
      */
    PublicIpAddressesBandwidthOut?: number;
    /**
      * 公网IP是否强制与NAT网关来自同可用区，true表示需要与NAT网关同可用区；false表示可与NAT网关不是同一个可用区。此参数只有当参数Zone存在时才能生效。
      */
    PublicIpFromSameZone?: boolean;
}
/**
 * CreateDirectConnectGateway请求参数结构体
 */
export interface CreateDirectConnectGatewayRequest {
    /**
      * 专线网关名称
      */
    DirectConnectGatewayName: string;
    /**
      * 关联网络类型，可选值：
<li>VPC - 私有网络</li>
<li>CCN - 云联网</li>
      */
    NetworkType: string;
    /**
      * <li>NetworkType 为 VPC 时，这里传值为私有网络实例ID</li>
<li>NetworkType 为 CCN 时，这里传值为云联网实例ID</li>
      */
    NetworkInstanceId: string;
    /**
      * 网关类型，可选值：
<li>NORMAL - （默认）标准型，注：云联网只支持标准型</li>
<li>NAT - NAT型</li>NAT类型支持网络地址转换配置，类型确定后不能修改；一个私有网络可以创建一个NAT类型的专线网关和一个非NAT类型的专线网关
      */
    GatewayType?: string;
    /**
      * 云联网路由发布模式，可选值：`standard`（标准模式）、`exquisite`（精细模式）。只有云联网类型专线网关才支持`ModeType`。
      */
    ModeType?: string;
    /**
      * 专线网关可用区
      */
    Zone?: string;
    /**
      * 专线网关高可用区容灾组ID
      */
    HaZoneGroupId?: string;
}
/**
 * CreateVpnGatewaySslServer请求参数结构体
 */
export interface CreateVpnGatewaySslServerRequest {
    /**
      * VPN实例ID
      */
    VpnGatewayId: string;
    /**
      * SSL_VPN_SERVER 实例名
      */
    SslVpnServerName: string;
    /**
      * 本端地址网段
      */
    LocalAddress: Array<string>;
    /**
      * 客户端地址网段
      */
    RemoteAddress: string;
    /**
      * SSL VPN服务端监听协议。当前仅支持 UDP。默认UDP
      */
    SslVpnProtocol?: string;
    /**
      * SSL VPN服务端监听协议端口。默认1194。
      */
    SslVpnPort?: number;
    /**
      * 认证算法。可选 'SHA1', 'MD5', 'NONE'。默认NONE
      */
    IntegrityAlgorithm?: string;
    /**
      * 加密算法。可选 'AES-128-CBC', 'AES-192-CBC', 'AES-256-CBC', 'NONE'。默认NONE
      */
    EncryptAlgorithm?: string;
    /**
      * 是否支持压缩。当前仅支持不支持压缩。默认False
      */
    Compress?: boolean;
}
/**
 * CreateVpcEndPoint请求参数结构体
 */
export interface CreateVpcEndPointRequest {
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 子网实例ID。
      */
    SubnetId: string;
    /**
      * 终端节点名称。
      */
    EndPointName: string;
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
    /**
      * 终端节点VIP，可以指定IP申请。
      */
    EndPointVip?: string;
    /**
      * 安全组ID。
      */
    SecurityGroupId?: string;
}
/**
 * ModifyBandwidthPackageAttribute请求参数结构体
 */
export interface ModifyBandwidthPackageAttributeRequest {
    /**
      * 带宽包唯一标识ID
      */
    BandwidthPackageId: string;
    /**
      * 带宽包名称
      */
    BandwidthPackageName: string;
    /**
      * 带宽包计费模式
      */
    ChargeType?: string;
    /**
      * 退款时迁移为后付费带宽包。默认值：否
      */
    MigrateOnRefund?: boolean;
}
/**
 * TransformAddress返回参数结构体
 */
export interface TransformAddressResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateNetworkInterfaceSecurityGroups请求参数结构体
 */
export interface DisassociateNetworkInterfaceSecurityGroupsRequest {
    /**
      * 弹性网卡实例ID。形如：eni-pxir56ns。每次请求的实例的上限为100。
      */
    NetworkInterfaceIds: Array<string>;
    /**
      * 安全组实例ID，例如：sg-33ocnj9n，可通过DescribeSecurityGroups获取。每次请求的实例的上限为100。
      */
    SecurityGroupIds: Array<string>;
}
/**
 * 安全组规则集合
 */
export interface SecurityGroupPolicySet {
    /**
      * 安全组规则当前版本。用户每次更新安全规则版本会自动加1，防止更新的路由规则已过期，不填不考虑冲突。
      */
    Version?: string;
    /**
      * 出站规则。
      */
    Egress?: Array<SecurityGroupPolicy>;
    /**
      * 入站规则。
      */
    Ingress?: Array<SecurityGroupPolicy>;
}
/**
 * ModifyFlowLogAttribute请求参数结构体
 */
export interface ModifyFlowLogAttributeRequest {
    /**
      * 流日志唯一ID
      */
    FlowLogId: string;
    /**
      * 私用网络ID或者统一ID，建议使用统一ID，修改云联网流日志属性时可不填，其他流日志类型必填。
      */
    VpcId?: string;
    /**
      * 流日志实例名字
      */
    FlowLogName?: string;
    /**
      * 流日志实例描述
      */
    FlowLogDescription?: string;
}
/**
 * UnassignIpv6SubnetCidrBlock返回参数结构体
 */
export interface UnassignIpv6SubnetCidrBlockResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpcEndPointServiceAttribute请求参数结构体
 */
export interface ModifyVpcEndPointServiceAttributeRequest {
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
    /**
      * VPCID。
      */
    VpcId: string;
    /**
      * 终端节点服务名称。
      */
    EndPointServiceName?: string;
    /**
      * 是否自动接受终端节点的连接请求。<ui><li>true：自动接受<li>false：不自动接受</ul>
      */
    AutoAcceptFlag?: boolean;
    /**
      * 后端服务的ID，比如lb-xxx。
      */
    ServiceInstanceId?: string;
}
/**
 * 过滤器键值对
 */
export interface FilterObject {
    /**
      * 属性名称, 若存在多个Filter时，Filter间的关系为逻辑与（AND）关系。
      */
    Name: string;
    /**
      * 属性值, 若同一个Filter存在多个Values，同一Filter下Values间的关系为逻辑或（OR）关系。
      */
    Values: Array<string>;
}
/**
 * DescribeIpGeolocationInfos返回参数结构体
 */
export interface DescribeIpGeolocationInfosResponse {
    /**
      * IP地址信息列表。
      */
    AddressInfo: Array<IpGeolocationInfo>;
    /**
      * IP地址信息个数。
      */
    Total: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcTaskResult请求参数结构体
 */
export interface DescribeVpcTaskResultRequest {
    /**
      * 异步任务请求返回的RequestId。
      */
    TaskId: string;
}
/**
 * AssociateNetworkAclSubnets返回参数结构体
 */
export interface AssociateNetworkAclSubnetsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNatGatewayDestinationIpPortTranslationNatRule请求参数结构体
 */
export interface DeleteNatGatewayDestinationIpPortTranslationNatRuleRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * NAT网关的端口转换规则。
      */
    DestinationIpPortTranslationNatRules: Array<DestinationIpPortTranslationNatRule>;
}
/**
 * ResetRoutes请求参数结构体
 */
export interface ResetRoutesRequest {
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
    /**
      * 路由表名称，最大长度不能超过60个字节。
      */
    RouteTableName: string;
    /**
      * 路由策略。
      */
    Routes: Array<Route>;
}
/**
 * CheckDefaultSubnet请求参数结构体
 */
export interface CheckDefaultSubnetRequest {
    /**
      * 子网所在的可用区ID，不同子网选择不同可用区可以做跨可用区灾备。
      */
    Zone?: string;
}
/**
 * CheckNetDetectState请求参数结构体
 */
export interface CheckNetDetectStateRequest {
    /**
      * 探测目的IPv4地址数组，最多两个。
      */
    DetectDestinationIp: Array<string>;
    /**
      * 下一跳类型，目前我们支持的类型有：
VPN：VPN网关；
DIRECTCONNECT：专线网关；
PEERCONNECTION：对等连接；
NAT：NAT网关；
NORMAL_CVM：普通云服务器；
      */
    NextHopType: string;
    /**
      * 下一跳目的网关，取值与“下一跳类型”相关：
下一跳类型为VPN，取值VPN网关ID，形如：vpngw-12345678；
下一跳类型为DIRECTCONNECT，取值专线网关ID，形如：dcg-12345678；
下一跳类型为PEERCONNECTION，取值对等连接ID，形如：pcx-12345678；
下一跳类型为NAT，取值Nat网关，形如：nat-12345678；
下一跳类型为NORMAL_CVM，取值云服务器IPv4地址，形如：10.0.0.12；
      */
    NextHopDestination: string;
    /**
      * 网络探测实例ID。形如：netd-12345678。该参数与（VpcId，SubnetId，NetDetectName），至少要有一个。当NetDetectId存在时，使用NetDetectId。
      */
    NetDetectId?: string;
    /**
      * `VPC`实例`ID`。形如：`vpc-12345678`。该参数与（SubnetId，NetDetectName）配合使用，与NetDetectId至少要有一个。当NetDetectId存在时，使用NetDetectId。
      */
    VpcId?: string;
    /**
      * 子网实例ID。形如：subnet-12345678。该参数与（VpcId，NetDetectName）配合使用，与NetDetectId至少要有一个。当NetDetectId存在时，使用NetDetectId。
      */
    SubnetId?: string;
    /**
      * 网络探测名称，最大长度不能超过60个字节。该参数与（VpcId，SubnetId）配合使用，与NetDetectId至少要有一个。当NetDetectId存在时，使用NetDetectId。
      */
    NetDetectName?: string;
}
/**
 * 路由表关联关系
 */
export interface RouteTableAssociation {
    /**
      * 子网实例ID。
      */
    SubnetId: string;
    /**
      * 路由表实例ID。
      */
    RouteTableId: string;
}
/**
 * ModifyCustomerGatewayAttribute请求参数结构体
 */
export interface ModifyCustomerGatewayAttributeRequest {
    /**
      * 对端网关ID，例如：cgw-2wqq41m9，可通过DescribeCustomerGateways接口查询对端网关。
      */
    CustomerGatewayId: string;
    /**
      * 对端网关名称，可任意命名，但不得超过60个字符。
      */
    CustomerGatewayName: string;
}
/**
 * DescribeRouteTables返回参数结构体
 */
export interface DescribeRouteTablesResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 路由表对象。
      */
    RouteTableSet: Array<RouteTable>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpcEndPointServiceWhiteList请求参数结构体
 */
export interface DeleteVpcEndPointServiceWhiteListRequest {
    /**
      * 用户UIN数组。
      */
    UserUin: Array<string>;
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
}
/**
 * DetachNetworkInterface返回参数结构体
 */
export interface DetachNetworkInterfaceResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpcEndPointService请求参数结构体
 */
export interface DeleteVpcEndPointServiceRequest {
    /**
      * 终端节点ID。
      */
    EndPointServiceId: string;
}
/**
 * DeleteCcn返回参数结构体
 */
export interface DeleteCcnResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 协议端口模板
 */
export interface ServiceTemplate {
    /**
      * 协议端口实例ID，例如：ppm-f5n1f8da。
      */
    ServiceTemplateId: string;
    /**
      * 模板名称。
      */
    ServiceTemplateName: string;
    /**
      * 协议端口信息。
      */
    ServiceSet: Array<string>;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * 带备注的协议端口信息。
      */
    ServiceExtraSet: Array<ServicesInfo>;
}
/**
 * DescribeCcnAttachedInstances请求参数结构体
 */
export interface DescribeCcnAttachedInstancesRequest {
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
    /**
      * 过滤条件：
<li>ccn-id - String -（过滤条件）CCN实例ID。</li>
<li>instance-type - String -（过滤条件）关联实例类型。</li>
<li>instance-region - String -（过滤条件）关联实例所属地域。</li>
<li>instance-id - String -（过滤条件）关联实例实例ID。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 云联网实例ID
      */
    CcnId?: string;
    /**
      * 排序字段。支持：`CcnId` `InstanceType` `InstanceId` `InstanceName` `InstanceRegion` `AttachedTime` `State`。
      */
    OrderField?: string;
    /**
      * 排序方法。顺序：`ASC`，倒序：`DESC`。
      */
    OrderDirection?: string;
}
/**
 * DescribeNatGatewaySourceIpTranslationNatRules请求参数结构体
 */
export interface DescribeNatGatewaySourceIpTranslationNatRulesRequest {
    /**
      * NAT网关统一 ID，形如：`nat-123xx454`。
      */
    NatGatewayId: string;
    /**
      * 过滤条件:
<li> resource-id，Subnet的ID或者Cvm ID，如`subnet-0yi4hekt`</li>
<li> public-ip-address，弹性IP，如`139.199.232.238`</li>
<li>description，规则描述。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * DescribeNatGateways请求参数结构体
 */
export interface DescribeNatGatewaysRequest {
    /**
      * NAT网关统一 ID，形如：`nat-123xx454`。
      */
    NatGatewayIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定NatGatewayIds和Filters。
<li>nat-gateway-id - String - （过滤条件）协议端口模板实例ID，形如：`nat-123xx454`。</li>
<li>vpc-id - String - （过滤条件）私有网络 唯一ID，形如：`vpc-123xx454`。</li>
<li>nat-gateway-name - String - （过滤条件）协议端口模板实例ID，形如：`test_nat`。</li>
<li>tag-key - String - （过滤条件）标签键，形如：`test-key`。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * ModifyFlowLogAttribute返回参数结构体
 */
export interface ModifyFlowLogAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeBandwidthPackages返回参数结构体
 */
export interface DescribeBandwidthPackagesResponse {
    /**
      * 符合条件的带宽包数量
      */
    TotalCount: number;
    /**
      * 描述带宽包详细信息
      */
    BandwidthPackageSet: Array<BandwidthPackage>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeDirectConnectGateways请求参数结构体
 */
export interface DescribeDirectConnectGatewaysRequest {
    /**
      * 专线网关唯一`ID`，形如：`dcg-9o233uri`。
      */
    DirectConnectGatewayIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定`DirectConnectGatewayIds`和`Filters`。
<li>direct-connect-gateway-id - String - 专线网关唯一`ID`，形如：`dcg-9o233uri`。</li>
<li>direct-connect-gateway-name - String - 专线网关名称，默认模糊查询。</li>
<li>direct-connect-gateway-ip - String - 专线网关`IP`。</li>
<li>gateway-type - String - 网关类型，可选值：`NORMAL`（普通型）、`NAT`（NAT型）。</li>
<li>network-type- String - 网络类型，可选值：`VPC`（私有网络类型）、`CCN`（云联网类型）。</li>
<li>ccn-id - String - 专线网关所在云联网`ID`。</li>
<li>vpc-id - String - 专线网关所在私有网络`ID`。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量。
      */
    Offset?: number;
    /**
      * 返回数量。
      */
    Limit?: number;
}
/**
 * DisableVpnGatewaySslClientCert请求参数结构体
 */
export interface DisableVpnGatewaySslClientCertRequest {
    /**
      * SSL-VPN-CLIENT 实例ID。
      */
    SslVpnClientId: string;
}
/**
 * DescribeVpcPrivateIpAddresses返回参数结构体
 */
export interface DescribeVpcPrivateIpAddressesResponse {
    /**
      * 内网`IP`地址信息列表。
      */
    VpcPrivateIpAddressSet: Array<VpcPrivateIpAddress>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyIp6Translator返回参数结构体
 */
export interface ModifyIp6TranslatorResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpcEndPointServiceWhiteList返回参数结构体
 */
export interface CreateVpcEndPointServiceWhiteListResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeIpGeolocationDatabaseUrl返回参数结构体
 */
export interface DescribeIpGeolocationDatabaseUrlResponse {
    /**
      * IP地理位置库下载链接地址。
      */
    DownLoadUrl: string;
    /**
      * 链接到期时间。按照`ISO8601`标准表示，并且使用`UTC`时间。
      */
    ExpiredAt: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * UnlockCcnBandwidths请求参数结构体
 */
export declare type UnlockCcnBandwidthsRequest = null;
/**
 * DeleteIp6Translators返回参数结构体
 */
export interface DeleteIp6TranslatorsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNatGatewaySourceIpTranslationNatRules返回参数结构体
 */
export interface DescribeNatGatewaySourceIpTranslationNatRulesResponse {
    /**
      * NAT网关SNAT规则对象数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    SourceIpTranslationNatRuleSet: Array<SourceIpTranslationNatRule>;
    /**
      * 符合条件的NAT网关端口转发规则对象数目。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcs请求参数结构体
 */
export interface DescribeVpcsRequest {
    /**
      * VPC实例ID。形如：vpc-f49l6u0z。每次请求的实例的上限为100。参数不支持同时指定VpcIds和Filters。
      */
    VpcIds?: Array<string>;
    /**
      * 过滤条件，不支持同时指定VpcIds和Filters参数。
支持的过滤条件如下：
<li>vpc-name：VPC实例名称。</li>
<li>is-default ：是否默认VPC。</li>
<li>vpc-id ：VPC实例ID，例如：vpc-f49l6u0z。</li>
<li>cidr-block：VPC的CIDR。</li>
<li>tag-key ：按照标签键进行过滤，非必填参数。</li>
<li>tag:tag-key：按照标签键值对进行过滤，非必填参数。 其中 tag-key 请使用具体的标签键进行替换，可参考示例2。</li>
  **说明：**若同一个过滤条件（Filter）存在多个Values，则同一Filter下Values间的关系为逻辑或（OR）关系；若存在多个过滤条件（Filter），Filter之间的关系为逻辑与（AND）关系。
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * DescribeRouteConflicts返回参数结构体
 */
export interface DescribeRouteConflictsResponse {
    /**
      * 路由策略冲突列表
      */
    RouteConflictSet?: Array<RouteConflict>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AcceptAttachCcnInstances请求参数结构体
 */
export interface AcceptAttachCcnInstancesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 接受关联实例列表。
      */
    Instances: Array<CcnInstance>;
}
/**
 * DescribeGatewayFlowMonitorDetail返回参数结构体
 */
export interface DescribeGatewayFlowMonitorDetailResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount?: number;
    /**
      * 网关流量监控明细。
      */
    GatewayFlowMonitorDetailSet?: Array<GatewayFlowMonitorDetail>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * IP地理位置信息
 */
export interface IpGeolocationInfo {
    /**
      * 国家信息
注意：此字段可能返回 null，表示取不到有效值。
      */
    Country?: string;
    /**
      * 省、州、郡一级行政区域信息
注意：此字段可能返回 null，表示取不到有效值。
      */
    Province?: string;
    /**
      * 市一级行政区域信息
注意：此字段可能返回 null，表示取不到有效值。
      */
    City?: string;
    /**
      * 市内区域信息
注意：此字段可能返回 null，表示取不到有效值。
      */
    Region?: string;
    /**
      * 接入运营商信息
注意：此字段可能返回 null，表示取不到有效值。
      */
    Isp?: string;
    /**
      * 骨干运营商名称
注意：此字段可能返回 null，表示取不到有效值。
      */
    AsName?: string;
    /**
      * 骨干运营商AS号
注意：此字段可能返回 null，表示取不到有效值。
      */
    AsId?: string;
    /**
      * 注释信息。目前的填充值为移动接入用户的APN值，如无APN属性则为空
注意：此字段可能返回 null，表示取不到有效值。
      */
    Comment?: string;
    /**
      * IP地址
注意：此字段可能返回 null，表示取不到有效值。
      */
    AddressIp: string;
}
/**
 * DeleteFlowLog请求参数结构体
 */
export interface DeleteFlowLogRequest {
    /**
      * 流日志唯一ID
      */
    FlowLogId: string;
    /**
      * 私用网络ID或者统一ID，建议使用统一ID，删除云联网流日志时，可不填，其他流日志类型必填。
      */
    VpcId?: string;
}
/**
 * 网络探测验证结果。
 */
export interface NetDetectState {
    /**
      * 网络探测实例ID。形如：netd-12345678。
      */
    NetDetectId: string;
    /**
      * 网络探测目的IP验证结果对象数组。
      */
    NetDetectIpStateSet: Array<NetDetectIpState>;
}
/**
 * HaVipDisassociateAddressIp返回参数结构体
 */
export interface HaVipDisassociateAddressIpResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateVpcEndPointSecurityGroups请求参数结构体
 */
export interface DisassociateVpcEndPointSecurityGroupsRequest {
    /**
      * 安全组ID数组。
      */
    SecurityGroupIds: Array<string>;
    /**
      * 终端节点ID。
      */
    EndPointId: string;
}
/**
 * DescribeTaskResult请求参数结构体
 */
export interface DescribeTaskResultRequest {
    /**
      * 异步任务ID。TaskId和DealName必填一个参数
      */
    TaskId?: number;
    /**
      * 计费订单号。TaskId和DealName必填一个参数
      */
    DealName?: string;
}
/**
 * ModifyAddressInternetChargeType返回参数结构体
 */
export interface ModifyAddressInternetChargeTypeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * UnassignIpv6SubnetCidrBlock请求参数结构体
 */
export interface UnassignIpv6SubnetCidrBlockRequest {
    /**
      * 子网所在私有网络`ID`。形如：`vpc-f49l6u0z`。
      */
    VpcId: string;
    /**
      * `IPv6` 子网段列表。
      */
    Ipv6SubnetCidrBlocks: Array<Ipv6SubnetCidrBlock>;
}
/**
 * DeleteVpcEndPointService返回参数结构体
 */
export interface DeleteVpcEndPointServiceResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssignIpv6CidrBlock请求参数结构体
 */
export interface AssignIpv6CidrBlockRequest {
    /**
      * `VPC`实例`ID`，形如：`vpc-f49l6u0z`。
      */
    VpcId: string;
}
/**
 * CreateSecurityGroupPolicies返回参数结构体
 */
export interface CreateSecurityGroupPoliciesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * UnassignIpv6CidrBlock返回参数结构体
 */
export interface UnassignIpv6CidrBlockResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpnGatewayRoutes请求参数结构体
 */
export interface ModifyVpnGatewayRoutesRequest {
    /**
      * Vpn网关id
      */
    VpnGatewayId: string;
    /**
      * 路由修改参数
      */
    Routes: Array<VpnGatewayRouteModify>;
}
/**
 * HaVipAssociateAddressIp请求参数结构体
 */
export interface HaVipAssociateAddressIpRequest {
    /**
      * `HAVIP`唯一`ID`，形如：`havip-9o233uri`。必须是没有绑定`EIP`的`HAVIP`
      */
    HaVipId: string;
    /**
      * 弹性公网`IP`。必须是没有绑定`HAVIP`的`EIP`
      */
    AddressIp: string;
}
/**
 * DisassociateNatGatewayAddress返回参数结构体
 */
export interface DisassociateNatGatewayAddressResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteRoutes返回参数结构体
 */
export interface DeleteRoutesResponse {
    /**
      * 已删除的路由策略详情。
      */
    RouteSet?: Array<Route>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCrossBorderCompliance请求参数结构体
 */
export interface DescribeCrossBorderComplianceRequest {
    /**
      * （精确匹配）服务商，可选值：`UNICOM`。
      */
    ServiceProvider?: string;
    /**
      * （精确匹配）合规化审批单`ID`。
      */
    ComplianceId?: number;
    /**
      * （模糊查询）公司名称。
      */
    Company?: string;
    /**
      * （精确匹配）统一社会信用代码。
      */
    UniformSocialCreditCode?: string;
    /**
      * （模糊查询）法定代表人。
      */
    LegalPerson?: string;
    /**
      * （模糊查询）发证机关。
      */
    IssuingAuthority?: string;
    /**
      * （模糊查询）营业执照住所。
      */
    BusinessAddress?: string;
    /**
      * （精确匹配）邮编。
      */
    PostCode?: number;
    /**
      * （模糊查询）经办人。
      */
    Manager?: string;
    /**
      * （精确查询）经办人身份证号。
      */
    ManagerId?: string;
    /**
      * （模糊查询）经办人身份证地址。
      */
    ManagerAddress?: string;
    /**
      * （精确匹配）经办人联系电话。
      */
    ManagerTelephone?: string;
    /**
      * （精确匹配）电子邮箱。
      */
    Email?: string;
    /**
      * （精确匹配）服务开始日期，如：`2020-07-28`。
      */
    ServiceStartDate?: string;
    /**
      * （精确匹配）服务结束日期，如：`2021-07-28`。
      */
    ServiceEndDate?: string;
    /**
      * （精确匹配）状态。待审批：`PENDING`，通过：`APPROVED `，拒绝：`DENY`。
      */
    State?: string;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
}
/**
 * DescribeSecurityGroupAssociationStatistics返回参数结构体
 */
export interface DescribeSecurityGroupAssociationStatisticsResponse {
    /**
      * 安全组关联实例统计。
      */
    SecurityGroupAssociationStatisticsSet?: Array<SecurityGroupAssociationStatistics>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyAssistantCidr返回参数结构体
 */
export interface ModifyAssistantCidrResponse {
    /**
      * 辅助CIDR数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    AssistantCidrSet: Array<AssistantCidr>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 用于发布云联网的cidr信息
 */
export interface CidrForCcn {
    /**
      * local cidr值。
注意：此字段可能返回 null，表示取不到有效值。
      */
    Cidr: string;
    /**
      * 是否发布到了云联网。
注意：此字段可能返回 null，表示取不到有效值。
      */
    PublishedToVbc: boolean;
}
/**
 * NAT网关绑定的弹性IP
 */
export interface NatGatewayAddress {
    /**
      * 弹性公网IP（EIP）的唯一 ID，形如：`eip-11112222`。
      */
    AddressId?: string;
    /**
      * 外网IP地址，形如：`123.121.34.33`。
      */
    PublicIpAddress?: string;
    /**
      * 资源封堵状态。true表示弹性ip处于封堵状态，false表示弹性ip处于未封堵状态。
      */
    IsBlocked?: boolean;
}
/**
 * DescribeVpcEndPointService返回参数结构体
 */
export interface DescribeVpcEndPointServiceResponse {
    /**
      * 终端节点服务对象数组。
      */
    EndPointServiceSet: Array<EndPointService>;
    /**
      * 符合查询条件的个数。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNetworkAclEntries返回参数结构体
 */
export interface ModifyNetworkAclEntriesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpcEndPointAttribute返回参数结构体
 */
export interface ModifyVpcEndPointAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeFlowLog请求参数结构体
 */
export interface DescribeFlowLogRequest {
    /**
      * 私用网络ID或者统一ID，建议使用统一ID
      */
    VpcId: string;
    /**
      * 流日志唯一ID
      */
    FlowLogId: string;
}
/**
 * DescribeTenantCcns请求参数结构体
 */
export declare type DescribeTenantCcnsRequest = null;
/**
 * DescribeIp6Addresses请求参数结构体
 */
export interface DescribeIp6AddressesRequest {
    /**
      * 标识 IPV6 的唯一 ID 列表。IPV6 唯一 ID 形如：`eip-11112222`。参数不支持同时指定`Ip6AddressIds`和`Filters`。
      */
    Ip6AddressIds?: Array<string>;
    /**
      * 每次请求的`Filters`的上限为10，`Filter.Values`的上限为5。参数不支持同时指定`AddressIds`和`Filters`。详细的过滤条件如下：
<li> address-ip - String - 是否必填：否 - （过滤条件）按照 EIP 的 IP 地址过滤。</li>
<li> network-interface-id - String - 是否必填：否 - （过滤条件）按照弹性网卡的唯一ID过滤。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于`Offset`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Limit?: number;
}
/**
 * AddIp6Rules请求参数结构体
 */
export interface AddIp6RulesRequest {
    /**
      * IPV6转换实例唯一ID，形如ip6-xxxxxxxx
      */
    Ip6TranslatorId: string;
    /**
      * IPV6转换规则信息
      */
    Ip6RuleInfos: Array<Ip6RuleInfo>;
    /**
      * IPV6转换规则名称
      */
    Ip6RuleName?: string;
}
/**
 * DescribeAccountAttributes返回参数结构体
 */
export interface DescribeAccountAttributesResponse {
    /**
      * 用户账号属性对象
      */
    AccountAttributeSet?: Array<AccountAttribute>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssignPrivateIpAddresses返回参数结构体
 */
export interface AssignPrivateIpAddressesResponse {
    /**
      * 内网IP详细信息。
      */
    PrivateIpAddressSet: Array<PrivateIpAddressSpecification>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroups请求参数结构体
 */
export interface DescribeSecurityGroupsRequest {
    /**
      * 安全组实例ID，例如：sg-33ocnj9n，可通过DescribeSecurityGroups获取。每次请求的实例的上限为100。参数不支持同时指定SecurityGroupIds和Filters。
      */
    SecurityGroupIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定SecurityGroupIds和Filters。
<li>security-group-id - String - （过滤条件）安全组ID。</li>
<li>project-id - Integer - （过滤条件）项目ID。</li>
<li>security-group-name - String - （过滤条件）安全组名称。</li>
<li>tag-key - String -是否必填：否- （过滤条件）按照标签键进行过滤。使用请参考示例2。</li>
<li>tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例3。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * RefreshDirectConnectGatewayRouteToNatGateway请求参数结构体
 */
export interface RefreshDirectConnectGatewayRouteToNatGatewayRequest {
    /**
      * vpc的ID
      */
    VpcId: string;
    /**
      * NAT网关ID
      */
    NatGatewayId: string;
    /**
      * 是否是预刷新；True:是， False:否
      */
    DryRun: boolean;
}
/**
 * DescribeNatGatewayDestinationIpPortTranslationNatRules请求参数结构体
 */
export interface DescribeNatGatewayDestinationIpPortTranslationNatRulesRequest {
    /**
      * NAT网关ID。
      */
    NatGatewayIds?: Array<string>;
    /**
      * 过滤条件:
参数不支持同时指定NatGatewayIds和Filters。
<li> nat-gateway-id，NAT网关的ID，如`nat-0yi4hekt`</li>
<li> vpc-id，私有网络VPC的ID，如`vpc-0yi4hekt`</li>
<li> public-ip-address， 弹性IP，如`139.199.232.238`。</li>
<li>public-port， 公网端口。</li>
<li>private-ip-address， 内网IP，如`10.0.0.1`。</li>
<li>private-port， 内网端口。</li>
<li>description，规则描述。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * ModifyNetworkAclAttribute返回参数结构体
 */
export interface ModifyNetworkAclAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpnGatewayRoutes请求参数结构体
 */
export interface CreateVpnGatewayRoutesRequest {
    /**
      * VPN网关的ID
      */
    VpnGatewayId: string;
    /**
      * VPN网关目的路由列表
      */
    Routes: Array<VpnGatewayRoute>;
}
/**
 * DisassociateNetworkAclSubnets返回参数结构体
 */
export interface DisassociateNetworkAclSubnetsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * SetCcnRegionBandwidthLimits请求参数结构体
 */
export interface SetCcnRegionBandwidthLimitsRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 云联网（CCN）各地域出带宽上限。
      */
    CcnRegionBandwidthLimits: Array<CcnRegionBandwidthLimit>;
    /**
      * 是否恢复云联网地域出口/地域间带宽限速为默认值（1Gbps）。false表示不恢复；true表示恢复。恢复默认值后，限速实例将不在控制台展示。该参数默认为 false，不恢复。
      */
    SetDefaultLimitFlag?: boolean;
}
/**
 * ModifyAddressInternetChargeType请求参数结构体
 */
export interface ModifyAddressInternetChargeTypeRequest {
    /**
      * 弹性公网IP的唯一ID，形如eip-xxx
      */
    AddressId: string;
    /**
      * 弹性公网IP调整目标计费模式，只支持"BANDWIDTH_PREPAID_BY_MONTH"和"TRAFFIC_POSTPAID_BY_HOUR"
      */
    InternetChargeType: string;
    /**
      * 弹性公网IP调整目标带宽值
      */
    InternetMaxBandwidthOut: number;
    /**
      * 包月带宽网络计费模式参数。弹性公网IP的调整目标计费模式是"BANDWIDTH_PREPAID_BY_MONTH"时，必传该参数。
      */
    AddressChargePrepaid?: AddressChargePrepaid;
}
/**
 * ModifyIp6AddressesBandwidth请求参数结构体
 */
export interface ModifyIp6AddressesBandwidthRequest {
    /**
      * 修改的目标带宽，单位Mbps
      */
    InternetMaxBandwidthOut: number;
    /**
      * IPV6地址。Ip6Addresses和Ip6AddressId必须且只能传一个
      */
    Ip6Addresses?: Array<string>;
    /**
      * IPV6地址对应的唯一ID，形如eip-xxxxxxxx。Ip6Addresses和Ip6AddressId必须且只能传一个
      */
    Ip6AddressIds?: Array<string>;
}
/**
 * DisableVpnGatewaySslClientCert返回参数结构体
 */
export interface DisableVpnGatewaySslClientCertResponse {
    /**
      * 异步任务实例ID。
      */
    TaskId: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateLocalGateway请求参数结构体
 */
export interface CreateLocalGatewayRequest {
    /**
      * 本地网关名称
      */
    LocalGatewayName: string;
    /**
      * VPC实例ID
      */
    VpcId: string;
    /**
      * CDC实例ID
      */
    CdcId: string;
}
/**
 * DescribeDirectConnectGateways返回参数结构体
 */
export interface DescribeDirectConnectGatewaysResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount?: number;
    /**
      * 专线网关对象数组。
      */
    DirectConnectGatewaySet?: Array<DirectConnectGateway>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AddBandwidthPackageResources返回参数结构体
 */
export interface AddBandwidthPackageResourcesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * IPV6转换规则
 */
export interface Ip6RuleInfo {
    /**
      * IPV6端口号，可在0~65535范围取值
      */
    Vport6: number;
    /**
      * 协议类型，支持TCP/UDP
      */
    Protocol: string;
    /**
      * IPV4地址
      */
    Vip: string;
    /**
      * IPV4端口号，可在0~65535范围取值
      */
    Vport: number;
}
/**
 * CreateSecurityGroupWithPolicies返回参数结构体
 */
export interface CreateSecurityGroupWithPoliciesResponse {
    /**
      * 安全组对象。
      */
    SecurityGroup?: SecurityGroup;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteAddressTemplate返回参数结构体
 */
export interface DeleteAddressTemplateResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifySubnetAttribute返回参数结构体
 */
export interface ModifySubnetAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ResetNatGatewayConnection请求参数结构体
 */
export interface ResetNatGatewayConnectionRequest {
    /**
      * NAT网关ID。
      */
    NatGatewayId: string;
    /**
      * NAT网关并发连接上限，形如：1000000、3000000、10000000。
      */
    MaxConcurrentConnection: number;
}
/**
 * ModifyCcnAttachedInstancesAttribute请求参数结构体
 */
export interface ModifyCcnAttachedInstancesAttributeRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 关联网络实例列表
      */
    Instances: Array<CcnInstance>;
}
/**
 * DeleteAddressTemplate请求参数结构体
 */
export interface DeleteAddressTemplateRequest {
    /**
      * IP地址模板实例ID，例如：ipm-09o5m8kc。
      */
    AddressTemplateId: string;
}
/**
 * CreateNatGatewaySourceIpTranslationNatRule请求参数结构体
 */
export interface CreateNatGatewaySourceIpTranslationNatRuleRequest {
    /**
      * NAT网关的ID，形如："nat-df45454"
      */
    NatGatewayId: string;
    /**
      * NAT网关的SNAT转换规则
      */
    SourceIpTranslationNatRules: Array<SourceIpTranslationNatRule>;
}
/**
 * 弹性网卡
 */
export interface NetworkInterface {
    /**
      * 弹性网卡实例ID，例如：eni-f1xjkw1b。
      */
    NetworkInterfaceId: string;
    /**
      * 弹性网卡名称。
      */
    NetworkInterfaceName: string;
    /**
      * 弹性网卡描述。
      */
    NetworkInterfaceDescription?: string;
    /**
      * 子网实例ID。
      */
    SubnetId: string;
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 绑定的安全组。
      */
    GroupSet?: Array<string>;
    /**
      * 是否是主网卡。
      */
    Primary?: boolean;
    /**
      * MAC地址。
      */
    MacAddress: string;
    /**
      * 弹性网卡状态：
<li>`PENDING`：创建中</li>
<li>`AVAILABLE`：可用的</li>
<li>`ATTACHING`：绑定中</li>
<li>`DETACHING`：解绑中</li>
<li>`DELETING`：删除中</li>
      */
    State: string;
    /**
      * 内网IP信息。
      */
    PrivateIpAddressSet: Array<PrivateIpAddressSpecification>;
    /**
      * 绑定的云服务器对象。
注意：此字段可能返回 null，表示取不到有效值。
      */
    Attachment?: NetworkInterfaceAttachment;
    /**
      * 可用区。
      */
    Zone?: string;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * `IPv6`地址列表。
      */
    Ipv6AddressSet: Array<Ipv6Address>;
    /**
      * 标签键值对。
      */
    TagSet: Array<Tag>;
    /**
      * 网卡类型。0 - 弹性网卡；1 - evm弹性网卡。
      */
    EniType: number;
    /**
      * 网卡绑定的子机类型：cvm，eks。
注意：此字段可能返回 null，表示取不到有效值。
      */
    Business: string;
    /**
      * 网卡所关联的CDC实例ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CdcId: string;
    /**
      * 弹性网卡类型：0:标准型/1:扩展型。默认值为0。
注意：此字段可能返回 null，表示取不到有效值。
      */
    AttachType: number;
}
/**
 * TransformAddress请求参数结构体
 */
export interface TransformAddressRequest {
    /**
      * 待操作有普通公网 IP 的实例 ID。实例 ID 形如：`ins-11112222`。可通过登录[控制台](https://console.cloud.tencent.com/cvm)查询，也可通过 [DescribeInstances](https://cloud.tencent.com/document/api/213/9389) 接口返回值中的`InstanceId`获取。
      */
    InstanceId: string;
}
/**
 * ReplaceDirectConnectGatewayCcnRoutes请求参数结构体
 */
export interface ReplaceDirectConnectGatewayCcnRoutesRequest {
    /**
      * 专线网关ID，形如：dcg-prpqlmg1
      */
    DirectConnectGatewayId: string;
    /**
      * 需要连通的IDC网段列表
      */
    Routes: Array<DirectConnectGatewayCcnRoute>;
}
/**
 * 安全组被引用信息
 */
export interface ReferredSecurityGroup {
    /**
      * 安全组实例ID。
      */
    SecurityGroupId: string;
    /**
      * 引用安全组实例ID（SecurityGroupId）的所有安全组实例ID。
      */
    ReferredSecurityGroupIds: Array<string>;
}
/**
 * ModifyAddressTemplateAttribute请求参数结构体
 */
export interface ModifyAddressTemplateAttributeRequest {
    /**
      * IP地址模板实例ID，例如：ipm-mdunqeb6。
      */
    AddressTemplateId: string;
    /**
      * IP地址模板名称。
      */
    AddressTemplateName?: string;
    /**
      * 地址信息，支持 IP、CIDR、IP 范围。
      */
    Addresses?: Array<string>;
    /**
      * 支持添加备注的地址信息，支持 IP、CIDR、IP 范围。
      */
    AddressesExtra?: Array<AddressInfo>;
}
/**
 * CreateNatGateway返回参数结构体
 */
export interface CreateNatGatewayResponse {
    /**
      * NAT网关对象数组。
      */
    NatGatewaySet: Array<NatGateway>;
    /**
      * 符合条件的 NAT网关对象数量。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpnGatewaySslClients请求参数结构体
 */
export interface DescribeVpnGatewaySslClientsRequest {
    /**
      * 过滤条件，参数不支持同时指定SslVpnClientIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID形如：vpc-f49l6u0z。</li>
<li>vpn-gateway-id - String - （过滤条件）VPN实例ID形如：vpngw-5aluhh9t。</li>
<li>ssl-vpn-server-id - String - （过滤条件）SSL-VPN-SERVER实例ID形如：vpngwSslServer-123456。</li>
<li>ssl-vpn-client-id - String - （过滤条件）SSL-VPN-CLIENT实例ID形如：vpngwSslClient-123456。</li>
<li>ssl-vpn-client-name - String - （过滤条件）SSL-VPN-CLIENT实例名称。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 请求对象个数
      */
    Limit?: number;
    /**
      * SSL-VPN-CLIENT实例ID。形如：vpngwSslClient-f49l6u0z。每次请求的实例的上限为100。参数不支持同时指定SslVpnClientIds和Filters。
      */
    SslVpnClientIds?: Array<string>;
}
/**
 * DescribeIp6TranslatorQuota请求参数结构体
 */
export interface DescribeIp6TranslatorQuotaRequest {
    /**
      * 待查询IPV6转换实例的唯一ID列表，形如ip6-xxxxxxxx
      */
    Ip6TranslatorIds?: Array<string>;
}
/**
 * ModifySecurityGroupAttribute请求参数结构体
 */
export interface ModifySecurityGroupAttributeRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 安全组名称，可任意命名，但不得超过60个字符。
      */
    GroupName?: string;
    /**
      * 安全组备注，最多100个字符。
      */
    GroupDescription?: string;
}
/**
 * DescribeVpnGatewaySslServers请求参数结构体
 */
export interface DescribeVpnGatewaySslServersRequest {
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 请求对象个数
      */
    Limit?: number;
    /**
      * SSL-VPN-SERVER实例ID。形如：vpngwSslServer-12345678。每次请求的实例的上限为100。参数不支持同时指定SslVpnServerIds和Filters。
      */
    SslVpnServerIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定SslVpnServerIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID形如：vpc-f49l6u0z。</li>
<li>vpn-gateway-id - String - （过滤条件）VPN实例ID形如：vpngw-5aluhh9t。</li>
<li>vpn-gateway-name - String - （过滤条件）VPN实例名称。</li>
<li>ssl-vpn-server-name - String - （过滤条件）SSL-VPN-SERVER实例名称。</li>
<li>ssl-vpn-server-id - String - （过滤条件）SSL-VPN-SERVER实例ID形如：vpngwSslServer-123456。</li>
      */
    Filters?: Array<FilterObject>;
}
/**
 * ModifyNetDetect请求参数结构体
 */
export interface ModifyNetDetectRequest {
    /**
      * 网络探测实例`ID`。形如：`netd-12345678`
      */
    NetDetectId: string;
    /**
      * 网络探测名称，最大长度不能超过60个字节。
      */
    NetDetectName?: string;
    /**
      * 探测目的IPv4地址数组，最多两个。
      */
    DetectDestinationIp?: Array<string>;
    /**
      * 下一跳类型，目前我们支持的类型有：
VPN：VPN网关；
DIRECTCONNECT：专线网关；
PEERCONNECTION：对等连接；
NAT：NAT网关；
NORMAL_CVM：普通云服务器；
CCN：云联网网关；
      */
    NextHopType?: string;
    /**
      * 下一跳目的网关，取值与“下一跳类型”相关：
下一跳类型为VPN，取值VPN网关ID，形如：vpngw-12345678；
下一跳类型为DIRECTCONNECT，取值专线网关ID，形如：dcg-12345678；
下一跳类型为PEERCONNECTION，取值对等连接ID，形如：pcx-12345678；
下一跳类型为NAT，取值Nat网关，形如：nat-12345678；
下一跳类型为NORMAL_CVM，取值云服务器IPv4地址，形如：10.0.0.12；
下一跳类型为CCN，取值云联网ID，形如：ccn-44csczop；
      */
    NextHopDestination?: string;
    /**
      * 网络探测描述。
      */
    NetDetectDescription?: string;
}
/**
 * DescribeNetDetectStates返回参数结构体
 */
export interface DescribeNetDetectStatesResponse {
    /**
      * 符合条件的网络探测验证结果对象数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NetDetectStateSet: Array<NetDetectState>;
    /**
      * 符合条件的网络探测验证结果对象数量。
注意：此字段可能返回 null，表示取不到有效值。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpnGatewaySslServer请求参数结构体
 */
export interface DeleteVpnGatewaySslServerRequest {
    /**
      * SSL-VPN-SERVER 实例ID。
      */
    SslVpnServerId: string;
}
/**
 * AllocateIp6AddressesBandwidth返回参数结构体
 */
export interface AllocateIp6AddressesBandwidthResponse {
    /**
      * 弹性公网 IPV6 的唯一 ID 列表。
      */
    AddressSet?: Array<string>;
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId?: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNetDetectStates请求参数结构体
 */
export interface DescribeNetDetectStatesRequest {
    /**
      * 网络探测实例`ID`数组。形如：[`netd-12345678`]
      */
    NetDetectIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定NetDetectIds和Filters。
<li>net-detect-id - String - （过滤条件）网络探测实例ID，形如：netd-12345678</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * DescribeNatGateways返回参数结构体
 */
export interface DescribeNatGatewaysResponse {
    /**
      * NAT网关对象数组。
      */
    NatGatewaySet: Array<NatGateway>;
    /**
      * 符合条件的NAT网关对象个数。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeFlowLog返回参数结构体
 */
export interface DescribeFlowLogResponse {
    /**
      * 流日志信息
      */
    FlowLog?: Array<FlowLog>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DownloadCustomerGatewayConfiguration返回参数结构体
 */
export interface DownloadCustomerGatewayConfigurationResponse {
    /**
      * XML格式配置信息。
      */
    CustomerGatewayConfiguration?: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeBandwidthPackages请求参数结构体
 */
export interface DescribeBandwidthPackagesRequest {
    /**
      * 带宽包唯一ID列表
      */
    BandwidthPackageIds?: Array<string>;
    /**
      * 每次请求的`Filters`的上限为10。参数不支持同时指定`BandwidthPackageIds`和`Filters`。详细的过滤条件如下：
<li> bandwidth-package_id - String - 是否必填：否 - （过滤条件）按照带宽包的唯一标识ID过滤。</li>
<li> bandwidth-package-name - String - 是否必填：否 - （过滤条件）按照 带宽包名称过滤。不支持模糊过滤。</li>
<li> network-type - String - 是否必填：否 - （过滤条件）按照带宽包的类型过滤。类型包括'HIGH_QUALITY_BGP','BGP','SINGLEISP'和'ANYCAST'。</li>
<li> charge-type - String - 是否必填：否 - （过滤条件）按照带宽包的计费类型过滤。计费类型包括'TOP5_POSTPAID_BY_MONTH'和'PERCENT95_POSTPAID_BY_MONTH'。</li>
<li> resource.resource-type - String - 是否必填：否 - （过滤条件）按照带宽包资源类型过滤。资源类型包括'Address'和'LoadBalance'</li>
<li> resource.resource-id - String - 是否必填：否 - （过滤条件）按照带宽包资源Id过滤。资源Id形如'eip-xxxx','lb-xxxx'</li>
<li> resource.address-ip - String - 是否必填：否 - （过滤条件）按照带宽包资源Ip过滤。</li>
<li> tag-key - String - 是否必填：否 - （过滤条件）按照标签键进行过滤。</li>
<li> tag-value - String - 是否必填：否 - （过滤条件）按照标签值进行过滤。</li>
<li> tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。tag-key使用具体的标签键进行替换。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 查询带宽包偏移量
      */
    Offset?: number;
    /**
      * 查询带宽包数量限制
      */
    Limit?: number;
}
/**
 * DeleteDirectConnectGatewayCcnRoutes返回参数结构体
 */
export interface DeleteDirectConnectGatewayCcnRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeAssistantCidr返回参数结构体
 */
export interface DescribeAssistantCidrResponse {
    /**
      * 符合条件的辅助CIDR数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    AssistantCidrSet: Array<AssistantCidr>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 用于描述实例的统计信息
 */
export interface InstanceStatistic {
    /**
      * 实例的类型
      */
    InstanceType: string;
    /**
      * 实例的个数
      */
    InstanceCount: number;
}
/**
 * CreateVpnConnection请求参数结构体
 */
export interface CreateVpnConnectionRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * 对端网关ID，例如：cgw-2wqq41m9，可通过DescribeCustomerGateways接口查询对端网关。
      */
    CustomerGatewayId: string;
    /**
      * 通道名称，可任意命名，但不得超过60个字符。
      */
    VpnConnectionName: string;
    /**
      * 预共享密钥。
      */
    PreShareKey: string;
    /**
      * VPC实例ID。可通过[DescribeVpcs](https://cloud.tencent.com/document/product/215/15778)接口返回值中的VpcId获取。
CCN VPN 形的通道 可以不传VPCID
      */
    VpcId?: string;
    /**
      * SPD策略组，例如：{"10.0.0.5/24":["172.123.10.5/16"]}，10.0.0.5/24是vpc内网段172.123.10.5/16是IDC网段。用户指定VPC内哪些网段可以和您IDC中哪些网段通信。
      */
    SecurityPolicyDatabases?: Array<SecurityPolicyDatabase>;
    /**
      * IKE配置（Internet Key Exchange，因特网密钥交换），IKE具有一套自我保护机制，用户配置网络安全协议
      */
    IKEOptionsSpecification?: IKEOptionsSpecification;
    /**
      * IPSec配置，腾讯云提供IPSec安全会话设置
      */
    IPSECOptionsSpecification?: IPSECOptionsSpecification;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * 是否支持隧道内健康检查
      */
    EnableHealthCheck?: boolean;
    /**
      * 健康检查本端地址
      */
    HealthCheckLocalIp?: string;
    /**
      * 健康检查对端地址
      */
    HealthCheckRemoteIp?: string;
    /**
      * 通道类型, 例如:["STATIC", "StaticRoute", "Policy"]
      */
    RouteType?: string;
    /**
      * 协商类型，默认为active（主动协商）。可选值：active（主动协商），passive（被动协商），flowTrigger（流量协商）
      */
    NegotiationType?: string;
    /**
      * DPD探测开关。默认为0，表示关闭DPD探测。可选值：0（关闭），1（开启）
      */
    DpdEnable?: number;
    /**
      * DPD超时时间。即探测确认对端不存在需要的时间。dpdEnable为1（开启）时有效。默认30，单位为秒
      */
    DpdTimeout?: string;
    /**
      * DPD超时后的动作。默认为clear。dpdEnable为1（开启）时有效。可取值为clear（断开）和restart（重试）
      */
    DpdAction?: string;
}
/**
 * CCN路由策略对象
 */
export interface CcnRoute {
    /**
      * 路由策略ID
      */
    RouteId?: string;
    /**
      * 目的端
      */
    DestinationCidrBlock: string;
    /**
      * 下一跳类型（关联实例类型），所有类型：VPC、DIRECTCONNECT
      */
    InstanceType: string;
    /**
      * 下一跳（关联实例）
      */
    InstanceId: string;
    /**
      * 下一跳名称（关联实例名称）
      */
    InstanceName: string;
    /**
      * 下一跳所属地域（关联实例所属地域）
      */
    InstanceRegion: string;
    /**
      * 更新时间
      */
    UpdateTime: string;
    /**
      * 路由是否启用
      */
    Enabled: boolean;
    /**
      * 关联实例所属UIN（根账号）
      */
    InstanceUin: string;
    /**
      * 路由的扩展状态
      */
    ExtraState: string;
    /**
      * 是否动态路由
      */
    IsBgp: boolean;
    /**
      * 路由优先级
      */
    RoutePriority: number;
    /**
      * 下一跳扩展名称（关联实例的扩展名称）
      */
    InstanceExtraName: string;
}
/**
 * ModifyIpv6AddressesAttribute返回参数结构体
 */
export interface ModifyIpv6AddressesAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteSecurityGroupPolicies请求参数结构体
 */
export interface DeleteSecurityGroupPoliciesRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 安全组规则集合。一个请求中只能删除单个方向的一条或多条规则。支持指定索引（PolicyIndex） 匹配删除和安全组规则匹配删除两种方式，一个请求中只能使用一种匹配方式。
      */
    SecurityGroupPolicySet: SecurityGroupPolicySet;
}
/**
 * VPN通道对象。
 */
export interface VpnConnection {
    /**
      * 通道实例ID。
      */
    VpnConnectionId: string;
    /**
      * 通道名称。
      */
    VpnConnectionName: string;
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * 对端网关实例ID。
      */
    CustomerGatewayId: string;
    /**
      * 预共享密钥。
      */
    PreShareKey: string;
    /**
      * 通道传输协议。
      */
    VpnProto: string;
    /**
      * 通道加密协议。
      */
    EncryptProto: string;
    /**
      * 路由类型。
      */
    RouteType: string;
    /**
      * 创建时间。
      */
    CreatedTime: string;
    /**
      * 通道的生产状态，PENDING：生产中，AVAILABLE：运行中，DELETING：删除中。
      */
    State: string;
    /**
      * 通道连接状态，AVAILABLE：已连接。
      */
    NetStatus: string;
    /**
      * SPD。
      */
    SecurityPolicyDatabaseSet: Array<SecurityPolicyDatabase>;
    /**
      * IKE选项。
      */
    IKEOptionsSpecification: IKEOptionsSpecification;
    /**
      * IPSEC选择。
      */
    IPSECOptionsSpecification: IPSECOptionsSpecification;
    /**
      * 是否支持健康状态探测
      */
    EnableHealthCheck: boolean;
    /**
      * 本端探测ip
      */
    HealthCheckLocalIp: string;
    /**
      * 对端探测ip
      */
    HealthCheckRemoteIp: string;
    /**
      * 通道健康检查状态，AVAILABLE：正常，UNAVAILABLE：不正常。 未配置健康检查不返回该对象
      */
    HealthCheckStatus: string;
}
/**
 * DescribeCcns请求参数结构体
 */
export interface DescribeCcnsRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。每次请求的实例的上限为100。参数不支持同时指定CcnIds和Filters。
      */
    CcnIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定CcnIds和Filters。
<li>ccn-id - String - （过滤条件）CCN唯一ID，形如：vpc-f49l6u0z。</li>
<li>ccn-name - String - （过滤条件）CCN名称。</li>
<li>ccn-description - String - （过滤条件）CCN描述。</li>
<li>state - String - （过滤条件）实例状态， 'ISOLATED': 隔离中（欠费停服），'AVAILABLE'：运行中。</li>
<li>tag-key - String -是否必填：否- （过滤条件）按照标签键进行过滤。</li>
<li>tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例：查询绑定了标签的CCN列表。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
    /**
      * 排序字段。支持：`CcnId` `CcnName` `CreateTime` `State` `QosLevel`
      */
    OrderField?: string;
    /**
      * 排序方法。顺序：`ASC`，倒序：`DESC`。
      */
    OrderDirection?: string;
}
/**
 * ModifyNatGatewayAttribute返回参数结构体
 */
export interface ModifyNatGatewayAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNetDetects请求参数结构体
 */
export interface DescribeNetDetectsRequest {
    /**
      * 网络探测实例`ID`数组。形如：[`netd-12345678`]
      */
    NetDetectIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定NetDetectIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-12345678</li>
<li>net-detect-id - String - （过滤条件）网络探测实例ID，形如：netd-12345678</li>
<li>subnet-id - String - （过滤条件）子网实例ID，形如：subnet-12345678</li>
<li>net-detect-name - String - （过滤条件）网络探测名称</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * CreateAddressTemplateGroup请求参数结构体
 */
export interface CreateAddressTemplateGroupRequest {
    /**
      * IP地址模板集合名称。
      */
    AddressTemplateGroupName: string;
    /**
      * IP地址模板实例ID，例如：ipm-mdunqeb6。
      */
    AddressTemplateIds: Array<string>;
}
/**
 * DescribeNatGatewayDirectConnectGatewayRoute请求参数结构体
 */
export interface DescribeNatGatewayDirectConnectGatewayRouteRequest {
    /**
      * nat的唯一标识
      */
    NatGatewayId: string;
    /**
      * vpc的唯一标识
      */
    VpcId: string;
    /**
      * 0到200之间
      */
    Limit?: number;
    /**
      * 大于0
      */
    Offset?: number;
}
/**
 * DescribeCustomerGatewayVendors返回参数结构体
 */
export interface DescribeCustomerGatewayVendorsResponse {
    /**
      * 对端网关厂商信息对象。
      */
    CustomerGatewayVendorSet?: Array<CustomerGatewayVendor>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 路由冲突对象
 */
export interface RouteConflict {
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
    /**
      * 要检查的与之冲突的目的端
      */
    DestinationCidrBlock: string;
    /**
      * 冲突的路由策略列表
      */
    ConflictSet: Array<Route>;
}
/**
 * DeleteSubnet返回参数结构体
 */
export interface DeleteSubnetResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 私有网络(VPC)对象。
 */
export interface Vpc {
    /**
      * `VPC`名称。
      */
    VpcName: string;
    /**
      * `VPC`实例`ID`，例如：vpc-azd4dt1c。
      */
    VpcId: string;
    /**
      * `VPC`的`IPv4` `CIDR`。
      */
    CidrBlock: string;
    /**
      * 是否默认`VPC`。
      */
    IsDefault?: boolean;
    /**
      * 是否开启组播。
      */
    EnableMulticast: boolean;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * `DNS`列表。
      */
    DnsServerSet: Array<string>;
    /**
      * `DHCP`域名选项值。
      */
    DomainName: string;
    /**
      * `DHCP`选项集`ID`。
      */
    DhcpOptionsId: string;
    /**
      * 是否开启`DHCP`。
      */
    EnableDhcp: boolean;
    /**
      * `VPC`的`IPv6` `CIDR`。
      */
    Ipv6CidrBlock: string;
    /**
      * 标签键值对
      */
    TagSet: Array<Tag>;
    /**
      * 辅助CIDR
注意：此字段可能返回 null，表示取不到有效值。
      */
    AssistantCidrSet: Array<AssistantCidr>;
}
/**
 * CreateVpnGateway返回参数结构体
 */
export interface CreateVpnGatewayResponse {
    /**
      * VPN网关对象
      */
    VpnGateway: VpnGateway;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNatGatewayDestinationIpPortTranslationNatRules返回参数结构体
 */
export interface DescribeNatGatewayDestinationIpPortTranslationNatRulesResponse {
    /**
      * NAT网关端口转发规则对象数组。
      */
    NatGatewayDestinationIpPortTranslationNatRuleSet: Array<NatGatewayDestinationIpPortTranslationNatRule>;
    /**
      * 符合条件的NAT网关端口转发规则对象数目。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 流日志存储信息
 */
export interface FlowLogStorage {
    /**
      * 存储实例Id，当流日志存储类型为ckafka时，必填。
      */
    StorageId: string;
    /**
      * 主题Id，当流日志存储类型为ckafka时，必填。
注意：此字段可能返回 null，表示取不到有效值。
      */
    StorageTopic?: string;
}
/**
 * DescribeVpcIpv6Addresses返回参数结构体
 */
export interface DescribeVpcIpv6AddressesResponse {
    /**
      * `IPv6`地址列表。
      */
    Ipv6AddressSet?: Array<VpcIpv6Address>;
    /**
      * `IPv6`地址总数。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ResetAttachCcnInstances返回参数结构体
 */
export interface ResetAttachCcnInstancesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * RejectAttachCcnInstances请求参数结构体
 */
export interface RejectAttachCcnInstancesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 拒绝关联实例列表。
      */
    Instances: Array<CcnInstance>;
}
/**
 * ModifyCcnRegionBandwidthLimitsType请求参数结构体
 */
export interface ModifyCcnRegionBandwidthLimitsTypeRequest {
    /**
      * 云联网实例ID。
      */
    CcnId: string;
    /**
      * 云联网限速类型，INTER_REGION_LIMIT：地域间限速，OUTER_REGION_LIMIT：地域出口限速。
      */
    BandwidthLimitType?: string;
}
/**
 * Vpn网关目的路由
 */
export interface VpnGatewayRoute {
    /**
      * 目的端IDC网段
      */
    DestinationCidrBlock: string;
    /**
      * 下一跳类型（关联实例类型）可选值:"VPNCONN"(VPN通道), "CCN"(CCN实例)
      */
    InstanceType: string;
    /**
      * 下一跳实例ID
      */
    InstanceId: string;
    /**
      * 优先级, 可选值: 0, 100
      */
    Priority: number;
    /**
      * 启用状态, 可选值: "ENABLE"(启用), "DISABLE"(禁用)
      */
    Status: string;
    /**
      * 路由条目ID
      */
    RouteId?: string;
    /**
      * 路由类型, 可选值: "VPC"(VPC路由), "CCN"(云联网传播路由), "Static"(静态路由), "BGP"(BGP路由)
      */
    Type?: string;
    /**
      * 创建时间
      */
    CreateTime?: string;
    /**
      * 更新时间
      */
    UpdateTime?: string;
}
/**
 * DescribeVpcResourceDashboard请求参数结构体
 */
export interface DescribeVpcResourceDashboardRequest {
    /**
      * Vpc实例ID，例如：vpc-f1xjkw1b。
      */
    VpcIds: Array<string>;
}
/**
 * ModifyIp6Rule请求参数结构体
 */
export interface ModifyIp6RuleRequest {
    /**
      * IPV6转换实例唯一ID，形如ip6-xxxxxxxx
      */
    Ip6TranslatorId: string;
    /**
      * IPV6转换规则唯一ID，形如rule6-xxxxxxxx
      */
    Ip6RuleId: string;
    /**
      * IPV6转换规则修改后的名称
      */
    Ip6RuleName?: string;
    /**
      * IPV6转换规则修改后的IPV4地址
      */
    Vip?: string;
    /**
      * IPV6转换规则修改后的IPV4端口号
      */
    Vport?: number;
}
/**
 * ReplaceRouteTableAssociation请求参数结构体
 */
export interface ReplaceRouteTableAssociationRequest {
    /**
      * 子网实例ID，例如：subnet-3x5lf5q0。可通过DescribeSubnets接口查询。
      */
    SubnetId: string;
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
}
/**
 * AssociateNetworkAclSubnets请求参数结构体
 */
export interface AssociateNetworkAclSubnetsRequest {
    /**
      * 网络ACL实例ID。例如：acl-12345678。
      */
    NetworkAclId: string;
    /**
      * 子网实例ID数组。例如：[subnet-12345678]
      */
    SubnetIds: Array<string>;
}
/**
 * CheckAssistantCidr请求参数结构体
 */
export interface CheckAssistantCidrRequest {
    /**
      * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
      */
    VpcId: string;
    /**
      * 待添加的负载CIDR。CIDR数组，格式如["10.0.0.0/16", "172.16.0.0/16"]。入参NewCidrBlocks和OldCidrBlocks至少需要其一。
      */
    NewCidrBlocks?: Array<string>;
    /**
      * 待删除的负载CIDR。CIDR数组，格式如["10.0.0.0/16", "172.16.0.0/16"]。入参NewCidrBlocks和OldCidrBlocks至少需要其一。
      */
    OldCidrBlocks?: Array<string>;
}
/**
 * RenewVpnGateway请求参数结构体
 */
export interface RenewVpnGatewayRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * 预付费计费模式。
      */
    InstanceChargePrepaid: InstanceChargePrepaid;
}
/**
 * 安全组规则对象
 */
export interface SecurityGroupPolicy {
    /**
      * 安全组规则索引号，值会随着安全组规则的变更动态变化。使用PolicyIndex时，请先调用`DescribeSecurityGroupPolicies`获取到规则的PolicyIndex，并且结合返回值中的Version一起使用处理规则。
      */
    PolicyIndex?: number;
    /**
      * 协议, 取值: TCP,UDP,ICMP,ICMPv6,ALL。
      */
    Protocol?: string;
    /**
      * 端口(all, 离散port,  range)。
说明：如果Protocol设置为ALL，则Port也需要设置为all。
      */
    Port?: string;
    /**
      * 协议端口ID或者协议端口组ID。ServiceTemplate和Protocol+Port互斥。
      */
    ServiceTemplate?: ServiceTemplateSpecification;
    /**
      * 网段或IP(互斥)。
      */
    CidrBlock?: string;
    /**
      * 网段或IPv6(互斥)。
      */
    Ipv6CidrBlock?: string;
    /**
      * 安全组实例ID，例如：sg-ohuuioma。
      */
    SecurityGroupId?: string;
    /**
      * IP地址ID或者ID地址组ID。
      */
    AddressTemplate?: AddressTemplateSpecification;
    /**
      * ACCEPT 或 DROP。
      */
    Action?: string;
    /**
      * 安全组规则描述。
      */
    PolicyDescription?: string;
    /**
      * 安全组最近修改时间。
      */
    ModifyTime?: string;
}
/**
 * NotifyRoutes请求参数结构体
 */
export interface NotifyRoutesRequest {
    /**
      * 路由表唯一ID。
      */
    RouteTableId: string;
    /**
      * 路由策略唯一ID。
      */
    RouteItemIds: Array<string>;
}
/**
 * DeleteVpc请求参数结构体
 */
export interface DeleteVpcRequest {
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
}
/**
 * ModifyServiceTemplateAttribute返回参数结构体
 */
export interface ModifyServiceTemplateAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCcns返回参数结构体
 */
export interface DescribeCcnsResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount: number;
    /**
      * CCN对象。
      */
    CcnSet: Array<CCN>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 参数模板配额
 */
export interface TemplateLimit {
    /**
      * 参数模板IP地址成员配额。
      */
    AddressTemplateMemberLimit: number;
    /**
      * 参数模板IP地址组成员配额。
      */
    AddressTemplateGroupMemberLimit: number;
    /**
      * 参数模板I协议端口成员配额。
      */
    ServiceTemplateMemberLimit: number;
    /**
      * 参数模板协议端口组成员配额。
      */
    ServiceTemplateGroupMemberLimit: number;
}
/**
 * CreateSubnet返回参数结构体
 */
export interface CreateSubnetResponse {
    /**
      * 子网对象。
      */
    Subnet: Subnet;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroupPolicies返回参数结构体
 */
export interface DescribeSecurityGroupPoliciesResponse {
    /**
      * 安全组规则集合。
      */
    SecurityGroupPolicySet: SecurityGroupPolicySet;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeGatewayFlowQos返回参数结构体
 */
export interface DescribeGatewayFlowQosResponse {
    /**
      * 实例详细信息列表。
      */
    GatewayQosSet: Array<GatewayQos>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifySecurityGroupPolicies请求参数结构体
 */
export interface ModifySecurityGroupPoliciesRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 安全组规则集合。 SecurityGroupPolicySet对象必须同时指定新的出（Egress）入（Ingress）站规则。 SecurityGroupPolicy对象不支持自定义索引（PolicyIndex）。
      */
    SecurityGroupPolicySet: SecurityGroupPolicySet;
    /**
      * 排序安全组标识，默认值为False。当SortPolicys为False时，不改变安全组规则排序；当SortPolicys为True时，系统将严格按照SecurityGroupPolicySet参数传入的安全组规则及顺序进行重置，考虑到人为输入参数可能存在遗漏风险，建议通过控制台对安全组规则进行排序。
      */
    SortPolicys?: boolean;
}
/**
 * NAT网关对象。
 */
export interface NatGateway {
    /**
      * NAT网关的ID。
      */
    NatGatewayId: string;
    /**
      * NAT网关的名称。
      */
    NatGatewayName: string;
    /**
      * NAT网关创建的时间。
      */
    CreatedTime: string;
    /**
      * NAT网关的状态。
 'PENDING'：生产中，'DELETING'：删除中，'AVAILABLE'：运行中，'UPDATING'：升级中，
‘FAILED’：失败。
      */
    State: string;
    /**
      * 网关最大外网出带宽(单位:Mbps)。
      */
    InternetMaxBandwidthOut: number;
    /**
      * 网关并发连接上限。
      */
    MaxConcurrentConnection: number;
    /**
      * 绑定NAT网关的公网IP对象数组。
      */
    PublicIpAddressSet: Array<NatGatewayAddress>;
    /**
      * NAT网关网络状态。“AVAILABLE”:运行中, “UNAVAILABLE”:不可用, “INSUFFICIENT”:欠费停服。
      */
    NetworkState: string;
    /**
      * NAT网关的端口转发规则。
      */
    DestinationIpPortTranslationNatRuleSet: Array<DestinationIpPortTranslationNatRule>;
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * NAT网关所在的可用区。
      */
    Zone: string;
    /**
      * 绑定的专线网关ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    DirectConnectGatewayIds: Array<string>;
    /**
      * 所属子网ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    SubnetId: string;
    /**
      * 标签键值对。
      */
    TagSet: Array<Tag>;
    /**
      * NAT网关绑定的安全组列表
注意：此字段可能返回 null，表示取不到有效值。
      */
    SecurityGroupSet: Array<string>;
    /**
      * NAT网关的SNAT转发规则。
注意：此字段可能返回 null，表示取不到有效值。
      */
    SourceIpTranslationNatRuleSet: Array<SourceIpTranslationNatRule>;
    /**
      * 是否独享型NAT。
注意：此字段可能返回 null，表示取不到有效值。
      */
    IsExclusive: boolean;
    /**
      * 独享型NAT所在的网关集群的带宽(单位:Mbps)，当IsExclusive为false时无此字段。
注意：此字段可能返回 null，表示取不到有效值。
      */
    ExclusiveGatewayBandwidth: number;
}
/**
 * AssociateDhcpIpWithAddressIp请求参数结构体
 */
export interface AssociateDhcpIpWithAddressIpRequest {
    /**
      * `DhcpIp`唯一`ID`，形如：`dhcpip-9o233uri`。必须是没有绑定`EIP`的`DhcpIp`
      */
    DhcpIpId: string;
    /**
      * 弹性公网`IP`。必须是没有绑定`DhcpIp`的`EIP`
      */
    AddressIp: string;
}
/**
 * ReplaceRoutes请求参数结构体
 */
export interface ReplaceRoutesRequest {
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
    /**
      * 路由策略对象。需要指定路由策略ID（RouteId）。
      */
    Routes: Array<Route>;
}
/**
 * CreateCustomerGateway返回参数结构体
 */
export interface CreateCustomerGatewayResponse {
    /**
      * 对端网关对象
      */
    CustomerGateway?: CustomerGateway;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * WithdrawNotifyRoutes请求参数结构体
 */
export interface WithdrawNotifyRoutesRequest {
    /**
      * 路由表唯一ID。
      */
    RouteTableId: string;
    /**
      * 路由策略唯一ID。
      */
    RouteItemIds: Array<string>;
}
/**
 * DeleteServiceTemplateGroup返回参数结构体
 */
export interface DeleteServiceTemplateGroupResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateAddress请求参数结构体
 */
export interface DisassociateAddressRequest {
    /**
      * 标识 EIP 的唯一 ID。EIP 唯一 ID 形如：`eip-11112222`。
      */
    AddressId: string;
    /**
      * 表示解绑 EIP 之后是否分配普通公网 IP。取值范围：<br><li>TRUE：表示解绑 EIP 之后分配普通公网 IP。<br><li>FALSE：表示解绑 EIP 之后不分配普通公网 IP。<br>默认取值：FALSE。<br><br>只有满足以下条件时才能指定该参数：<br><li> 只有在解绑主网卡的主内网 IP 上的 EIP 时才能指定该参数。<br><li>解绑 EIP 后重新分配普通公网 IP 操作一个账号每天最多操作 10 次；详情可通过 [DescribeAddressQuota](https://cloud.tencent.com/document/api/213/1378) 接口获取。
      */
    ReallocateNormalPublicIp?: boolean;
}
/**
 * 网络ACL规则集合
 */
export interface NetworkAclEntrySet {
    /**
      * 入站规则。
      */
    Ingress?: Array<NetworkAclEntry>;
    /**
      * 出站规则。
      */
    Egress?: Array<NetworkAclEntry>;
}
/**
 * DeleteVpnConnection返回参数结构体
 */
export interface DeleteVpnConnectionResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpnGatewaySslClients返回参数结构体
 */
export interface DescribeVpnGatewaySslClientsResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 符合条件的实例个数。
      */
    SslVpnClientSet: Array<SslVpnClient>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeBandwidthPackageResources请求参数结构体
 */
export interface DescribeBandwidthPackageResourcesRequest {
    /**
      * 标识 共享带宽包 的唯一 ID 列表。共享带宽包 唯一 ID 形如：`bwp-11112222`。
      */
    BandwidthPackageId: string;
    /**
      * 每次请求的`Filters`的上限为10，`Filter.Values`的上限为5。参数不支持同时指定`AddressIds`和`Filters`。详细的过滤条件如下：
<li> resource-id - String - 是否必填：否 - （过滤条件）按照 共享带宽包内资源 的唯一 ID 过滤。共享带宽包内资源 唯一 ID 形如：eip-11112222。</li>
<li> resource-type - String - 是否必填：否 - （过滤条件）按照 共享带宽包内资源 类型过滤，目前仅支持 弹性IP 和 负载均衡 两种类型，可选值为 Address 和 LoadBalance。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于`Offset`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Limit?: number;
}
/**
 * EnableCcnRoutes请求参数结构体
 */
export interface EnableCcnRoutesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * CCN路由策略唯一ID。形如：ccnr-f49l6u0z。
      */
    RouteIds: Array<string>;
}
/**
 * 标签键值对
 */
export interface Tag {
    /**
      * 标签键
注意：此字段可能返回 null，表示取不到有效值。
      */
    Key: string;
    /**
      * 标签值
注意：此字段可能返回 null，表示取不到有效值。
      */
    Value?: string;
}
/**
 * CreateFlowLog返回参数结构体
 */
export interface CreateFlowLogResponse {
    /**
      * 创建的流日志信息
      */
    FlowLog: Array<FlowLog>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 默认VPC和子网
 */
export interface DefaultVpcSubnet {
    /**
      * 默认VpcId
      */
    VpcId: string;
    /**
      * 默认SubnetId
      */
    SubnetId: string;
}
/**
 * DescribeIp6Translators请求参数结构体
 */
export interface DescribeIp6TranslatorsRequest {
    /**
      * IPV6转换实例唯一ID数组，形如ip6-xxxxxxxx
      */
    Ip6TranslatorIds?: Array<string>;
    /**
      * 每次请求的`Filters`的上限为10，`Filter.Values`的上限为5。参数不支持同时指定`Ip6TranslatorIds`和`Filters`。详细的过滤条件如下：
<li> ip6-translator-id - String - 是否必填：否 - （过滤条件）按照IPV6转换实例的唯一ID过滤,形如ip6-xxxxxxx。</li>
<li> ip6-translator-vip6 - String - 是否必填：否 - （过滤条件）按照IPV6地址过滤。不支持模糊过滤。</li>
<li> ip6-translator-name - String - 是否必填：否 - （过滤条件）按照IPV6转换实例名称过滤。不支持模糊过滤。</li>
<li> ip6-translator-status - String - 是否必填：否 - （过滤条件）按照IPV6转换实例的状态过滤。状态取值范围为"CREATING","RUNNING","DELETING","MODIFYING"
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于`Offset`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Limit?: number;
}
/**
 * CreateSubnets返回参数结构体
 */
export interface CreateSubnetsResponse {
    /**
      * 新创建的子网列表。
      */
    SubnetSet: Array<Subnet>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeGatewayFlowMonitorDetail请求参数结构体
 */
export interface DescribeGatewayFlowMonitorDetailRequest {
    /**
      * 时间点。表示要查询这分钟内的明细。如：`2019-02-28 18:15:20`，将查询 `18:15` 这一分钟内的明细。
      */
    TimePoint: string;
    /**
      * VPN网关实例ID，形如：`vpn-ltjahce6`。
      */
    VpnId?: string;
    /**
      * 专线网关实例ID，形如：`dcg-ltjahce6`。
      */
    DirectConnectGatewayId?: string;
    /**
      * 对等连接实例ID，形如：`pcx-ltjahce6`。
      */
    PeeringConnectionId?: string;
    /**
      * NAT网关实例ID，形如：`nat-ltjahce6`。
      */
    NatId?: string;
    /**
      * 偏移量。
      */
    Offset?: number;
    /**
      * 返回数量。
      */
    Limit?: number;
    /**
      * 排序字段。支持 `InPkg` `OutPkg` `InTraffic` `OutTraffic`。
      */
    OrderField?: string;
    /**
      * 排序方法。顺序：`ASC`，倒序：`DESC`。
      */
    OrderDirection?: string;
}
/**
 * InquiryPriceCreateVpnGateway返回参数结构体
 */
export interface InquiryPriceCreateVpnGatewayResponse {
    /**
      * 商品价格。
      */
    Price: Price;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroupLimits返回参数结构体
 */
export interface DescribeSecurityGroupLimitsResponse {
    /**
      * 用户安全组配额限制。
      */
    SecurityGroupLimitSet?: SecurityGroupLimitSet;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 对端网关
 */
export interface CustomerGateway {
    /**
      * 用户网关唯一ID
      */
    CustomerGatewayId: string;
    /**
      * 网关名称
      */
    CustomerGatewayName: string;
    /**
      * 公网地址
      */
    IpAddress: string;
    /**
      * 创建时间
      */
    CreatedTime: string;
}
/**
 * ModifyDirectConnectGatewayAttribute请求参数结构体
 */
export interface ModifyDirectConnectGatewayAttributeRequest {
    /**
      * 专线网关唯一`ID`，形如：`dcg-9o233uri`。
      */
    DirectConnectGatewayId: string;
    /**
      * 专线网关名称，可任意命名，但不得超过60个字符。
      */
    DirectConnectGatewayName?: string;
    /**
      * 云联网路由学习类型，可选值：`BGP`（自动学习）、`STATIC`（静态，即用户配置）。只有云联网类型专线网关且开启了BGP功能才支持修改`CcnRouteType`。
      */
    CcnRouteType?: string;
    /**
      * 云联网路由发布模式，可选值：`standard`（标准模式）、`exquisite`（精细模式）。只有云联网类型专线网关才支持修改`ModeType`。
      */
    ModeType?: string;
}
/**
 * ModifyBandwidthPackageAttribute返回参数结构体
 */
export interface ModifyBandwidthPackageAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpnGatewaySslServer返回参数结构体
 */
export interface CreateVpnGatewaySslServerResponse {
    /**
      * 创建SSL-VPN server 异步任务ID
      */
    TaskId: number;
    /**
      * SSL-VPN server 唯一ID
      */
    SslVpnServerId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ResetRoutes返回参数结构体
 */
export interface ResetRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNetworkAcl请求参数结构体
 */
export interface DeleteNetworkAclRequest {
    /**
      * 网络ACL实例ID。例如：acl-12345678。
      */
    NetworkAclId: string;
}
/**
 * NAT网关的端口转发规则
 */
export interface NatGatewayDestinationIpPortTranslationNatRule {
    /**
      * 网络协议，可选值：`TCP`、`UDP`。
      */
    IpProtocol?: string;
    /**
      * 弹性IP。
      */
    PublicIpAddress: string;
    /**
      * 公网端口。
      */
    PublicPort: number;
    /**
      * 内网地址。
      */
    PrivateIpAddress: string;
    /**
      * 内网端口。
      */
    PrivatePort: number;
    /**
      * NAT网关转发规则描述。
      */
    Description?: string;
    /**
      * NAT网关的ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NatGatewayId: string;
    /**
      * 私有网络VPC的ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    VpcId: string;
    /**
      * NAT网关转发规则创建时间。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CreatedTime: string;
}
/**
 * CloneSecurityGroup返回参数结构体
 */
export interface CloneSecurityGroupResponse {
    /**
      * 安全组对象。
注意：此字段可能返回 null，表示取不到有效值。
      */
    SecurityGroup?: SecurityGroup;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyDhcpIpAttribute请求参数结构体
 */
export interface ModifyDhcpIpAttributeRequest {
    /**
      * `DhcpIp`唯一`ID`，形如：`dhcpip-9o233uri`。
      */
    DhcpIpId: string;
    /**
      * `DhcpIp`名称，可任意命名，但不得超过60个字符。
      */
    DhcpIpName: string;
}
/**
 * ModifyIp6Translator请求参数结构体
 */
export interface ModifyIp6TranslatorRequest {
    /**
      * IPV6转换实例唯一ID，形如ip6-xxxxxxxxx
      */
    Ip6TranslatorId: string;
    /**
      * IPV6转换实例修改名称
      */
    Ip6TranslatorName?: string;
}
/**
 * CreateVpnConnection返回参数结构体
 */
export interface CreateVpnConnectionResponse {
    /**
      * 通道实例对象。
      */
    VpnConnection: VpnConnection;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * IP地址模板
 */
export interface AddressTemplateSpecification {
    /**
      * IP地址ID，例如：ipm-2uw6ujo6。
      */
    AddressId: string;
    /**
      * IP地址组ID，例如：ipmg-2uw6ujo6。
      */
    AddressGroupId: string;
}
/**
 * VPC内网IPv6对象。
 */
export interface VpcIpv6Address {
    /**
      * `VPC`内`IPv6`地址。
      */
    Ipv6Address: string;
    /**
      * 所属子网 `IPv6` `CIDR`。
      */
    CidrBlock: string;
    /**
      * `IPv6`类型。
      */
    Ipv6AddressType: string;
    /**
      * `IPv6`申请时间。
      */
    CreatedTime: string;
}
/**
 * AssignIpv6Addresses请求参数结构体
 */
export interface AssignIpv6AddressesRequest {
    /**
      * 弹性网卡实例`ID`，形如：`eni-m6dyj72l`。
      */
    NetworkInterfaceId: string;
    /**
      * 指定的`IPv6`地址列表，单次最多指定10个。与入参`Ipv6AddressCount`合并计算配额。与Ipv6AddressCount必填一个。
      */
    Ipv6Addresses?: Array<Ipv6Address>;
    /**
      * 自动分配`IPv6`地址个数，内网IP地址个数总和不能超过配数。与入参`Ipv6Addresses`合并计算配额。与Ipv6Addresses必填一个。
      */
    Ipv6AddressCount?: number;
}
/**
 * CreateServiceTemplateGroup返回参数结构体
 */
export interface CreateServiceTemplateGroupResponse {
    /**
      * 协议端口模板集合对象。
      */
    ServiceTemplateGroup?: ServiceTemplateGroup;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 网络探测对象。
 */
export interface NetDetect {
    /**
      * `VPC`实例`ID`。形如：`vpc-12345678`
      */
    VpcId: string;
    /**
      * `VPC`实例名称。
      */
    VpcName: string;
    /**
      * 子网实例ID。形如：subnet-12345678。
      */
    SubnetId: string;
    /**
      * 子网实例名称。
      */
    SubnetName: string;
    /**
      * 网络探测实例ID。形如：netd-12345678。
      */
    NetDetectId: string;
    /**
      * 网络探测名称，最大长度不能超过60个字节。
      */
    NetDetectName: string;
    /**
      * 探测目的IPv4地址数组，最多两个。
      */
    DetectDestinationIp: Array<string>;
    /**
      * 系统自动分配的探测源IPv4数组。长度为2。
      */
    DetectSourceIp: Array<string>;
    /**
      * 下一跳类型，目前我们支持的类型有：
VPN：VPN网关；
DIRECTCONNECT：专线网关；
PEERCONNECTION：对等连接；
NAT：NAT网关；
NORMAL_CVM：普通云服务器；
CCN：云联网网关；
      */
    NextHopType: string;
    /**
      * 下一跳目的网关，取值与“下一跳类型”相关：
下一跳类型为VPN，取值VPN网关ID，形如：vpngw-12345678；
下一跳类型为DIRECTCONNECT，取值专线网关ID，形如：dcg-12345678；
下一跳类型为PEERCONNECTION，取值对等连接ID，形如：pcx-12345678；
下一跳类型为NAT，取值Nat网关，形如：nat-12345678；
下一跳类型为NORMAL_CVM，取值云服务器IPv4地址，形如：10.0.0.12；
下一跳类型为CCN，取值云联网网关，形如：ccn-12345678；
      */
    NextHopDestination: string;
    /**
      * 下一跳网关名称。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NextHopName: string;
    /**
      * 网络探测描述。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NetDetectDescription: string;
    /**
      * 创建时间。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CreateTime: string;
}
/**
 * 修改VPN状态参数
 */
export interface VpnGatewayRouteModify {
    /**
      * Vpn网关路由ID
      */
    RouteId: string;
    /**
      * Vpn网关状态, ENABEL 启用, DISABLE禁用
      */
    Status: string;
}
/**
 * 模板对象成员信息
 */
export interface MemberInfo {
    /**
      * 模板对象成员
      */
    Member: string;
    /**
      * 模板对象成员描述信息
      */
    Description?: string;
}
/**
 * ReplaceSecurityGroupPolicy请求参数结构体
 */
export interface ReplaceSecurityGroupPolicyRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 安全组规则集合对象。
      */
    SecurityGroupPolicySet: SecurityGroupPolicySet;
    /**
      * 旧的安全组规则集合对象，可选，日志记录用。
      */
    OriginalSecurityGroupPolicySet?: SecurityGroupPolicySet;
}
/**
 * ModifyVpcEndPointServiceAttribute返回参数结构体
 */
export interface ModifyVpcEndPointServiceAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * VPC资源看板（各资源个数）
 */
export interface ResourceDashboard {
    /**
      * Vpc实例ID，例如：vpc-bq4bzxpj。
      */
    VpcId: string;
    /**
      * 子网实例ID，例如：subnet-bthucmmy。
      */
    SubnetId: string;
    /**
      * 基础网络互通。
      */
    Classiclink: number;
    /**
      * 专线网关。
      */
    Dcg: number;
    /**
      * 对等连接。
      */
    Pcx: number;
    /**
      * 统计当前除云服务器 IP、弹性网卡IP和网络探测IP以外的所有已使用的IP总数。云服务器 IP、弹性网卡IP和网络探测IP单独计数。
      */
    Ip: number;
    /**
      * NAT网关。
      */
    Nat: number;
    /**
      * VPN网关。
      */
    Vpngw: number;
    /**
      * 流日志。
      */
    FlowLog: number;
    /**
      * 网络探测。
      */
    NetworkDetect: number;
    /**
      * 网络ACL。
      */
    NetworkACL: number;
    /**
      * 云主机。
      */
    CVM: number;
    /**
      * 负载均衡。
      */
    LB: number;
    /**
      * 关系型数据库。
      */
    CDB: number;
    /**
      * 云数据库 TencentDB for Memcached。
      */
    Cmem: number;
    /**
      * 时序数据库。
      */
    CTSDB: number;
    /**
      * 数据库 TencentDB for MariaDB（TDSQL）。
      */
    MariaDB: number;
    /**
      * 数据库 TencentDB for SQL Server。
      */
    SQLServer: number;
    /**
      * 云数据库 TencentDB for PostgreSQL。
      */
    Postgres: number;
    /**
      * 网络附加存储。
      */
    NAS: number;
    /**
      * Snova云数据仓库。
      */
    Greenplumn: number;
    /**
      * 消息队列 CKAFKA。
      */
    Ckafka: number;
    /**
      * Grocery。
      */
    Grocery: number;
    /**
      * 数据加密服务。
      */
    HSM: number;
    /**
      * 游戏存储 Tcaplus。
      */
    Tcaplus: number;
    /**
      * Cnas。
      */
    Cnas: number;
    /**
      * HTAP 数据库 TiDB。
      */
    TiDB: number;
    /**
      * EMR 集群。
      */
    Emr: number;
    /**
      * SEAL。
      */
    SEAL: number;
    /**
      * 文件存储 CFS。
      */
    CFS: number;
    /**
      * Oracle。
      */
    Oracle: number;
    /**
      * ElasticSearch服务。
      */
    ElasticSearch: number;
    /**
      * 区块链服务。
      */
    TBaaS: number;
    /**
      * Itop。
      */
    Itop: number;
    /**
      * 云数据库审计。
      */
    DBAudit: number;
    /**
      * 企业级云数据库 CynosDB for Postgres。
      */
    CynosDBPostgres: number;
    /**
      * 数据库 TencentDB for Redis。
      */
    Redis: number;
    /**
      * 数据库 TencentDB for MongoDB。
      */
    MongoDB: number;
    /**
      * 分布式数据库 TencentDB for TDSQL。
      */
    DCDB: number;
    /**
      * 企业级云数据库 CynosDB for MySQL。
      */
    CynosDBMySQL: number;
    /**
      * 子网。
      */
    Subnet: number;
    /**
      * 路由表。
      */
    RouteTable: number;
}
/**
 * DescribeCcnAttachedInstances返回参数结构体
 */
export interface DescribeCcnAttachedInstancesResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount: number;
    /**
      * 关联实例列表。
      */
    InstanceSet: Array<CcnAttachedInstance>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * HaVipAssociateAddressIp返回参数结构体
 */
export interface HaVipAssociateAddressIpResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteCustomerGateway返回参数结构体
 */
export interface DeleteCustomerGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpnGatewayRoutes返回参数结构体
 */
export interface CreateVpnGatewayRoutesResponse {
    /**
      * VPN网关目的路由
      */
    Routes: Array<VpnGatewayRoute>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateNetDetect请求参数结构体
 */
export interface CreateNetDetectRequest {
    /**
      * `VPC`实例`ID`。形如：`vpc-12345678`
      */
    VpcId: string;
    /**
      * 子网实例ID。形如：subnet-12345678。
      */
    SubnetId: string;
    /**
      * 网络探测名称，最大长度不能超过60个字节。
      */
    NetDetectName: string;
    /**
      * 探测目的IPv4地址数组。最多两个。
      */
    DetectDestinationIp: Array<string>;
    /**
      * 下一跳类型，目前我们支持的类型有：
VPN：VPN网关；
DIRECTCONNECT：专线网关；
PEERCONNECTION：对等连接；
NAT：NAT网关；
NORMAL_CVM：普通云服务器；
CCN：云联网网关；
      */
    NextHopType?: string;
    /**
      * 下一跳目的网关，取值与“下一跳类型”相关：
下一跳类型为VPN，取值VPN网关ID，形如：vpngw-12345678；
下一跳类型为DIRECTCONNECT，取值专线网关ID，形如：dcg-12345678；
下一跳类型为PEERCONNECTION，取值对等连接ID，形如：pcx-12345678；
下一跳类型为NAT，取值Nat网关，形如：nat-12345678；
下一跳类型为NORMAL_CVM，取值云服务器IPv4地址，形如：10.0.0.12；
下一跳类型为CCN，取值云联网ID，形如：ccn-12345678；
      */
    NextHopDestination?: string;
    /**
      * 网络探测描述。
      */
    NetDetectDescription?: string;
}
/**
 * CreateAddressTemplate返回参数结构体
 */
export interface CreateAddressTemplateResponse {
    /**
      * IP地址模板对象。
      */
    AddressTemplate: AddressTemplate;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateNatGatewayDestinationIpPortTranslationNatRule返回参数结构体
 */
export interface CreateNatGatewayDestinationIpPortTranslationNatRuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteAddressTemplateGroup请求参数结构体
 */
export interface DeleteAddressTemplateGroupRequest {
    /**
      * IP地址模板集合实例ID，例如：ipmg-90cex8mq。
      */
    AddressTemplateGroupId: string;
}
/**
 * CreateVpnGatewaySslClient返回参数结构体
 */
export interface CreateVpnGatewaySslClientResponse {
    /**
      * 异步任务ID。
      */
    TaskId: number;
    /**
      * SSL-VPN client 唯一ID
      */
    SslVpnClientId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNetworkInterfaceLimit请求参数结构体
 */
export interface DescribeNetworkInterfaceLimitRequest {
    /**
      * 要查询的CVM实例ID或弹性网卡ID
      */
    InstanceId: string;
}
/**
 * CreateBandwidthPackage请求参数结构体
 */
export interface CreateBandwidthPackageRequest {
    /**
      * 带宽包类型, 默认值: BGP, 可选值:
<li>BGP: 普通BGP共享带宽包</li>
<li>HIGH_QUALITY_BGP: 精品BGP共享带宽包</li>
      */
    NetworkType?: string;
    /**
      * 带宽包计费类型, 默认为: TOP5_POSTPAID_BY_MONTH, 可选值:
<li>TOP5_POSTPAID_BY_MONTH: 按月后付费TOP5计费</li>
<li>PERCENT95_POSTPAID_BY_MONTH: 按月后付费月95计费</li>
<li>FIXED_PREPAID_BY_MONTH: 包月预付费计费</li>
      */
    ChargeType?: string;
    /**
      * 带宽包名称。
      */
    BandwidthPackageName?: string;
    /**
      * 带宽包数量(传统账户类型只能填1), 标准账户类型取值范围为1~20。
      */
    BandwidthPackageCount?: number;
    /**
      * 带宽包限速大小。单位：Mbps，-1表示不限速。该功能当前内测中，暂不对外开放。
      */
    InternetMaxBandwidth?: number;
    /**
      * 需要关联的标签列表。
      */
    Tags?: Array<Tag>;
    /**
      * 带宽包协议类型。当前支持'ipv4'和'ipv6'协议带宽包，默认值是'ipv4'。
      */
    Protocol?: string;
}
/**
 * DescribeIp6Addresses返回参数结构体
 */
export interface DescribeIp6AddressesResponse {
    /**
      * 符合条件的 IPV6 数量。
      */
    TotalCount?: number;
    /**
      * IPV6 详细信息列表。
      */
    AddressSet?: Array<Address>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyRouteTableAttribute请求参数结构体
 */
export interface ModifyRouteTableAttributeRequest {
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
    /**
      * 路由表名称。
      */
    RouteTableName: string;
}
/**
 * ModifyDirectConnectGatewayAttribute返回参数结构体
 */
export interface ModifyDirectConnectGatewayAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpnGateways请求参数结构体
 */
export interface DescribeVpnGatewaysRequest {
    /**
      * VPN网关实例ID。形如：vpngw-f49l6u0z。每次请求的实例的上限为100。参数不支持同时指定VpnGatewayIds和Filters。
      */
    VpnGatewayIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定VpnGatewayIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID形如：vpc-f49l6u0z。</li>
<li>vpn-gateway-id - String - （过滤条件）VPN实例ID形如：vpngw-5aluhh9t。</li>
<li>vpn-gateway-name - String - （过滤条件）VPN实例名称。</li>
<li>type - String - （过滤条件）VPN网关类型：'IPSEC', 'SSL'。</li>
<li>public-ip-address- String - （过滤条件）公网IP。</li>
<li>renew-flag - String - （过滤条件）网关续费类型，手动续费：'NOTIFY_AND_MANUAL_RENEW'、自动续费：'NOTIFY_AND_AUTO_RENEW'。</li>
<li>zone - String - （过滤条件）VPN所在可用区，形如：ap-guangzhou-2。</li>
      */
    Filters?: Array<FilterObject>;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 请求对象个数
      */
    Limit?: number;
}
/**
 * 网络探测目的IP的验证结果。
 */
export interface NetDetectIpState {
    /**
      * 探测目的IPv4地址。
      */
    DetectDestinationIp: string;
    /**
      * 探测结果。
0：成功；
-1：查询不到路由丢包；
-2：外出ACL丢包；
-3：IN ACL丢包；
-4：其他错误；
      */
    State: number;
    /**
      * 时延，单位毫秒
      */
    Delay: number;
    /**
      * 丢包率
      */
    PacketLossRate: number;
}
/**
 * ModifyIp6AddressesBandwidth返回参数结构体
 */
export interface ModifyIp6AddressesBandwidthResponse {
    /**
      * 任务ID
      */
    TaskId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateSubnets请求参数结构体
 */
export interface CreateSubnetsRequest {
    /**
      * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
      */
    VpcId: string;
    /**
      * 子网对象列表。
      */
    Subnets: Array<SubnetInput>;
    /**
      * 指定绑定的标签列表，注意这里的标签集合为列表中所有子网对象所共享，不能为每个子网对象单独指定标签，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * 需要增加到的CDC实例ID。
      */
    CdcId?: string;
}
/**
 * DescribeVpcEndPointService请求参数结构体
 */
export interface DescribeVpcEndPointServiceRequest {
    /**
      * 过滤条件。
<li> service-id- String - （过滤条件）终端节点服务唯一ID。</li>
<li>service-name - String - （过滤条件）终端节点实例名称。</li>
<li>service-instance-id - String - （过滤条件）后端服务的唯一ID，比如lb-xxx。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 单页返回数量，默认为20，最大值为100。
      */
    Limit?: number;
    /**
      * 终端节点服务ID。
      */
    EndPointServiceIds?: Array<string>;
}
/**
 * ModifyServiceTemplateAttribute请求参数结构体
 */
export interface ModifyServiceTemplateAttributeRequest {
    /**
      * 协议端口模板实例ID，例如：ppm-529nwwj8。
      */
    ServiceTemplateId: string;
    /**
      * 协议端口模板名称。
      */
    ServiceTemplateName?: string;
    /**
      * 支持单个端口、多个端口、连续端口及所有端口，协议支持：TCP、UDP、ICMP、GRE 协议。
      */
    Services?: Array<string>;
    /**
      * 支持添加备注的协议端口信息，支持单个端口、多个端口、连续端口及所有端口，协议支持：TCP、UDP、ICMP、GRE 协议。
      */
    ServicesExtra?: Array<ServicesInfo>;
}
/**
 * AssociateAddress返回参数结构体
 */
export interface AssociateAddressResponse {
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyCcnAttachedInstancesAttribute返回参数结构体
 */
export interface ModifyCcnAttachedInstancesAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateNetworkAcl请求参数结构体
 */
export interface CreateNetworkAclRequest {
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * 网络ACL名称，最大长度不能超过60个字节。
      */
    NetworkAclName: string;
}
/**
 * DescribeAddresses请求参数结构体
 */
export interface DescribeAddressesRequest {
    /**
      * 标识 EIP 的唯一 ID 列表。EIP 唯一 ID 形如：`eip-11112222`。参数不支持同时指定`AddressIds`和`Filters.address-id`。
      */
    AddressIds?: Array<string>;
    /**
      * 每次请求的`Filters`的上限为10，`Filter.Values`的上限为100。详细的过滤条件如下：
<li> address-id - String - 是否必填：否 - （过滤条件）按照 EIP 的唯一 ID 过滤。EIP 唯一 ID 形如：eip-11112222。</li>
<li> address-name - String - 是否必填：否 - （过滤条件）按照 EIP 名称过滤。不支持模糊过滤。</li>
<li> address-ip - String - 是否必填：否 - （过滤条件）按照 EIP 的 IP 地址过滤。</li>
<li> address-status - String - 是否必填：否 - （过滤条件）按照 EIP 的状态过滤。状态包含：'CREATING'，'BINDING'，'BIND'，'UNBINDING'，'UNBIND'，'OFFLINING'，'BIND_ENI'。</li>
<li> instance-id - String - 是否必填：否 - （过滤条件）按照 EIP 绑定的实例 ID 过滤。实例 ID 形如：ins-11112222。</li>
<li> private-ip-address - String - 是否必填：否 - （过滤条件）按照 EIP 绑定的内网 IP 过滤。</li>
<li> network-interface-id - String - 是否必填：否 - （过滤条件）按照 EIP 绑定的弹性网卡 ID 过滤。弹性网卡 ID 形如：eni-11112222。</li>
<li> is-arrears - String - 是否必填：否 - （过滤条件）按照 EIP 是否欠费进行过滤。（TRUE：EIP 处于欠费状态|FALSE：EIP 费用状态正常）</li>
<li> address-type - String - 是否必填：否 - （过滤条件）按照 IP类型 进行过滤。可选值：'WanIP', 'EIP'，'AnycastEIP'，'HighQualityEIP'。默认值是'EIP'。</li>
<li> address-isp - String - 是否必填：否 - （过滤条件）按照 运营商类型 进行过滤。可选值：'BGP'，'CMCC'，'CUCC', 'CTCC'</li>
<li> dedicated-cluster-id - String - 是否必填：否 - （过滤条件）按照 CDC 的唯一 ID 过滤。CDC 唯一 ID 形如：cluster-11112222。</li>
<li> tag-key - String - 是否必填：否 - （过滤条件）按照标签键进行过滤。</li>
<li> tag-value - String - 是否必填：否 - （过滤条件）按照标签值进行过滤。</li>
<li> tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。tag-key使用具体的标签键进行替换。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于`Offset`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/11646)中的相关小节。
      */
    Limit?: number;
}
/**
 * DescribeSecurityGroupPolicies请求参数结构体
 */
export interface DescribeSecurityGroupPoliciesRequest {
    /**
      * 安全组实例ID，例如：sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 过滤条件,不支持同时指定SecurityGroupId和Filters参数。
<li>security-group-id - String - 安全组ID。</li>
<li>ip - String - IP，支持IPV4和IPV6模糊匹配。</li>
<li>address-module - String - IP地址模板或IP地址组模板ID。</li>
<li>service-module - String - 协议端口模板或协议端口组模板ID。</li>
<li>protocol-type - String - 安全组策略支持的协议，可选值：`TCP`, `UDP`, `ICMP`, `ICMPV6`, `GRE`, `ALL`。</li>
<li>port - String - 是否必填：否 -协议端口，支持模糊匹配，值为`ALL`时，查询所有的端口。</li>
<li>poly - String - 协议策略，可选值：`ALL`，所有策略；`ACCEPT`，允许；`DROP`，拒绝。</li>
<li>direction - String - 协议规则，可选值：`ALL`，所有策略；`INBOUND`，入站规则；`OUTBOUND`，出站规则。</li>
<li>description - String - 协议描述，该过滤条件支持模糊匹配。</li>
      */
    Filters?: Array<Filter>;
}
/**
 * ModifyNetworkInterfaceAttribute返回参数结构体
 */
export interface ModifyNetworkInterfaceAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateSecurityGroup返回参数结构体
 */
export interface CreateSecurityGroupResponse {
    /**
      * 安全组对象。
      */
    SecurityGroup?: SecurityGroup;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateNetworkInterfaceSecurityGroups返回参数结构体
 */
export interface DisassociateNetworkInterfaceSecurityGroupsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcs返回参数结构体
 */
export interface DescribeVpcsResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount: number;
    /**
      * VPC对象。
      */
    VpcSet: Array<Vpc>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNetworkInterfaceLimit返回参数结构体
 */
export interface DescribeNetworkInterfaceLimitResponse {
    /**
      * 标准型弹性网卡配额
      */
    EniQuantity: number;
    /**
      * 每个标准型弹性网卡可以分配的IP配额
      */
    EniPrivateIpAddressQuantity: number;
    /**
      * 扩展型网卡配额
注意：此字段可能返回 null，表示取不到有效值。
      */
    ExtendEniQuantity: number;
    /**
      * 每个扩展型弹性网卡可以分配的IP配额
注意：此字段可能返回 null，表示取不到有效值。
      */
    ExtendEniPrivateIpAddressQuantity: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssignIpv6CidrBlock返回参数结构体
 */
export interface AssignIpv6CidrBlockResponse {
    /**
      * 分配的 `IPv6` 网段。形如：`3402:4e00:20:1000::/56`
      */
    Ipv6CidrBlock?: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateCcn请求参数结构体
 */
export interface CreateCcnRequest {
    /**
      * CCN名称，最大长度不能超过60个字节。
      */
    CcnName: string;
    /**
      * CCN描述信息，最大长度不能超过100个字节。
      */
    CcnDescription?: string;
    /**
      * CCN服务质量，'PT'：白金，'AU'：金，'AG'：银，默认为‘AU’。
      */
    QosLevel?: string;
    /**
      * 计费模式，PREPAID：表示预付费，即包年包月，POSTPAID：表示后付费，即按量计费。默认：POSTPAID。
      */
    InstanceChargeType?: string;
    /**
      * 限速类型，OUTER_REGION_LIMIT表示地域出口限速，INTER_REGION_LIMIT为地域间限速，默认为OUTER_REGION_LIMIT。预付费模式仅支持地域间限速，后付费模式支持地域间限速和地域出口限速。
      */
    BandwidthLimitType?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
}
/**
 * DeleteTemplateMember返回参数结构体
 */
export interface DeleteTemplateMemberResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNatGatewaySourceIpTranslationNatRule请求参数结构体
 */
export interface ModifyNatGatewaySourceIpTranslationNatRuleRequest {
    /**
      * NAT网关的ID，形如：`nat-df453454`。
      */
    NatGatewayId: string;
    /**
      * NAT网关的SNAT转换规则。
      */
    SourceIpTranslationNatRule: SourceIpTranslationNatRule;
}
/**
 * RemoveIp6Rules请求参数结构体
 */
export interface RemoveIp6RulesRequest {
    /**
      * IPV6转换规则所属的转换实例唯一ID，形如ip6-xxxxxxxx
      */
    Ip6TranslatorId: string;
    /**
      * 待删除IPV6转换规则，形如rule6-xxxxxxxx
      */
    Ip6RuleIds: Array<string>;
}
/**
 * DescribeIpGeolocationDatabaseUrl请求参数结构体
 */
export interface DescribeIpGeolocationDatabaseUrlRequest {
    /**
      * IP地理位置库协议类型，目前仅支持"ipv4"。
      */
    Type: string;
}
/**
 * DescribeVpcEndPoint返回参数结构体
 */
export interface DescribeVpcEndPointResponse {
    /**
      * 终端节点对象。
      */
    EndPointSet: Array<EndPoint>;
    /**
      * 符合查询条件的终端节点个数。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisableGatewayFlowMonitor请求参数结构体
 */
export interface DisableGatewayFlowMonitorRequest {
    /**
      * 网关实例ID，目前我们支持的网关实例类型有，
专线网关实例ID，形如，`dcg-ltjahce6`；
Nat网关实例ID，形如，`nat-ltjahce6`；
VPN网关实例ID，形如，`vpn-ltjahce6`。
      */
    GatewayId: string;
}
/**
 * EnableRoutes返回参数结构体
 */
export interface EnableRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpnConnection请求参数结构体
 */
export interface DeleteVpnConnectionRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * VPN通道实例ID。形如：vpnx-f49l6u0z。
      */
    VpnConnectionId: string;
}
/**
 * 网络ACL规则。
 */
export interface NetworkAclEntry {
    /**
      * 修改时间。
      */
    ModifyTime: string;
    /**
      * 协议, 取值: TCP,UDP, ICMP, ALL。
      */
    Protocol?: string;
    /**
      * 端口(all, 单个port,  range)。当Protocol为ALL或ICMP时，不能指定Port。
      */
    Port?: string;
    /**
      * 网段或IP(互斥)。
      */
    CidrBlock?: string;
    /**
      * 网段或IPv6(互斥)。
      */
    Ipv6CidrBlock?: string;
    /**
      * ACCEPT 或 DROP。
      */
    Action?: string;
    /**
      * 规则描述，最大长度100。
      */
    Description?: string;
}
/**
 * DescribeDhcpIps请求参数结构体
 */
export interface DescribeDhcpIpsRequest {
    /**
      * DhcpIp实例ID。形如：dhcpip-pxir56ns。每次请求的实例的上限为100。参数不支持同时指定DhcpIpIds和Filters。
      */
    DhcpIpIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定DhcpIpIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-f49l6u0z。</li>
<li>subnet-id - String - （过滤条件）所属子网实例ID，形如：subnet-f49l6u0z。</li>
<li>dhcpip-id - String - （过滤条件）DhcpIp实例ID，形如：dhcpip-pxir56ns。</li>
<li>dhcpip-name - String - （过滤条件）DhcpIp实例名称。</li>
<li>address-ip - String - （过滤条件）DhcpIp实例的IP，根据IP精确查找。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * DescribeAssistantCidr请求参数结构体
 */
export interface DescribeAssistantCidrRequest {
    /**
      * `VPC`实例`ID`数组。形如：[`vpc-6v2ht8q5`]
      */
    VpcIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定VpcIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-f49l6u0z。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * RenewVpnGateway返回参数结构体
 */
export interface RenewVpnGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteDirectConnectGateway返回参数结构体
 */
export interface DeleteDirectConnectGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyAddressesBandwidth请求参数结构体
 */
export interface ModifyAddressesBandwidthRequest {
    /**
      * EIP唯一标识ID列表，形如'eip-xxxx'
      */
    AddressIds: Array<string>;
    /**
      * 调整带宽目标值
      */
    InternetMaxBandwidthOut: number;
    /**
      * 包月带宽起始时间(已废弃，输入无效)
      */
    StartTime?: string;
    /**
      * 包月带宽结束时间(已废弃，输入无效)
      */
    EndTime?: string;
}
/**
 * ResetVpnGatewayInternetMaxBandwidth请求参数结构体
 */
export interface ResetVpnGatewayInternetMaxBandwidthRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * 公网带宽设置。可选带宽规格：5, 10, 20, 50, 100；单位：Mbps。
      */
    InternetMaxBandwidthOut: number;
}
/**
 * 终端节点详情。
 */
export interface EndPoint {
    /**
      * 终端节点ID。
      */
    EndPointId: string;
    /**
      * VPCID。
      */
    VpcId: string;
    /**
      * 子网ID。
      */
    SubnetId: string;
    /**
      * APPID。
      */
    EndPointOwner: string;
    /**
      * 终端节点名称。
      */
    EndPointName: string;
    /**
      * 终端节点服务的VPCID。
      */
    ServiceVpcId: string;
    /**
      * 终端节点服务的VIP。
      */
    ServiceVip: string;
    /**
      * 终端节点服务的ID。
      */
    EndPointServiceId: string;
    /**
      * 终端节点的VIP。
      */
    EndPointVip: string;
    /**
      * 终端节点状态，ACTIVE：可用，PENDING：待接受，ACCEPTING：接受中，REJECTED：已拒绝，FAILED：失败。
      */
    State: string;
    /**
      * 创建时间。
      */
    CreateTime: string;
    /**
      * 终端节点绑定的安全组实例ID列表。
      */
    GroupSet: Array<string>;
    /**
      * 终端节点服务名称。
注意：此字段可能返回 null，表示取不到有效值。
      */
    ServiceName: string;
}
/**
 * 专线网关对象。
 */
export interface DirectConnectGateway {
    /**
      * 专线网关`ID`。
      */
    DirectConnectGatewayId: string;
    /**
      * 专线网关名称。
      */
    DirectConnectGatewayName: string;
    /**
      * 专线网关关联`VPC`实例`ID`。
      */
    VpcId: string;
    /**
      * 关联网络类型：
<li>`VPC` - 私有网络</li>
<li>`CCN` - 云联网</li>
      */
    NetworkType: string;
    /**
      * 关联网络实例`ID`：
<li>`NetworkType`为`VPC`时，这里为私有网络实例`ID`</li>
<li>`NetworkType`为`CCN`时，这里为云联网实例`ID`</li>
      */
    NetworkInstanceId: string;
    /**
      * 网关类型：
<li>NORMAL - 标准型，注：云联网只支持标准型</li>
<li>NAT - NAT型</li>
NAT类型支持网络地址转换配置，类型确定后不能修改；一个私有网络可以创建一个NAT类型的专线网关和一个非NAT类型的专线网关
      */
    GatewayType: string;
    /**
      * 创建时间。
      */
    CreateTime: string;
    /**
      * 专线网关IP。
      */
    DirectConnectGatewayIp: string;
    /**
      * 专线网关关联`CCN`实例`ID`。
      */
    CcnId: string;
    /**
      * 云联网路由学习类型：
<li>`BGP` - 自动学习。</li>
<li>`STATIC` - 静态，即用户配置。</li>
      */
    CcnRouteType: string;
    /**
      * 是否启用BGP。
      */
    EnableBGP: boolean;
    /**
      * 开启和关闭BGP的community属性。
      */
    EnableBGPCommunity: boolean;
    /**
      * 绑定的NAT网关ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NatGatewayId: string;
    /**
      * 专线网关是否支持VXLAN架构
注意：此字段可能返回 null，表示取不到有效值。
      */
    VXLANSupport: Array<boolean>;
    /**
      * 云联网路由发布模式：`standard`（标准模式）、`exquisite`（精细模式）。
注意：此字段可能返回 null，表示取不到有效值。
      */
    ModeType: string;
    /**
      * 是否为localZone专线网关。
注意：此字段可能返回 null，表示取不到有效值。
      */
    LocalZone: boolean;
    /**
      * 专线网关所在可用区
注意：此字段可能返回 null，表示取不到有效值。
      */
    Zone: string;
    /**
      * 网关流控明细启用状态：
0：关闭
1：开启
注意：此字段可能返回 null，表示取不到有效值。
      */
    EnableFlowDetails: number;
    /**
      * 开启、关闭网关流控明细时间
注意：此字段可能返回 null，表示取不到有效值。
      */
    FlowDetailsUpdateTime: string;
    /**
      * 是否支持开启网关流控明细
0：不支持
1：支持
注意：此字段可能返回 null，表示取不到有效值。
      */
    NewAfc: number;
    /**
      * 专线网关接入网络类型：
<li>`VXLAN` - VXLAN类型。</li>
<li>`MPLS` - MPLS类型。</li>
<li>`Hybrid` - Hybrid类型。</li>
注意：此字段可能返回 null，表示取不到有效值。
      */
    AccessNetworkType: string;
    /**
      * 跨可用区容灾专线网关的可用区列表
注意：此字段可能返回 null，表示取不到有效值。
      */
    HaZoneList: Array<string>;
}
/**
 * DescribeProductQuota返回参数结构体
 */
export interface DescribeProductQuotaResponse {
    /**
      * ProductQuota对象数组
      */
    ProductQuotaSet: Array<ProductQuota>;
    /**
      * 符合条件的产品类型个数
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 价格
 */
export interface Price {
    /**
      * 实例价格。
      */
    InstancePrice?: ItemPrice;
    /**
      * 网络价格。
      */
    BandwidthPrice?: ItemPrice;
}
/**
 * HaVipDisassociateAddressIp请求参数结构体
 */
export interface HaVipDisassociateAddressIpRequest {
    /**
      * `HAVIP`唯一`ID`，形如：`havip-9o233uri`。必须是已绑定`EIP`的`HAVIP`。
      */
    HaVipId: string;
}
/**
 * DisableFlowLogs返回参数结构体
 */
export interface DisableFlowLogsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeBandwidthPackageResources返回参数结构体
 */
export interface DescribeBandwidthPackageResourcesResponse {
    /**
      * 符合条件的 共享带宽包内资源 数量。
      */
    TotalCount: number;
    /**
      * 共享带宽包内资源 详细信息列表。
      */
    ResourceSet: Array<Resource>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCrossBorderCompliance返回参数结构体
 */
export interface DescribeCrossBorderComplianceResponse {
    /**
      * 合规化审批单列表。
      */
    CrossBorderComplianceSet: Array<CrossBorderCompliance>;
    /**
      * 合规化审批单总数。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpnGatewayAttribute返回参数结构体
 */
export interface ModifyVpnGatewayAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssociateDirectConnectGatewayNatGateway返回参数结构体
 */
export interface AssociateDirectConnectGatewayNatGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 终端节点服务对象。
 */
export interface EndPointService {
    /**
      * 终端节点服务ID
      */
    EndPointServiceId: string;
    /**
      * VPCID。
      */
    VpcId: string;
    /**
      * APPID。
      */
    ServiceOwner: string;
    /**
      * 终端节点服务名称。
      */
    ServiceName: string;
    /**
      * 后端服务的VIP。
      */
    ServiceVip: string;
    /**
      * 后端服务的ID，比如lb-xxx。
      */
    ServiceInstanceId: string;
    /**
      * 是否自动接受。
      */
    AutoAcceptFlag: boolean;
    /**
      * 关联的终端节点个数。
注意：此字段可能返回 null，表示取不到有效值。
      */
    EndPointCount: number;
    /**
      * 终端节点对象数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    EndPointSet: Array<EndPoint>;
    /**
      * 创建时间。
      */
    CreateTime: string;
}
/**
 * DescribeVpcResourceDashboard返回参数结构体
 */
export interface DescribeVpcResourceDashboardResponse {
    /**
      * 资源对象列表。
      */
    ResourceDashboardSet?: Array<ResourceDashboard>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpnGatewayCcnRoutes请求参数结构体
 */
export interface DescribeVpnGatewayCcnRoutesRequest {
    /**
      * VPN网关实例ID
      */
    VpnGatewayId: string;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
}
/**
 * DisassociateDirectConnectGatewayNatGateway返回参数结构体
 */
export interface DisassociateDirectConnectGatewayNatGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateServiceTemplateGroup请求参数结构体
 */
export interface CreateServiceTemplateGroupRequest {
    /**
      * 协议端口模板集合名称
      */
    ServiceTemplateGroupName: string;
    /**
      * 协议端口模板实例ID，例如：ppm-4dw6agho。
      */
    ServiceTemplateIds: Array<string>;
}
/**
 * DescribeClassicLinkInstances返回参数结构体
 */
export interface DescribeClassicLinkInstancesResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 私有网络和基础网络互通设备。
      */
    ClassicLinkInstanceSet: Array<ClassicLinkInstance>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * EnableVpnGatewaySslClientCert请求参数结构体
 */
export interface EnableVpnGatewaySslClientCertRequest {
    /**
      * SSL-VPN-CLIENT 实例ID。
      */
    SslVpnClientId: string;
}
/**
 * DescribeVpnGatewayCcnRoutes返回参数结构体
 */
export interface DescribeVpnGatewayCcnRoutesResponse {
    /**
      * 云联网路由（IDC网段）列表。
      */
    RouteSet?: Array<VpngwCcnRoutes>;
    /**
      * 符合条件的对象数。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DetachCcnInstances请求参数结构体
 */
export interface DetachCcnInstancesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 要解关联网络实例列表
      */
    Instances: Array<CcnInstance>;
}
/**
 * ModifyVpcEndPointServiceWhiteList请求参数结构体
 */
export interface ModifyVpcEndPointServiceWhiteListRequest {
    /**
      * 用户UIN。
      */
    UserUin: string;
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
    /**
      * 白名单描述信息。
      */
    Description?: string;
}
/**
 * DescribeTenantCcns返回参数结构体
 */
export interface DescribeTenantCcnsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 过滤器
 */
export interface Filter {
    /**
      * 属性名称, 若存在多个Filter时，Filter间的关系为逻辑与（AND）关系。
      */
    Name: string;
    /**
      * 属性值, 若同一个Filter存在多个Values，同一Filter下Values间的关系为逻辑或（OR）关系。
      */
    Values: Array<string>;
}
/**
 * MigrateNetworkInterface返回参数结构体
 */
export interface MigrateNetworkInterfaceResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteDirectConnectGateway请求参数结构体
 */
export interface DeleteDirectConnectGatewayRequest {
    /**
      * 专线网关唯一`ID`，形如：`dcg-9o233uri`。
      */
    DirectConnectGatewayId: string;
}
/**
 * CreateNatGatewaySourceIpTranslationNatRule返回参数结构体
 */
export interface CreateNatGatewaySourceIpTranslationNatRuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNatGatewaySourceIpTranslationNatRule返回参数结构体
 */
export interface DeleteNatGatewaySourceIpTranslationNatRuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 云联网（CCN）关联实例（Instance）对象
 */
export interface CcnAttachedInstance {
    /**
      * 云联网实例ID。
      */
    CcnId: string;
    /**
      * 关联实例类型：
<li>`VPC`：私有网络</li>
<li>`DIRECTCONNECT`：专线网关</li>
<li>`BMVPC`：黑石私有网络</li>
      */
    InstanceType: string;
    /**
      * 关联实例ID。
      */
    InstanceId: string;
    /**
      * 关联实例名称。
      */
    InstanceName: string;
    /**
      * 关联实例所属大区，例如：ap-guangzhou。
      */
    InstanceRegion: string;
    /**
      * 关联实例所属UIN（根账号）。
      */
    InstanceUin: string;
    /**
      * 关联实例CIDR。
      */
    CidrBlock: Array<string>;
    /**
      * 关联实例状态：
<li>`PENDING`：申请中</li>
<li>`ACTIVE`：已连接</li>
<li>`EXPIRED`：已过期</li>
<li>`REJECTED`：已拒绝</li>
<li>`DELETED`：已删除</li>
<li>`FAILED`：失败的（2小时后将异步强制解关联）</li>
<li>`ATTACHING`：关联中</li>
<li>`DETACHING`：解关联中</li>
<li>`DETACHFAILED`：解关联失败（2小时后将异步强制解关联）</li>
      */
    State: string;
    /**
      * 关联时间。
      */
    AttachedTime: string;
    /**
      * 云联网所属UIN（根账号）。
      */
    CcnUin: string;
    /**
      * 关联实例所属的大地域，如: CHINA_MAINLAND
      */
    InstanceArea: string;
    /**
      * 备注
      */
    Description: string;
    /**
      * 路由表ID
注意：此字段可能返回 null，表示取不到有效值。
      */
    RouteTableId: string;
    /**
      * 路由表名称
注意：此字段可能返回 null，表示取不到有效值。
      */
    RouteTableName: string;
}
/**
 * SecurityPolicyDatabase策略
 */
export interface SecurityPolicyDatabase {
    /**
      * 本端网段
      */
    LocalCidrBlock: string;
    /**
      * 对端网段
      */
    RemoteCidrBlock: Array<string>;
}
/**
 * ResetVpnConnection返回参数结构体
 */
export interface ResetVpnConnectionResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpcEndPointService请求参数结构体
 */
export interface CreateVpcEndPointServiceRequest {
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 终端节点服务名称。
      */
    EndPointServiceName: string;
    /**
      * 是否自动接受。
      */
    AutoAcceptFlag: boolean;
    /**
      * 后端服务ID，比如lb-xxx。
      */
    ServiceInstanceId: string;
    /**
      * 是否是PassService类型。
      */
    IsPassService?: boolean;
}
/**
 * `IPv6`地址信息。
 */
export interface Ipv6Address {
    /**
      * `IPv6`地址，形如：`3402:4e00:20:100:0:8cd9:2a67:71f3`
      */
    Address: string;
    /**
      * 是否是主`IP`。
      */
    Primary?: boolean;
    /**
      * `EIP`实例`ID`，形如：`eip-hxlqja90`。
      */
    AddressId?: string;
    /**
      * 描述信息。
      */
    Description?: string;
    /**
      * 公网IP是否被封堵。
      */
    IsWanIpBlocked?: boolean;
    /**
      * `IPv6`地址状态：
<li>`PENDING`：生产中</li>
<li>`MIGRATING`：迁移中</li>
<li>`DELETING`：删除中</li>
<li>`AVAILABLE`：可用的</li>
      */
    State?: string;
}
/**
 * CreateNetworkInterface请求参数结构体
 */
export interface CreateNetworkInterfaceRequest {
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * 弹性网卡名称，最大长度不能超过60个字节。
      */
    NetworkInterfaceName: string;
    /**
      * 弹性网卡所在的子网实例ID，例如：subnet-0ap8nwca。
      */
    SubnetId: string;
    /**
      * 弹性网卡描述，可任意命名，但不得超过60个字符。
      */
    NetworkInterfaceDescription?: string;
    /**
      * 新申请的内网IP地址个数，内网IP地址个数总和不能超过配数。
      */
    SecondaryPrivateIpAddressCount?: number;
    /**
      * 指定绑定的安全组，例如：['sg-1dd51d']。
      */
    SecurityGroupIds?: Array<string>;
    /**
      * 指定的内网IP信息，单次最多指定10个。
      */
    PrivateIpAddresses?: Array<PrivateIpAddressSpecification>;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
}
/**
 * 后付费共享带宽包的当前计费用量
 */
export interface BandwidthPackageBillBandwidth {
    /**
      * 当前计费用量，单位为 Mbps
      */
    BandwidthUsage: number;
}
/**
 * DeleteHaVip返回参数结构体
 */
export interface DeleteHaVipResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeFlowLogs返回参数结构体
 */
export interface DescribeFlowLogsResponse {
    /**
      * 流日志实例集合
      */
    FlowLog: Array<FlowLog>;
    /**
      * 流日志总数目
      */
    TotalNum: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * VPC内网IP对象。
 */
export interface VpcPrivateIpAddress {
    /**
      * `VPC`内网`IP`。
      */
    PrivateIpAddress: string;
    /**
      * 所属子网`CIDR`。
      */
    CidrBlock: string;
    /**
      * 内网`IP`类型。
      */
    PrivateIpAddressType: string;
    /**
      * `IP`申请时间。
      */
    CreatedTime: string;
}
/**
 * 云主机实例信息。
 */
export interface CvmInstance {
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 子网实例ID。
      */
    SubnetId: string;
    /**
      * 云主机实例ID
      */
    InstanceId: string;
    /**
      * 云主机名称。
      */
    InstanceName: string;
    /**
      * 云主机状态。
      */
    InstanceState: string;
    /**
      * 实例的CPU核数，单位：核。
      */
    CPU: number;
    /**
      * 实例内存容量，单位：GB。
      */
    Memory: number;
    /**
      * 创建时间。
      */
    CreatedTime: string;
    /**
      * 实例机型。
      */
    InstanceType: string;
    /**
      * 实例弹性网卡配额（包含主网卡）。
      */
    EniLimit: number;
    /**
      * 实例弹性网卡内网IP配额（包含主网卡）。
      */
    EniIpLimit: number;
    /**
      * 实例已绑定弹性网卡的个数（包含主网卡）。
      */
    InstanceEniCount: number;
}
/**
 * DescribeNetworkAcls请求参数结构体
 */
export interface DescribeNetworkAclsRequest {
    /**
      * 过滤条件，参数不支持同时指定NetworkAclIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-12345678。</li>
<li>network-acl-id - String - （过滤条件）网络ACL实例ID，形如：acl-12345678。</li>
<li>network-acl-name - String - （过滤条件）网络ACL实例名称。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 网络ACL实例ID数组。形如：[acl-12345678]。每次请求的实例的上限为100。参数不支持同时指定NetworkAclIds和Filters。
      */
    NetworkAclIds?: Array<string>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最小值为1，最大值为100。
      */
    Limit?: number;
}
/**
 * DescribeSubnets请求参数结构体
 */
export interface DescribeSubnetsRequest {
    /**
      * 子网实例ID查询。形如：subnet-pxir56ns。每次请求的实例的上限为100。参数不支持同时指定SubnetIds和Filters。
      */
    SubnetIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定SubnetIds和Filters。
<li>subnet-id - String - （过滤条件）Subnet实例名称。</li>
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-f49l6u0z。</li>
<li>cidr-block - String - （过滤条件）子网网段，形如: 192.168.1.0 。</li>
<li>is-default - Boolean - （过滤条件）是否是默认子网。</li>
<li>is-remote-vpc-snat - Boolean - （过滤条件）是否为VPC SNAT地址池子网。</li>
<li>subnet-name - String - （过滤条件）子网名称。</li>
<li>zone - String - （过滤条件）可用区。</li>
<li>tag-key - String -是否必填：否- （过滤条件）按照标签键进行过滤。</li>
<li>tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例2。</li>
<li>cdc-id - String - 是否必填：否 - （过滤条件）按照cdc信息进行过滤。过滤出来制定cdc下的子网。</li>
<li>is-cdc-subnet - String - 是否必填：否 - （过滤条件）按照是否是cdc子网进行过滤。取值：“0”-非cdc子网，“1”--cdc子网</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * CreateSubnet请求参数结构体
 */
export interface CreateSubnetRequest {
    /**
      * 待操作的VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * 子网名称，最大长度不能超过60个字节。
      */
    SubnetName: string;
    /**
      * 子网网段，子网网段必须在VPC网段内，相同VPC内子网网段不能重叠。
      */
    CidrBlock: string;
    /**
      * 子网所在的可用区ID，不同子网选择不同可用区可以做跨可用区灾备。
      */
    Zone: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * CDC实例ID。
      */
    CdcId?: string;
}
/**
 * IP地址模板集合
 */
export interface AddressTemplateGroup {
    /**
      * IP地址模板集合名称。
      */
    AddressTemplateGroupName: string;
    /**
      * IP地址模板集合实例ID，例如：ipmg-dih8xdbq。
      */
    AddressTemplateGroupId: string;
    /**
      * IP地址模板ID。
      */
    AddressTemplateIdSet: Array<string>;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * IP地址模板实例。
      */
    AddressTemplateSet: Array<AddressTemplateItem>;
}
/**
 * DownloadCustomerGatewayConfiguration请求参数结构体
 */
export interface DownloadCustomerGatewayConfigurationRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * VPN通道实例ID。形如：vpnx-f49l6u0z。
      */
    VpnConnectionId: string;
    /**
      * 对端网关厂商信息对象，可通过DescribeCustomerGatewayVendors获取。
      */
    CustomerGatewayVendor: CustomerGatewayVendor;
    /**
      * 通道接入设备物理接口名称。
      */
    InterfaceName: string;
}
/**
 * DeleteBandwidthPackage请求参数结构体
 */
export interface DeleteBandwidthPackageRequest {
    /**
      * 待删除带宽包唯一ID
      */
    BandwidthPackageId: string;
}
/**
 * 描述 HAVIP 信息
 */
export interface HaVip {
    /**
      * `HAVIP`的`ID`，是`HAVIP`的唯一标识。
      */
    HaVipId: string;
    /**
      * `HAVIP`名称。
      */
    HaVipName: string;
    /**
      * 虚拟IP地址。
      */
    Vip: string;
    /**
      * `HAVIP`所在私有网络`ID`。
      */
    VpcId: string;
    /**
      * `HAVIP`所在子网`ID`。
      */
    SubnetId: string;
    /**
      * `HAVIP`关联弹性网卡`ID`。
      */
    NetworkInterfaceId: string;
    /**
      * 被绑定的实例`ID`。
      */
    InstanceId: string;
    /**
      * 绑定`EIP`。
      */
    AddressIp: string;
    /**
      * 状态：
<li>`AVAILABLE`：运行中</li>
<li>`UNBIND`：未绑定</li>
      */
    State: string;
    /**
      * 创建时间。
      */
    CreatedTime: string;
    /**
      * 使用havip的业务标识。
      */
    Business: string;
}
/**
 * ModifyAddressesBandwidth返回参数结构体
 */
export interface ModifyAddressesBandwidthResponse {
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 本地网关信息
 */
export interface LocalGateway {
    /**
      * CDC实例ID
      */
    CdcId: string;
    /**
      * VPC实例ID
      */
    VpcId: string;
    /**
      * 本地网关实例ID
      */
    UniqLocalGwId: string;
    /**
      * 本地网关名称
      */
    LocalGatewayName: string;
    /**
      * 本地网关IP地址
      */
    LocalGwIp: string;
    /**
      * 本地网关创建时间
      */
    CreateTime: string;
}
/**
 * RejectAttachCcnInstances返回参数结构体
 */
export interface RejectAttachCcnInstancesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * SetCcnRegionBandwidthLimits返回参数结构体
 */
export interface SetCcnRegionBandwidthLimitsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeAccountAttributes请求参数结构体
 */
export declare type DescribeAccountAttributesRequest = null;
/**
 * RenewAddresses返回参数结构体
 */
export interface RenewAddressesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCcnRoutes请求参数结构体
 */
export interface DescribeCcnRoutesRequest {
    /**
      * CCN实例ID，形如：ccn-gree226l。
      */
    CcnId: string;
    /**
      * CCN路由策略唯一ID。形如：ccnr-f49l6u0z。
      */
    RouteIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定RouteIds和Filters。
<li>route-id - String -（过滤条件）路由策略ID。</li>
<li>cidr-block - String -（过滤条件）目的端。</li>
<li>instance-type - String -（过滤条件）下一跳类型。</li>
<li>instance-region - String -（过滤条件）下一跳所属地域。</li>
<li>instance-id - String -（过滤条件）下一跳实例ID。</li>
<li>route-table-id - String -（过滤条件）路由表ID列表，形如ccntr-1234edfr，可以根据路由表ID 过滤。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
}
/**
 * ModifyDhcpIpAttribute返回参数结构体
 */
export interface ModifyDhcpIpAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateAndAttachNetworkInterface请求参数结构体
 */
export interface CreateAndAttachNetworkInterfaceRequest {
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * 弹性网卡名称，最大长度不能超过60个字节。
      */
    NetworkInterfaceName: string;
    /**
      * 弹性网卡所在的子网实例ID，例如：subnet-0ap8nwca。
      */
    SubnetId: string;
    /**
      * 云服务器实例ID。
      */
    InstanceId: string;
    /**
      * 指定的内网IP信息，单次最多指定10个。
      */
    PrivateIpAddresses?: Array<PrivateIpAddressSpecification>;
    /**
      * 新申请的内网IP地址个数，内网IP地址个数总和不能超过配数。
      */
    SecondaryPrivateIpAddressCount?: number;
    /**
      * 指定绑定的安全组，例如：['sg-1dd51d']。
      */
    SecurityGroupIds?: Array<string>;
    /**
      * 弹性网卡描述，可任意命名，但不得超过60个字符。
      */
    NetworkInterfaceDescription?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * 绑定类型：0 标准型 1 扩展型。
      */
    AttachType?: number;
}
/**
 * DeleteVpcEndPoint返回参数结构体
 */
export interface DeleteVpcEndPointResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteDhcpIp返回参数结构体
 */
export interface DeleteDhcpIpResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * SSL-VPN-SERVER 信息 SET
 */
export interface SslVpnSever {
    /**
      * VPC实例ID.
注意：此字段可能返回 null，表示取不到有效值。
      */
    VpcId: string;
    /**
      * SSL-VPN-SERVER 实例ID。
      */
    SslVpnServerId: string;
    /**
      * VPN 实例ID。
      */
    VpnGatewayId: string;
    /**
      * SSL-VPN-SERVER name。
      */
    SslVpnServerName: string;
    /**
      * 本端地址段。
      */
    LocalAddress: Array<string>;
    /**
      * 客户端地址段。
      */
    RemoteAddress: string;
    /**
      * 客户端最大连接数。
      */
    MaxConnection: number;
    /**
      * SSL-VPN 网关公网IP。
      */
    WanIp: string;
    /**
      * SSL VPN服务端监听协议
      */
    SslVpnProtocol: string;
    /**
      * SSL VPN服务端监听协议端口
      */
    SslVpnPort: number;
    /**
      * 加密算法。
      */
    EncryptAlgorithm: string;
    /**
      * 认证算法。
      */
    IntegrityAlgorithm: string;
    /**
      * 是否支持压缩。
      */
    Compress: number;
    /**
      * 创建时间。
      */
    CreateTime: string;
    /**
      * SSL-VPN-SERVER 创建状态。
0 创建中
1 创建出错
2 更新中
3 更新出错
4 销毁中
5 销毁出粗
6 已连通
7 未知
      */
    State: number;
}
/**
 * DownloadVpnGatewaySslClientCert返回参数结构体
 */
export interface DownloadVpnGatewaySslClientCertResponse {
    /**
      * SSL-VPN-CLIENT 证书配置
      */
    SslClientConfigsSet: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNetDetect返回参数结构体
 */
export interface DeleteNetDetectResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AllocateAddresses请求参数结构体
 */
export interface AllocateAddressesRequest {
    /**
      * EIP数量。默认值：1。
      */
    AddressCount?: number;
    /**
      * EIP线路类型。默认值：BGP。
<ul style="margin:0"><li>已开通静态单线IP白名单的用户，可选值：<ul><li>CMCC：中国移动</li>
<li>CTCC：中国电信</li>
<li>CUCC：中国联通</li></ul>注意：仅部分地域支持静态单线IP。</li></ul>
      */
    InternetServiceProvider?: string;
    /**
      * EIP计费方式。
<ul style="margin:0"><li>已开通标准账户类型白名单的用户，可选值：<ul><li>BANDWIDTH_PACKAGE：[共享带宽包](https://cloud.tencent.com/document/product/684/15255)付费（需额外开通共享带宽包白名单）</li>
<li>BANDWIDTH_POSTPAID_BY_HOUR：带宽按小时后付费</li>
<li>BANDWIDTH_PREPAID_BY_MONTH：包月按带宽预付费</li>
<li>TRAFFIC_POSTPAID_BY_HOUR：流量按小时后付费</li></ul>默认值：TRAFFIC_POSTPAID_BY_HOUR。</li>
<li>未开通标准账户类型白名单的用户，EIP计费方式与其绑定的实例的计费方式一致，无需传递此参数。</li></ul>
      */
    InternetChargeType?: string;
    /**
      * EIP出带宽上限，单位：Mbps。
<ul style="margin:0"><li>已开通标准账户类型白名单的用户，可选值范围取决于EIP计费方式：<ul><li>BANDWIDTH_PACKAGE：1 Mbps 至 1000 Mbps</li>
<li>BANDWIDTH_POSTPAID_BY_HOUR：1 Mbps 至 100 Mbps</li>
<li>BANDWIDTH_PREPAID_BY_MONTH：1 Mbps 至 200 Mbps</li>
<li>TRAFFIC_POSTPAID_BY_HOUR：1 Mbps 至 100 Mbps</li></ul>默认值：1 Mbps。</li>
<li>未开通标准账户类型白名单的用户，EIP出带宽上限取决于与其绑定的实例的公网出带宽上限，无需传递此参数。</li></ul>
      */
    InternetMaxBandwidthOut?: number;
    /**
      * 包月按带宽预付费EIP的计费参数。EIP为包月按带宽预付费时，该参数必传，其余场景不需传递
      */
    AddressChargePrepaid?: AddressChargePrepaid;
    /**
      * EIP类型。默认值：EIP。
<ul style="margin:0"><li>已开通Anycast公网加速白名单的用户，可选值：<ul><li>AnycastEIP：加速IP，可参见 [Anycast 公网加速](https://cloud.tencent.com/document/product/644)</li></ul>注意：仅部分地域支持加速IP。</li></ul>
<ul style="margin:0"><li>已开通精品IP白名单的用户，可选值：<ul><li>HighQualityEIP：精品IP</li></ul>注意：仅部分地域支持精品IP。</li></ul>
      */
    AddressType?: string;
    /**
      * Anycast发布域。
<ul style="margin:0"><li>已开通Anycast公网加速白名单的用户，可选值：<ul><li>ANYCAST_ZONE_GLOBAL：全球发布域（需要额外开通Anycast全球加速白名单）</li><li>ANYCAST_ZONE_OVERSEAS：境外发布域</li><li><b>[已废弃]</b> ANYCAST_ZONE_A：发布域A（已更新为全球发布域）</li><li><b>[已废弃]</b> ANYCAST_ZONE_B：发布域B（已更新为全球发布域）</li></ul>默认值：ANYCAST_ZONE_OVERSEAS。</li></ul>
      */
    AnycastZone?: string;
    /**
      * <b>[已废弃]</b> AnycastEIP不再区分是否负载均衡。原参数说明如下：
AnycastEIP是否用于绑定负载均衡。
<ul style="margin:0"><li>已开通Anycast公网加速白名单的用户，可选值：<ul><li>TRUE：AnycastEIP可绑定对象为负载均衡</li>
<li>FALSE：AnycastEIP可绑定对象为云服务器、NAT网关、高可用虚拟IP等</li></ul>默认值：FALSE。</li></ul>
      */
    ApplicableForCLB?: boolean;
    /**
      * 需要关联的标签列表。
      */
    Tags?: Array<Tag>;
    /**
      * BGP带宽包唯一ID参数。设定该参数且InternetChargeType为BANDWIDTH_PACKAGE，则表示创建的EIP加入该BGP带宽包并采用带宽包计费
      */
    BandwidthPackageId?: string;
    /**
      * EIP名称，用于申请EIP时用户自定义该EIP的个性化名称，默认值：未命名
      */
    AddressName?: string;
}
/**
 * 合规化审批单
 */
export interface CrossBorderCompliance {
    /**
      * 服务商，可选值：`UNICOM`。
      */
    ServiceProvider: string;
    /**
      * 合规化审批单`ID`。
      */
    ComplianceId: number;
    /**
      * 公司全称。
      */
    Company: string;
    /**
      * 统一社会信用代码。
      */
    UniformSocialCreditCode: string;
    /**
      * 法定代表人。
      */
    LegalPerson: string;
    /**
      * 发证机关。
      */
    IssuingAuthority: string;
    /**
      * 营业执照。
      */
    BusinessLicense: string;
    /**
      * 营业执照住所。
      */
    BusinessAddress: string;
    /**
      * 邮编。
      */
    PostCode: number;
    /**
      * 经办人。
      */
    Manager: string;
    /**
      * 经办人身份证号。
      */
    ManagerId: string;
    /**
      * 经办人身份证。
      */
    ManagerIdCard: string;
    /**
      * 经办人身份证地址。
      */
    ManagerAddress: string;
    /**
      * 经办人联系电话。
      */
    ManagerTelephone: string;
    /**
      * 电子邮箱。
      */
    Email: string;
    /**
      * 服务受理单。
      */
    ServiceHandlingForm: string;
    /**
      * 授权函。
      */
    AuthorizationLetter: string;
    /**
      * 信息安全承诺书。
      */
    SafetyCommitment: string;
    /**
      * 服务开始时间。
      */
    ServiceStartDate: string;
    /**
      * 服务截止时间。
      */
    ServiceEndDate: string;
    /**
      * 状态。待审批：`PENDING`，已通过：`APPROVED`，已拒绝：`DENY`。
      */
    State: string;
    /**
      * 审批单创建时间。
      */
    CreatedTime: string;
}
/**
 * ModifyAssistantCidr请求参数结构体
 */
export interface ModifyAssistantCidrRequest {
    /**
      * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
      */
    VpcId: string;
    /**
      * 待添加的辅助CIDR。CIDR数组，格式如["10.0.0.0/16", "172.16.0.0/16"]，入参NewCidrBlocks和OldCidrBlocks至少需要其一。
      */
    NewCidrBlocks?: Array<string>;
    /**
      * 待删除的辅助CIDR。CIDR数组，格式如["10.0.0.0/16", "172.16.0.0/16"]，入参NewCidrBlocks和OldCidrBlocks至少需要其一。
      */
    OldCidrBlocks?: Array<string>;
}
/**
 * CreateIp6Translators请求参数结构体
 */
export interface CreateIp6TranslatorsRequest {
    /**
      * 转换实例名称
      */
    Ip6TranslatorName?: string;
    /**
      * 创建转换实例数量，默认是1个
      */
    Ip6TranslatorCount?: number;
    /**
      * 转换实例运营商属性，可取"CMCC","CTCC","CUCC","BGP"
      */
    Ip6InternetServiceProvider?: string;
}
/**
 * AssociateDhcpIpWithAddressIp返回参数结构体
 */
export interface AssociateDhcpIpWithAddressIpResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyGatewayFlowQos返回参数结构体
 */
export interface ModifyGatewayFlowQosResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNetworkInterfaceQos返回参数结构体
 */
export interface ModifyNetworkInterfaceQosResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifySecurityGroupAttribute返回参数结构体
 */
export interface ModifySecurityGroupAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssociateDirectConnectGatewayNatGateway请求参数结构体
 */
export interface AssociateDirectConnectGatewayNatGatewayRequest {
    /**
      * 专线网关ID。
      */
    VpcId: string;
    /**
      * NAT网关ID。
      */
    NatGatewayId: string;
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    DirectConnectGatewayId: string;
}
/**
 * 地址信息
 */
export interface AddressTemplateItem {
    /**
      * 起始地址。
      */
    From: string;
    /**
      * 结束地址。
      */
    To: string;
}
/**
 * ModifyAddressAttribute返回参数结构体
 */
export interface ModifyAddressAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AttachClassicLinkVpc请求参数结构体
 */
export interface AttachClassicLinkVpcRequest {
    /**
      * VPC实例ID
      */
    VpcId: string;
    /**
      * CVM实例ID
      */
    InstanceIds: Array<string>;
}
/**
 * 网关流量监控明细
 */
export interface GatewayFlowMonitorDetail {
    /**
      * 来源`IP`。
      */
    PrivateIpAddress: string;
    /**
      * 入包量。
      */
    InPkg: number;
    /**
      * 出包量。
      */
    OutPkg: number;
    /**
      * 入流量，单位：`Byte`。
      */
    InTraffic: number;
    /**
      * 出流量，单位：`Byte`。
      */
    OutTraffic: number;
}
/**
 * CreateVpnGatewaySslClient请求参数结构体
 */
export interface CreateVpnGatewaySslClientRequest {
    /**
      * SSL-VPN-SERVER 实例ID。
      */
    SslVpnServerId: string;
    /**
      * name
      */
    SslVpnClientName: string;
}
/**
 * UnlockCcns请求参数结构体
 */
export declare type UnlockCcnsRequest = null;
/**
 * DescribeVpnGatewaySslServers返回参数结构体
 */
export interface DescribeVpnGatewaySslServersResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * SSL-VPN-SERVER 实例详细信息列表。
      */
    SslVpnSeverSet: Array<SslVpnSever>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNatGatewayDestinationIpPortTranslationNatRule返回参数结构体
 */
export interface DeleteNatGatewayDestinationIpPortTranslationNatRuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpnGateway请求参数结构体
 */
export interface DeleteVpnGatewayRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
}
/**
 * ReplaceRouteTableAssociation返回参数结构体
 */
export interface ReplaceRouteTableAssociationResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AttachCcnInstances请求参数结构体
 */
export interface AttachCcnInstancesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 关联网络实例列表
      */
    Instances: Array<CcnInstance>;
    /**
      * CCN所属UIN（根账号），默认当前账号所属UIN
      */
    CcnUin?: string;
}
/**
 * DescribeDirectConnectGatewayCcnRoutes请求参数结构体
 */
export interface DescribeDirectConnectGatewayCcnRoutesRequest {
    /**
      * 专线网关ID，形如：`dcg-prpqlmg1`。
      */
    DirectConnectGatewayId: string;
    /**
      * 云联网路由学习类型，可选值：
<li>`BGP` - 自动学习。</li>
<li>`STATIC` - 静态，即用户配置，默认值。</li>
      */
    CcnRouteType?: string;
    /**
      * 偏移量。
      */
    Offset?: number;
    /**
      * 返回数量。
      */
    Limit?: number;
}
/**
 * 云联网（CCN）关联实例（Instance）对象。
 */
export interface CcnInstance {
    /**
      * 关联实例ID。
      */
    InstanceId: string;
    /**
      * 关联实例ID所属大区，例如：ap-guangzhou。
      */
    InstanceRegion: string;
    /**
      * 关联实例类型，可选值：
<li>`VPC`：私有网络</li>
<li>`DIRECTCONNECT`：专线网关</li>
<li>`BMVPC`：黑石私有网络</li>
<li>`VPNGW`：VPNGW类型</li>
      */
    InstanceType?: string;
    /**
      * 备注
      */
    Description?: string;
    /**
      * 实例关联的路由表ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    RouteTableId?: string;
}
/**
 * DescribeLocalGateway返回参数结构体
 */
export interface DescribeLocalGatewayResponse {
    /**
      * 本地网关信息集合
      */
    LocalGatewaySet: Array<LocalGateway>;
    /**
      * 本地网关总数
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 单项计费价格信息
 */
export interface ItemPrice {
    /**
      * 按量计费后付费单价，单位：元。
      */
    UnitPrice?: number;
    /**
      * 按量计费后付费计价单元，可取值范围： HOUR：表示计价单元是按每小时来计算。当前涉及该计价单元的场景有：实例按小时后付费（POSTPAID_BY_HOUR）、带宽按小时后付费（BANDWIDTH_POSTPAID_BY_HOUR）： GB：表示计价单元是按每GB来计算。当前涉及该计价单元的场景有：流量按小时后付费（TRAFFIC_POSTPAID_BY_HOUR）。
      */
    ChargeUnit?: string;
    /**
      * 预付费商品的原价，单位：元。
      */
    OriginalPrice?: number;
    /**
      * 预付费商品的折扣价，单位：元。
      */
    DiscountPrice?: number;
}
/**
 * DeleteNatGateway请求参数结构体
 */
export interface DeleteNatGatewayRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
}
/**
 * ModifyCustomerGatewayAttribute返回参数结构体
 */
export interface ModifyCustomerGatewayAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 冲突资源条目信息。
 */
export interface ConflictItem {
    /**
      * 冲突资源的ID
      */
    ConfilctId: string;
    /**
      * 冲突目的资源
      */
    DestinationItem: string;
}
/**
 * InquiryPriceRenewVpnGateway返回参数结构体
 */
export interface InquiryPriceRenewVpnGatewayResponse {
    /**
      * 商品价格。
      */
    Price?: Price;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssignIpv6SubnetCidrBlock返回参数结构体
 */
export interface AssignIpv6SubnetCidrBlockResponse {
    /**
      * 分配 `IPv6` 子网段列表。
      */
    Ipv6SubnetCidrBlockSet?: Array<Ipv6SubnetCidrBlock>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpcEndPoint返回参数结构体
 */
export interface CreateVpcEndPointResponse {
    /**
      * 终端节点对象详细信息。
      */
    EndPoint: EndPoint;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteAssistantCidr返回参数结构体
 */
export interface DeleteAssistantCidrResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCcnRegionBandwidthLimits返回参数结构体
 */
export interface DescribeCcnRegionBandwidthLimitsResponse {
    /**
      * 云联网（CCN）各地域出带宽上限
      */
    CcnRegionBandwidthLimitSet?: Array<CcnRegionBandwidthLimit>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyTemplateMember请求参数结构体
 */
export interface ModifyTemplateMemberRequest {
    /**
      * 参数模板实例ID，支持IP地址、协议端口、IP地址组、协议端口组四种参数模板的实例ID。
      */
    TemplateId: string;
    /**
      * 需要修改的参数模板成员信息，支持IP地址、协议端口、IP地址组、协议端口组四种类型，类型需要与TemplateId参数类型一致，修改顺序与TemplateMember参数顺序一一对应，入参长度需要与TemplateMember参数保持一致。
      */
    OriginalTemplateMember: Array<MemberInfo>;
    /**
      * 新的参数模板成员信息，支持IP地址、协议端口、IP地址组、协议端口组四种类型，类型需要与TemplateId参数类型一致，修改顺序与OriginalTemplateMember参数顺序一一对应，入参长度需要与OriginalTemplateMember参数保持一致。
      */
    TemplateMember: Array<MemberInfo>;
}
/**
 * DescribeAddresses返回参数结构体
 */
export interface DescribeAddressesResponse {
    /**
      * 符合条件的 EIP 数量。
      */
    TotalCount: number;
    /**
      * EIP 详细信息列表。
      */
    AddressSet: Array<Address>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 网关流控带宽信息
 */
export interface GatewayQos {
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 云服务器内网IP。
      */
    IpAddress: string;
    /**
      * 流控带宽值。
      */
    Bandwidth: number;
    /**
      * 创建时间。
      */
    CreateTime: string;
}
/**
 * ModifyIpv6AddressesAttribute请求参数结构体
 */
export interface ModifyIpv6AddressesAttributeRequest {
    /**
      * 弹性网卡实例`ID`，形如：`eni-m6dyj72l`。
      */
    NetworkInterfaceId: string;
    /**
      * 指定的内网IPv6`地址信息。
      */
    Ipv6Addresses: Array<Ipv6Address>;
}
/**
 * DescribeCustomerGatewayVendors请求参数结构体
 */
export declare type DescribeCustomerGatewayVendorsRequest = null;
/**
 * DeleteLocalGateway请求参数结构体
 */
export interface DeleteLocalGatewayRequest {
    /**
      * 本地网关实例ID
      */
    LocalGatewayId: string;
    /**
      * CDC实例ID
      */
    CdcId: string;
    /**
      * VPC实例ID
      */
    VpcId?: string;
}
/**
 * ResetVpnGatewayInternetMaxBandwidth返回参数结构体
 */
export interface ResetVpnGatewayInternetMaxBandwidthResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * LockCcnBandwidths请求参数结构体
 */
export declare type LockCcnBandwidthsRequest = null;
/**
 * 用于描述弹性公网IP的费用对象
 */
export interface AddressChargePrepaid {
    /**
      * 购买实例的时长，单位是月。可支持时长：1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 24, 36
      */
    Period: number;
    /**
      * 自动续费标志。0表示手动续费，1表示自动续费，2表示到期不续费。默认缺省为0即手动续费
      */
    AutoRenewFlag?: number;
}
/**
 * DescribeVpnGatewayRoutes返回参数结构体
 */
export interface DescribeVpnGatewayRoutesResponse {
    /**
      * VPN网关目的路由
      */
    Routes: Array<VpnGatewayRoute>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNetworkAcls返回参数结构体
 */
export interface DescribeNetworkAclsResponse {
    /**
      * 实例详细信息列表。
      */
    NetworkAclSet?: Array<NetworkAcl>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteFlowLog返回参数结构体
 */
export interface DeleteFlowLogResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AttachCcnInstances返回参数结构体
 */
export interface AttachCcnInstancesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateDefaultVpc返回参数结构体
 */
export interface CreateDefaultVpcResponse {
    /**
      * 默认VPC和子网ID
      */
    Vpc?: DefaultVpcSubnet;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpcAttribute返回参数结构体
 */
export interface ModifyVpcAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpnConnectionAttribute返回参数结构体
 */
export interface ModifyVpnConnectionAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 内网IP信息
 */
export interface PrivateIpAddressSpecification {
    /**
      * 内网IP地址。
      */
    PrivateIpAddress: string;
    /**
      * 是否是主IP。
      */
    Primary?: boolean;
    /**
      * 公网IP地址。
      */
    PublicIpAddress?: string;
    /**
      * EIP实例ID，例如：eip-11112222。
      */
    AddressId?: string;
    /**
      * 内网IP描述信息。
      */
    Description?: string;
    /**
      * 公网IP是否被封堵。
      */
    IsWanIpBlocked?: boolean;
    /**
      * IP状态：
PENDING：生产中
MIGRATING：迁移中
DELETING：删除中
AVAILABLE：可用的
      */
    State?: string;
}
/**
 * ALG协议类型
 */
export interface AlgType {
    /**
      * Ftp协议Alg功能是否开启
      */
    Ftp: boolean;
    /**
      * Sip协议Alg功能是否开启
      */
    Sip: boolean;
}
/**
 * MigratePrivateIpAddress返回参数结构体
 */
export interface MigratePrivateIpAddressResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteRouteTable返回参数结构体
 */
export interface DeleteRouteTableResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcInstances返回参数结构体
 */
export interface DescribeVpcInstancesResponse {
    /**
      * 云主机实例列表。
      */
    InstanceSet?: Array<CvmInstance>;
    /**
      * 满足条件的云主机实例个数。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 账户属性对象
 */
export interface AccountAttribute {
    /**
      * 属性名
      */
    AttributeName: string;
    /**
      * 属性值
      */
    AttributeValues: Array<string>;
}
/**
 * DeleteDirectConnectGatewayCcnRoutes请求参数结构体
 */
export interface DeleteDirectConnectGatewayCcnRoutesRequest {
    /**
      * 专线网关ID，形如：dcg-prpqlmg1
      */
    DirectConnectGatewayId: string;
    /**
      * 路由ID。形如：ccnr-f49l6u0z。
      */
    RouteIds: Array<string>;
}
/**
 * ModifyNatGatewaySourceIpTranslationNatRule返回参数结构体
 */
export interface ModifyNatGatewaySourceIpTranslationNatRuleResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateNatGatewayDestinationIpPortTranslationNatRule请求参数结构体
 */
export interface CreateNatGatewayDestinationIpPortTranslationNatRuleRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * NAT网关的端口转换规则。
      */
    DestinationIpPortTranslationNatRules: Array<DestinationIpPortTranslationNatRule>;
}
/**
 * CreateFlowLog请求参数结构体
 */
export interface CreateFlowLogRequest {
    /**
      * 流日志实例名字
      */
    FlowLogName: string;
    /**
      * 流日志所属资源类型，VPC|SUBNET|NETWORKINTERFACE|CCN|NAT|DCG
      */
    ResourceType: string;
    /**
      * 资源唯一ID
      */
    ResourceId: string;
    /**
      * 流日志采集类型，ACCEPT|REJECT|ALL
      */
    TrafficType: string;
    /**
      * 私用网络ID或者统一ID，建议使用统一ID，当ResourceType为CCN时不填，其他类型必填。
      */
    VpcId?: string;
    /**
      * 流日志实例描述
      */
    FlowLogDescription?: string;
    /**
      * 流日志存储ID
      */
    CloudLogId?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * 消费端类型：cls、ckafka
      */
    StorageType?: string;
    /**
      * 流日志消费端信息，当消费端类型为ckafka时，必填。
      */
    FlowLogStorage?: FlowLogStorage;
}
/**
 * InquirePriceCreateDirectConnectGateway请求参数结构体
 */
export declare type InquirePriceCreateDirectConnectGatewayRequest = null;
/**
 * AttachNetworkInterface返回参数结构体
 */
export interface AttachNetworkInterfaceResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateNatGatewayAddress请求参数结构体
 */
export interface DisassociateNatGatewayAddressRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * 待解绑NAT网关的弹性IP数组。
      */
    PublicIpAddresses: Array<string>;
}
/**
 * DescribeServiceTemplates返回参数结构体
 */
export interface DescribeServiceTemplatesResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 协议端口模板对象。
      */
    ServiceTemplateSet: Array<ServiceTemplate>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeRouteTables请求参数结构体
 */
export interface DescribeRouteTablesRequest {
    /**
      * 过滤条件，参数不支持同时指定RouteTableIds和Filters。
<li>route-table-id - String - （过滤条件）路由表实例ID。</li>
<li>route-table-name - String - （过滤条件）路由表名称。</li>
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-f49l6u0z。</li>
<li>association.main - String - （过滤条件）是否主路由表。</li>
<li>tag-key - String -是否必填：否- （过滤条件）按照标签键进行过滤。</li>
<li>tag:tag-key - String - 是否必填：否 - （过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例2。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableIds?: Array<string>;
    /**
      * 偏移量。
      */
    Offset?: string;
    /**
      * 请求对象个数。
      */
    Limit?: string;
}
/**
 * ResetAttachCcnInstances请求参数结构体
 */
export interface ResetAttachCcnInstancesRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * CCN所属UIN（根账号）。
      */
    CcnUin: string;
    /**
      * 重新申请关联网络实例列表。
      */
    Instances: Array<CcnInstance>;
}
/**
 * CreateHaVip返回参数结构体
 */
export interface CreateHaVipResponse {
    /**
      * `HAVIP`对象。
      */
    HaVip: HaVip;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroupReferences请求参数结构体
 */
export interface DescribeSecurityGroupReferencesRequest {
    /**
      * 安全组实例ID数组。格式如：['sg-12345678']
      */
    SecurityGroupIds: Array<string>;
}
/**
 * DescribeTemplateLimits返回参数结构体
 */
export interface DescribeTemplateLimitsResponse {
    /**
      * 参数模板配额对象。
      */
    TemplateLimit?: TemplateLimit;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CheckDefaultSubnet返回参数结构体
 */
export interface CheckDefaultSubnetResponse {
    /**
      * 检查结果。true为可以创建默认子网，false为不可以创建默认子网。
      */
    Result?: boolean;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisableRoutes请求参数结构体
 */
export interface DisableRoutesRequest {
    /**
      * 路由表唯一ID。
      */
    RouteTableId: string;
    /**
      * 路由策略ID。不能和RouteItemIds同时使用，但至少输入一个。该参数取值可通过查询路由列表（[DescribeRouteTables](https://cloud.tencent.com/document/product/215/15763)）获取。
      */
    RouteIds?: Array<number>;
    /**
      * 路由策略唯一ID。不能和RouteIds同时使用，但至少输入一个。该参数取值可通过查询路由列表（[DescribeRouteTables](https://cloud.tencent.com/document/product/215/15763)）获取。
      */
    RouteItemIds?: Array<string>;
}
/**
 * DisassociateDirectConnectGatewayNatGateway请求参数结构体
 */
export interface DisassociateDirectConnectGatewayNatGatewayRequest {
    /**
      * 专线网关ID。
      */
    VpcId: string;
    /**
      * NAT网关ID。
      */
    NatGatewayId: string;
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    DirectConnectGatewayId: string;
}
/**
 * EnableRoutes请求参数结构体
 */
export interface EnableRoutesRequest {
    /**
      * 路由表唯一ID。
      */
    RouteTableId: string;
    /**
      * 路由策略ID。不能和RouteItemIds同时使用，但至少输入一个。该参数取值可通过查询路由列表（[DescribeRouteTables](https://cloud.tencent.com/document/product/215/15763)）获取。
      */
    RouteIds?: Array<number>;
    /**
      * 路由策略唯一ID。不能和RouteIds同时使用，但至少输入一个。该参数取值可通过查询路由列表（[DescribeRouteTables](https://cloud.tencent.com/document/product/215/15763)）获取。
      */
    RouteItemIds?: Array<string>;
}
/**
 * DescribeAddressTemplateGroups返回参数结构体
 */
export interface DescribeAddressTemplateGroupsResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * IP地址模板。
      */
    AddressTemplateGroupSet?: Array<AddressTemplateGroup>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ReleaseAddresses请求参数结构体
 */
export interface ReleaseAddressesRequest {
    /**
      * 标识 EIP 的唯一 ID 列表。EIP 唯一 ID 形如：`eip-11112222`。
      */
    AddressIds: Array<string>;
}
/**
 * CreateDirectConnectGatewayCcnRoutes请求参数结构体
 */
export interface CreateDirectConnectGatewayCcnRoutesRequest {
    /**
      * 专线网关ID，形如：dcg-prpqlmg1
      */
    DirectConnectGatewayId: string;
    /**
      * 需要连通的IDC网段列表
      */
    Routes: Array<DirectConnectGatewayCcnRoute>;
}
/**
 * ModifyGatewayFlowQos请求参数结构体
 */
export interface ModifyGatewayFlowQosRequest {
    /**
      * 网关实例ID，目前我们支持的网关实例类型有，
专线网关实例ID，形如，`dcg-ltjahce6`；
Nat网关实例ID，形如，`nat-ltjahce6`；
VPN网关实例ID，形如，`vpn-ltjahce6`。
      */
    GatewayId: string;
    /**
      * 流控带宽值。取值大于0，表示限流到指定的Mbps；取值等于0，表示完全限流；取值为-1，不限流。
      */
    Bandwidth: number;
    /**
      * 限流的云服务器内网IP。
      */
    IpAddresses: Array<string>;
}
/**
 * CreateDirectConnectGatewayCcnRoutes返回参数结构体
 */
export interface CreateDirectConnectGatewayCcnRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateRouteTable请求参数结构体
 */
export interface CreateRouteTableRequest {
    /**
      * 待操作的VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * 路由表名称，最大长度不能超过60个字节。
      */
    RouteTableName: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
}
/**
 * MigrateNetworkInterface请求参数结构体
 */
export interface MigrateNetworkInterfaceRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
    /**
      * 弹性网卡当前绑定的CVM实例ID。形如：ins-r8hr2upy。
      */
    SourceInstanceId: string;
    /**
      * 待迁移的目的CVM实例ID。
      */
    DestinationInstanceId: string;
    /**
      * 网卡绑定类型：0 标准型 1 扩展型。
      */
    AttachType?: number;
}
/**
 * DescribeCustomerGateways请求参数结构体
 */
export interface DescribeCustomerGatewaysRequest {
    /**
      * 对端网关ID，例如：cgw-2wqq41m9。每次请求的实例的上限为100。参数不支持同时指定CustomerGatewayIds和Filters。
      */
    CustomerGatewayIds?: Array<string>;
    /**
      * 过滤条件，详见下表：实例过滤条件表。每次请求的Filters的上限为10，Filter.Values的上限为5。参数不支持同时指定CustomerGatewayIds和Filters。
<li>customer-gateway-id - String - （过滤条件）用户网关唯一ID形如：`cgw-mgp33pll`。</li>
<li>customer-gateway-name - String - （过滤条件）用户网关名称形如：`test-cgw`。</li>
<li>ip-address - String - （过滤条件）公网地址形如：`58.211.1.12`。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。关于Offset的更进一步介绍请参考 API 简介中的相关小节。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * RenewAddresses请求参数结构体
 */
export interface RenewAddressesRequest {
    /**
      * EIP唯一标识ID列表，形如'eip-xxxx'
      */
    AddressIds: Array<string>;
    /**
      * 续费参数
      */
    AddressChargePrepaid: AddressChargePrepaid;
}
/**
 * 描述网络中心每个产品的配额信息
 */
export interface ProductQuota {
    /**
      * 产品配额ID
      */
    QuotaId: string;
    /**
      * 产品配额名称
      */
    QuotaName: string;
    /**
      * 产品当前配额
      */
    QuotaCurrent: number;
    /**
      * 产品配额上限
      */
    QuotaLimit: number;
    /**
      * 产品配额是否有地域属性
      */
    QuotaRegion: boolean;
}
/**
 * DisableRoutes返回参数结构体
 */
export interface DisableRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyAddressAttribute请求参数结构体
 */
export interface ModifyAddressAttributeRequest {
    /**
      * 标识 EIP 的唯一 ID。EIP 唯一 ID 形如：`eip-11112222`。
      */
    AddressId: string;
    /**
      * 修改后的 EIP 名称。长度上限为20个字符。
      */
    AddressName?: string;
    /**
      * 设定EIP是否直通，"TRUE"表示直通，"FALSE"表示非直通。注意该参数仅对EIP直通功能可见的用户可以设定。
      */
    EipDirectConnection?: string;
}
/**
 * 描述 DhcpIp 信息
 */
export interface DhcpIp {
    /**
      * `DhcpIp`的`ID`，是`DhcpIp`的唯一标识。
      */
    DhcpIpId: string;
    /**
      * `DhcpIp`所在私有网络`ID`。
      */
    VpcId: string;
    /**
      * `DhcpIp`所在子网`ID`。
      */
    SubnetId: string;
    /**
      * `DhcpIp`的名称。
      */
    DhcpIpName: string;
    /**
      * IP地址。
      */
    PrivateIpAddress: string;
    /**
      * 绑定`EIP`。
      */
    AddressIp: string;
    /**
      * `DhcpIp`关联弹性网卡`ID`。
      */
    NetworkInterfaceId: string;
    /**
      * 被绑定的实例`ID`。
      */
    InstanceId: string;
    /**
      * 状态：
<li>`AVAILABLE`：运行中</li>
<li>`UNBIND`：未绑定</li>
      */
    State: string;
    /**
      * 创建时间。
      */
    CreatedTime: string;
}
/**
 * DeleteAssistantCidr请求参数结构体
 */
export interface DeleteAssistantCidrRequest {
    /**
      * `VPC`实例`ID`。形如：`vpc-6v2ht8q5`
      */
    VpcId: string;
    /**
      * CIDR数组，格式如["10.0.0.0/16", "172.16.0.0/16"]
      */
    CidrBlocks: Array<string>;
}
/**
 * ModifyTemplateMember返回参数结构体
 */
export interface ModifyTemplateMemberResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteVpnGatewaySslClient请求参数结构体
 */
export interface DeleteVpnGatewaySslClientRequest {
    /**
      * SSL-VPN-CLIENT 实例ID。
      */
    SslVpnClientId: string;
}
/**
 * 子网对象
 */
export interface SubnetInput {
    /**
      * 子网的`CIDR`。
      */
    CidrBlock: string;
    /**
      * 子网名称。
      */
    SubnetName: string;
    /**
      * 可用区。形如：`ap-guangzhou-2`。
      */
    Zone: string;
    /**
      * 指定关联路由表，形如：`rtb-3ryrwzuu`。
      */
    RouteTableId?: string;
}
/**
 * DescribeNatGatewayDirectConnectGatewayRoute返回参数结构体
 */
export interface DescribeNatGatewayDirectConnectGatewayRouteResponse {
    /**
      * 路由数据
      */
    NatDirectConnectGatewayRouteSet: Array<NatDirectConnectGatewayRoute>;
    /**
      * 路由总数
      */
    Total: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * EnableVpcEndPointConnect返回参数结构体
 */
export interface EnableVpcEndPointConnectResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateNetDetect返回参数结构体
 */
export interface CreateNetDetectResponse {
    /**
      * 网络探测（NetDetect）对象。
      */
    NetDetect: NetDetect;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteCcn请求参数结构体
 */
export interface DeleteCcnRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
}
/**
 * ModifyLocalGateway返回参数结构体
 */
export interface ModifyLocalGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssociateNetworkInterfaceSecurityGroups返回参数结构体
 */
export interface AssociateNetworkInterfaceSecurityGroupsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * EnableFlowLogs请求参数结构体
 */
export interface EnableFlowLogsRequest {
    /**
      * 流日志Id。
      */
    FlowLogIds: Array<string>;
}
/**
 * ModifyVpnGatewayAttribute请求参数结构体
 */
export interface ModifyVpnGatewayAttributeRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * VPN网关名称，最大长度不能超过60个字节。
      */
    VpnGatewayName?: string;
    /**
      * VPN网关计费模式，目前只支持预付费（即包年包月）到后付费（即按量计费）的转换。即参数只支持：POSTPAID_BY_HOUR。
      */
    InstanceChargeType?: string;
}
/**
 * CreateNatGateway请求参数结构体
 */
export interface CreateNatGatewayRequest {
    /**
      * NAT网关名称
      */
    NatGatewayName: string;
    /**
      * VPC实例ID。可通过DescribeVpcs接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * NAT网关最大外网出带宽(单位:Mbps)，支持的参数值：`20, 50, 100, 200, 500, 1000, 2000, 5000`，默认: `100Mbps`。
      */
    InternetMaxBandwidthOut?: number;
    /**
      * NAT网关并发连接上限，支持参数值：`1000000、3000000、10000000`，默认值为`100000`。
      */
    MaxConcurrentConnection?: number;
    /**
      * 需要申请的弹性IP个数，系统会按您的要求生产N个弹性IP，其中AddressCount和PublicAddresses至少传递一个。
      */
    AddressCount?: number;
    /**
      * 绑定NAT网关的弹性IP数组，其中AddressCount和PublicAddresses至少传递一个。
      */
    PublicIpAddresses?: Array<string>;
    /**
      * 可用区，形如：`ap-guangzhou-1`。
      */
    Zone?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * NAT网关所属子网
      */
    SubnetId?: string;
    /**
      * 绑定NAT网关的弹性IP带宽大小（单位Mbps），默认为当前用户类型所能使用的最大值。
      */
    StockPublicIpAddressesBandwidthOut?: number;
    /**
      * 需要申请公网IP带宽大小（单位Mbps），默认为当前用户类型所能使用的最大值。
      */
    PublicIpAddressesBandwidthOut?: number;
    /**
      * 公网IP是否强制与NAT网关来自同可用区，true表示需要与NAT网关同可用区；false表示可与NAT网关不是同一个可用区。此参数只有当参数Zone存在时才能生效。
      */
    PublicIpFromSameZone?: boolean;
}
/**
 * DeleteNetDetect请求参数结构体
 */
export interface DeleteNetDetectRequest {
    /**
      * 网络探测实例`ID`。形如：`netd-12345678`
      */
    NetDetectId: string;
}
/**
 * IPSec配置，腾讯云提供IPSec安全会话设置
 */
export interface IPSECOptionsSpecification {
    /**
      * 加密算法，可选值：'3DES-CBC', 'AES-CBC-128', 'AES-CBC-192', 'AES-CBC-256', 'DES-CBC', 'SM4', 'NULL'， 默认为AES-CBC-128
      */
    EncryptAlgorithm?: string;
    /**
      * 认证算法：可选值：'MD5', 'SHA1'，'SHA-256' 默认为
      */
    IntegrityAlgorith?: string;
    /**
      * IPsec SA lifetime(s)：单位秒，取值范围：180-604800
      */
    IPSECSaLifetimeSeconds?: number;
    /**
      * PFS：可选值：'NULL', 'DH-GROUP1', 'DH-GROUP2', 'DH-GROUP5', 'DH-GROUP14', 'DH-GROUP24'，默认为NULL
      */
    PfsDhGroup?: string;
    /**
      * IPsec SA lifetime(KB)：单位KB，取值范围：2560-604800
      */
    IPSECSaLifetimeTraffic?: number;
}
/**
 * UnassignIpv6Addresses请求参数结构体
 */
export interface UnassignIpv6AddressesRequest {
    /**
      * 弹性网卡实例`ID`，形如：`eni-m6dyj72l`。
      */
    NetworkInterfaceId: string;
    /**
      * 指定的`IPv6`地址列表，单次最多指定10个。
      */
    Ipv6Addresses: Array<Ipv6Address>;
}
/**
 * CreateAndAttachNetworkInterface返回参数结构体
 */
export interface CreateAndAttachNetworkInterfaceResponse {
    /**
      * 弹性网卡实例。
      */
    NetworkInterface: NetworkInterface;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyCcnAttribute请求参数结构体
 */
export interface ModifyCcnAttributeRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * CCN名称，最大长度不能超过60个字节，限制：CcnName和CcnDescription必须至少选择一个参数输入，否则报错。
      */
    CcnName?: string;
    /**
      * CCN描述信息，最大长度不能超过100个字节，限制：CcnName和CcnDescription必须至少选择一个参数输入，否则报错。
      */
    CcnDescription?: string;
}
/**
 * DeleteSecurityGroupPolicies返回参数结构体
 */
export interface DeleteSecurityGroupPoliciesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateDhcpIpWithAddressIp返回参数结构体
 */
export interface DisassociateDhcpIpWithAddressIpResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpcEndPointService返回参数结构体
 */
export interface CreateVpcEndPointServiceResponse {
    /**
      * 终端节点服务对象详细信息。
      */
    EndPointService: EndPointService;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNetworkAclAttribute请求参数结构体
 */
export interface ModifyNetworkAclAttributeRequest {
    /**
      * 网络ACL实例ID。例如：acl-12345678。
      */
    NetworkAclId: string;
    /**
      * 网络ACL名称，最大长度不能超过60个字节。
      */
    NetworkAclName: string;
}
/**
 * DeleteVpnGateway返回参数结构体
 */
export interface DeleteVpnGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeHaVips请求参数结构体
 */
export interface DescribeHaVipsRequest {
    /**
      * `HAVIP`唯一`ID`，形如：`havip-9o233uri`。
      */
    HaVipIds?: Array<string>;
    /**
      * 过滤条件，参数不支持同时指定`HaVipIds`和`Filters`。
<li>havip-id - String - `HAVIP`唯一`ID`，形如：`havip-9o233uri`。</li>
<li>havip-name - String - `HAVIP`名称。</li>
<li>vpc-id - String - `HAVIP`所在私有网络`ID`。</li>
<li>subnet-id - String - `HAVIP`所在子网`ID`。</li>
<li>vip - String - `HAVIP`的地址`VIP`。</li>
<li>address-ip - String - `HAVIP`绑定的弹性公网`IP`。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
}
/**
 * UnassignPrivateIpAddresses返回参数结构体
 */
export interface UnassignPrivateIpAddressesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 描述 EIP 信息
 */
export interface Address {
    /**
      * `EIP`的`ID`，是`EIP`的唯一标识。
      */
    AddressId?: string;
    /**
      * `EIP`名称。
      */
    AddressName?: string;
    /**
      * `EIP`状态，包含'CREATING'(创建中),'BINDING'(绑定中),'BIND'(已绑定),'UNBINDING'(解绑中),'UNBIND'(已解绑),'OFFLINING'(释放中),'BIND_ENI'(绑定悬空弹性网卡)
      */
    AddressStatus?: string;
    /**
      * 外网IP地址
      */
    AddressIp?: string;
    /**
      * 绑定的资源实例`ID`。可能是一个`CVM`，`NAT`。
      */
    InstanceId?: string;
    /**
      * 创建时间。按照`ISO8601`标准表示，并且使用`UTC`时间。格式为：`YYYY-MM-DDThh:mm:ssZ`。
      */
    CreatedTime?: string;
    /**
      * 绑定的弹性网卡ID
      */
    NetworkInterfaceId: string;
    /**
      * 绑定的资源内网ip
      */
    PrivateAddressIp: string;
    /**
      * 资源隔离状态。true表示eip处于隔离状态，false表示资源处于未隔离状态
      */
    IsArrears: boolean;
    /**
      * 资源封堵状态。true表示eip处于封堵状态，false表示eip处于未封堵状态
      */
    IsBlocked: boolean;
    /**
      * eip是否支持直通模式。true表示eip支持直通模式，false表示资源不支持直通模式
      */
    IsEipDirectConnection: boolean;
    /**
      * EIP 资源类型，包括CalcIP、WanIP、EIP和AnycastEIP。其中：CalcIP 表示设备 IP，WanIP 表示普通公网 IP，EIP 表示弹性公网 IP，AnycastEip 表示加速 EIP。
      */
    AddressType: string;
    /**
      * eip是否在解绑后自动释放。true表示eip将会在解绑后自动释放，false表示eip在解绑后不会自动释放
      */
    CascadeRelease: boolean;
    /**
      * EIP ALG开启的协议类型。
      */
    EipAlgType: AlgType;
    /**
      * 弹性公网IP的运营商信息，当前可能返回值包括"CMCC","CTCC","CUCC","BGP"
      */
    InternetServiceProvider: string;
    /**
      * 是否本地带宽EIP
      */
    LocalBgp: boolean;
    /**
      * 弹性公网IP的带宽值。注意，传统账户类型账户的弹性公网IP没有带宽属性，值为空。
注意：此字段可能返回 null，表示取不到有效值。
      */
    Bandwidth: number;
    /**
      * 弹性公网IP的网络计费模式。注意，传统账户类型账户的弹性公网IP没有网络计费模式属性，值为空。
注意：此字段可能返回 null，表示取不到有效值。
包括：
<li><strong>BANDWIDTH_PREPAID_BY_MONTH</strong></li>
<p style="padding-left: 30px;">表示包月带宽预付费。</p>
<li><strong>TRAFFIC_POSTPAID_BY_HOUR</strong></li>
<p style="padding-left: 30px;">表示按小时流量后付费。</p>
<li><strong>BANDWIDTH_POSTPAID_BY_HOUR</strong></li>
<p style="padding-left: 30px;">表示按小时带宽后付费。</p>
<li><strong>BANDWIDTH_PACKAGE</strong></li>
<p style="padding-left: 30px;">表示共享带宽包。</p>
注意：此字段可能返回 null，表示取不到有效值。
      */
    InternetChargeType: string;
    /**
      * 弹性公网IP关联的标签列表。
注意：此字段可能返回 null，表示取不到有效值。
      */
    TagSet: Array<Tag>;
}
/**
 * VPN网关对象。
 */
export interface VpnGateway {
    /**
      * 网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 网关实例名称。
      */
    VpnGatewayName: string;
    /**
      * 网关实例类型：'IPSEC', 'SSL','CCN'。
      */
    Type: string;
    /**
      * 网关实例状态， 'PENDING'：生产中，'DELETING'：删除中，'AVAILABLE'：运行中。
      */
    State: string;
    /**
      * 网关公网IP。
      */
    PublicIpAddress: string;
    /**
      * 网关续费类型：'NOTIFY_AND_MANUAL_RENEW'：手动续费，'NOTIFY_AND_AUTO_RENEW'：自动续费，'NOT_NOTIFY_AND_NOT_RENEW'：到期不续费。
      */
    RenewFlag: string;
    /**
      * 网关付费类型：POSTPAID_BY_HOUR：按小时后付费，PREPAID：包年包月预付费，
      */
    InstanceChargeType: string;
    /**
      * 网关出带宽。
      */
    InternetMaxBandwidthOut: number;
    /**
      * 创建时间。
      */
    CreatedTime: string;
    /**
      * 预付费网关过期时间。
      */
    ExpiredTime: string;
    /**
      * 公网IP是否被封堵。
      */
    IsAddressBlocked: boolean;
    /**
      * 计费模式变更，PREPAID_TO_POSTPAID：包年包月预付费到期转按小时后付费。
      */
    NewPurchasePlan: string;
    /**
      * 网关计费装，PROTECTIVELY_ISOLATED：被安全隔离的实例，NORMAL：正常。
      */
    RestrictState: string;
    /**
      * 可用区，如：ap-guangzhou-2
      */
    Zone: string;
    /**
      * 网关带宽配额信息
      */
    VpnGatewayQuotaSet: Array<VpnGatewayQuota>;
    /**
      * 网关实例版本信息
      */
    Version: string;
    /**
      * Type值为CCN时，该值表示云联网实例ID
      */
    NetworkInstanceId: string;
    /**
      * CDC 实例ID
      */
    CdcId: string;
    /**
      * SSL-VPN 客户端连接数。
      */
    MaxConnection: number;
}
/**
 * EnableVpcEndPointConnect请求参数结构体
 */
export interface EnableVpcEndPointConnectRequest {
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
    /**
      * 终端节点ID。
      */
    EndPointId: Array<string>;
    /**
      * 是否接受终端节点连接请求。
      */
    AcceptFlag: boolean;
}
/**
 * EnableGatewayFlowMonitor返回参数结构体
 */
export interface EnableGatewayFlowMonitorResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 描述带宽包资源信息的结构
 */
export interface Resource {
    /**
      * 带宽包资源类型，包括'Address'和'LoadBalance'
      */
    ResourceType: string;
    /**
      * 带宽包资源Id，形如'eip-xxxx', 'lb-xxxx'
      */
    ResourceId: string;
    /**
      * 带宽包资源Ip
      */
    AddressIp: string;
}
/**
 * DeleteDhcpIp请求参数结构体
 */
export interface DeleteDhcpIpRequest {
    /**
      * `DhcpIp`的`ID`，是`DhcpIp`的唯一标识。
      */
    DhcpIpId: string;
}
/**
 * AllocateAddresses返回参数结构体
 */
export interface AllocateAddressesResponse {
    /**
      * 申请到的 EIP 的唯一 ID 列表。
      */
    AddressSet: Array<string>;
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 描述带宽包信息的结构
 */
export interface BandwidthPackage {
    /**
      * 带宽包唯一标识Id
      */
    BandwidthPackageId: string;
    /**
      * 带宽包类型，包括'BGP','SINGLEISP','ANYCAST'
      */
    NetworkType: string;
    /**
      * 带宽包计费类型，包括'TOP5_POSTPAID_BY_MONTH'和'PERCENT95_POSTPAID_BY_MONTH'
      */
    ChargeType: string;
    /**
      * 带宽包名称
      */
    BandwidthPackageName: string;
    /**
      * 带宽包创建时间。按照`ISO8601`标准表示，并且使用`UTC`时间。格式为：`YYYY-MM-DDThh:mm:ssZ`。
      */
    CreatedTime: string;
    /**
      * 带宽包状态，包括'CREATING','CREATED','DELETING','DELETED'
      */
    Status: string;
    /**
      * 带宽包资源信息
      */
    ResourceSet: Array<Resource>;
    /**
      * 带宽包限速大小。单位：Mbps，-1表示不限速。
      */
    Bandwidth: number;
}
/**
 * ModifyVpcAttribute请求参数结构体
 */
export interface ModifyVpcAttributeRequest {
    /**
      * VPC实例ID。形如：vpc-f49l6u0z。每次请求的实例的上限为100。参数不支持同时指定VpcIds和Filters。
      */
    VpcId: string;
    /**
      * 私有网络名称，可任意命名，但不得超过60个字符。
      */
    VpcName?: string;
    /**
      * 是否开启组播。true: 开启, false: 关闭。
      */
    EnableMulticast?: string;
    /**
      * DNS地址，最多支持4个，第1个默认为主，其余为备
      */
    DnsServers?: Array<string>;
    /**
      * 域名
      */
    DomainName?: string;
}
/**
 * DescribeIp6Translators返回参数结构体
 */
export interface DescribeIp6TranslatorsResponse {
    /**
      * 符合过滤条件的IPV6转换实例数量。
      */
    TotalCount?: number;
    /**
      * 符合过滤条件的IPV6转换实例详细信息
      */
    Ip6TranslatorSet?: Array<Ip6Translator>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateSecurityGroupPolicies请求参数结构体
 */
export interface CreateSecurityGroupPoliciesRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
    /**
      * 安全组规则集合。
      */
    SecurityGroupPolicySet: SecurityGroupPolicySet;
}
/**
 * ModifyVpnGatewayRoutes返回参数结构体
 */
export interface ModifyVpnGatewayRoutesResponse {
    /**
      * VPN路由信息
注意：此字段可能返回 null，表示取不到有效值。
      */
    Routes: Array<VpnGatewayRoute>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyRouteTableAttribute返回参数结构体
 */
export interface ModifyRouteTableAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroupReferences返回参数结构体
 */
export interface DescribeSecurityGroupReferencesResponse {
    /**
      * 安全组被引用信息。
      */
    ReferredSecurityGroupSet?: Array<ReferredSecurityGroup>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AddIp6Rules返回参数结构体
 */
export interface AddIp6RulesResponse {
    /**
      * IPV6转换规则唯一ID数组，形如rule6-xxxxxxxx
      */
    Ip6RuleSet?: Array<string>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateAddressTemplateGroup返回参数结构体
 */
export interface CreateAddressTemplateGroupResponse {
    /**
      * IP地址模板集合对象。
      */
    AddressTemplateGroup: AddressTemplateGroup;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeBandwidthPackageQuota返回参数结构体
 */
export interface DescribeBandwidthPackageQuotaResponse {
    /**
      * 带宽包配额详细信息
      */
    QuotaSet?: Array<Quota>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteServiceTemplateGroup请求参数结构体
 */
export interface DeleteServiceTemplateGroupRequest {
    /**
      * 协议端口模板集合实例ID，例如：ppmg-n17uxvve。
      */
    ServiceTemplateGroupId: string;
}
/**
 * DeleteNatGateway返回参数结构体
 */
export interface DeleteNatGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateDirectConnectGateway返回参数结构体
 */
export interface CreateDirectConnectGatewayResponse {
    /**
      * 专线网关对象。
      */
    DirectConnectGateway: DirectConnectGateway;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpcEndPointAttribute请求参数结构体
 */
export interface ModifyVpcEndPointAttributeRequest {
    /**
      * 终端节点ID。
      */
    EndPointId: string;
    /**
      * 终端节点名称。
      */
    EndPointName?: string;
    /**
      * 安全组ID列表。
      */
    SecurityGroupIds?: Array<string>;
}
/**
 * DescribeTaskResult返回参数结构体
 */
export interface DescribeTaskResultResponse {
    /**
      * 任务ID
      */
    TaskId?: number;
    /**
      * 执行结果，包括"SUCCESS", "FAILED", "RUNNING"
      */
    Result?: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateNetworkAclSubnets请求参数结构体
 */
export interface DisassociateNetworkAclSubnetsRequest {
    /**
      * 网络ACL实例ID。例如：acl-12345678。
      */
    NetworkAclId: string;
    /**
      * 子网实例ID数组。例如：[subnet-12345678]
      */
    SubnetIds: Array<string>;
}
/**
 * ModifyAddressTemplateGroupAttribute请求参数结构体
 */
export interface ModifyAddressTemplateGroupAttributeRequest {
    /**
      * IP地址模板集合实例ID，例如：ipmg-2uw6ujo6。
      */
    AddressTemplateGroupId: string;
    /**
      * IP地址模板集合名称。
      */
    AddressTemplateGroupName?: string;
    /**
      * IP地址模板实例ID， 例如：ipm-mdunqeb6。
      */
    AddressTemplateIds?: Array<string>;
}
/**
 * ModifyServiceTemplateGroupAttribute请求参数结构体
 */
export interface ModifyServiceTemplateGroupAttributeRequest {
    /**
      * 协议端口模板集合实例ID，例如：ppmg-ei8hfd9a。
      */
    ServiceTemplateGroupId: string;
    /**
      * 协议端口模板集合名称。
      */
    ServiceTemplateGroupName?: string;
    /**
      * 协议端口模板实例ID，例如：ppm-4dw6agho。
      */
    ServiceTemplateIds?: Array<string>;
}
/**
 * DeleteVpcEndPoint请求参数结构体
 */
export interface DeleteVpcEndPointRequest {
    /**
      * 终端节点ID。
      */
    EndPointId: string;
}
/**
 * UnassignIpv6CidrBlock请求参数结构体
 */
export interface UnassignIpv6CidrBlockRequest {
    /**
      * `VPC`实例`ID`，形如：`vpc-f49l6u0z`。
      */
    VpcId: string;
    /**
      * `IPv6`网段。形如：`3402:4e00:20:1000::/56`
      */
    Ipv6CidrBlock?: string;
}
/**
 * 云联网（CCN）对象
 */
export interface CCN {
    /**
      * 云联网唯一ID
      */
    CcnId: string;
    /**
      * 云联网名称
      */
    CcnName: string;
    /**
      * 云联网描述信息
      */
    CcnDescription: string;
    /**
      * 关联实例数量
      */
    InstanceCount: number;
    /**
      * 创建时间
      */
    CreateTime: string;
    /**
      * 实例状态， 'ISOLATED': 隔离中（欠费停服），'AVAILABLE'：运行中。
      */
    State: string;
    /**
      * 实例服务质量，’PT’：白金，'AU'：金，'AG'：银。
      */
    QosLevel: string;
    /**
      * 付费类型，PREPAID为预付费，POSTPAID为后付费。
注意：此字段可能返回 null，表示取不到有效值。
      */
    InstanceChargeType: string;
    /**
      * 限速类型，INTER_REGION_LIMIT为地域间限速；OUTER_REGION_LIMIT为地域出口限速。
注意：此字段可能返回 null，表示取不到有效值。
      */
    BandwidthLimitType: string;
    /**
      * 标签键值对。
      */
    TagSet: Array<Tag>;
    /**
      * 是否支持云联网路由优先级的功能。False：不支持，True：支持。
      */
    RoutePriorityFlag: boolean;
    /**
      * 实例关联的路由表个数。
注意：此字段可能返回 null，表示取不到有效值。
      */
    RouteTableCount: number;
    /**
      * 是否开启云联网多路由表特性。False：未开启，True：开启。
注意：此字段可能返回 null，表示取不到有效值。
      */
    RouteTableFlag: boolean;
}
/**
 * 终端节点服务的服务白名单对象详情。
 */
export interface VpcEndPointServiceUser {
    /**
      * AppId。
      */
    Owner: number;
    /**
      * Uin。
      */
    UserUin: string;
    /**
      * 描述信息。
      */
    Description: string;
    /**
      * 创建时间。
      */
    CreateTime: string;
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
}
/**
 * InquirePriceCreateDirectConnectGateway返回参数结构体
 */
export interface InquirePriceCreateDirectConnectGatewayResponse {
    /**
      * 专线网关标准接入费用
注意：此字段可能返回 null，表示取不到有效值。
      */
    TotalCost?: number;
    /**
      * 专线网关真实接入费用
注意：此字段可能返回 null，表示取不到有效值。
      */
    RealTotalCost?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteIp6Translators请求参数结构体
 */
export interface DeleteIp6TranslatorsRequest {
    /**
      * 待释放的IPV6转换实例的唯一ID，形如‘ip6-xxxxxxxx’
      */
    Ip6TranslatorIds: Array<string>;
}
/**
 * IPV6转换实例信息
 */
export interface Ip6Translator {
    /**
      * IPV6转换实例唯一ID，形如ip6-xxxxxxxx
      */
    Ip6TranslatorId: string;
    /**
      * IPV6转换实例名称
      */
    Ip6TranslatorName: string;
    /**
      * IPV6地址
      */
    Vip6: string;
    /**
      * IPV6转换地址所属运营商
      */
    IspName: string;
    /**
      * 转换实例状态，限于CREATING,RUNNING,DELETING,MODIFYING
      */
    TranslatorStatus: string;
    /**
      * IPV6转换实例创建时间
      */
    CreatedTime: string;
    /**
      * 绑定的IPV6转换规则数量
      */
    Ip6RuleCount: number;
    /**
      * IPV6转换规则信息
      */
    IP6RuleSet: Array<Ip6Rule>;
}
/**
 * NAT网关的端口转发规则
 */
export interface DestinationIpPortTranslationNatRule {
    /**
      * 网络协议，可选值：`TCP`、`UDP`。
      */
    IpProtocol: string;
    /**
      * 弹性IP。
      */
    PublicIpAddress: string;
    /**
      * 公网端口。
      */
    PublicPort: number;
    /**
      * 内网地址。
      */
    PrivateIpAddress: string;
    /**
      * 内网端口。
      */
    PrivatePort: number;
    /**
      * NAT网关转发规则描述。
      */
    Description: string;
}
/**
 * CreateDefaultVpc请求参数结构体
 */
export interface CreateDefaultVpcRequest {
    /**
      * 子网所在的可用区，该参数可通过[DescribeZones](https://cloud.tencent.com/document/product/213/15707)接口获取，例如ap-guangzhou-1，不指定时将随机选择可用区。
      */
    Zone?: string;
    /**
      * 是否强制返回默认VPC。
      */
    Force?: boolean;
}
/**
 * DescribeSubnets返回参数结构体
 */
export interface DescribeSubnetsResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 子网对象。
      */
    SubnetSet: Array<Subnet>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCustomerGateways返回参数结构体
 */
export interface DescribeCustomerGatewaysResponse {
    /**
      * 对端网关对象列表
      */
    CustomerGatewaySet?: Array<CustomerGateway>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CheckAssistantCidr返回参数结构体
 */
export interface CheckAssistantCidrResponse {
    /**
      * 冲突资源信息数组。
      */
    ConflictSourceSet?: Array<ConflictSource>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * InquiryPriceRenewVpnGateway请求参数结构体
 */
export interface InquiryPriceRenewVpnGatewayRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * 预付费模式，即包年包月相关参数设置。通过该参数可以指定包年包月实例的购买时长、是否设置自动续费等属性。若指定实例的付费模式为预付费则该参数必传。
      */
    InstanceChargePrepaid: InstanceChargePrepaid;
}
/**
 * EnableCcnRoutes返回参数结构体
 */
export interface EnableCcnRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyVpnGatewayCcnRoutes返回参数结构体
 */
export interface ModifyVpnGatewayCcnRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DetachCcnInstances返回参数结构体
 */
export interface DetachCcnInstancesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyServiceTemplateGroupAttribute返回参数结构体
 */
export interface ModifyServiceTemplateGroupAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteSubnet请求参数结构体
 */
export interface DeleteSubnetRequest {
    /**
      * 子网实例ID。可通过DescribeSubnets接口返回值中的SubnetId获取。
      */
    SubnetId: string;
}
/**
 * DescribeAddressTemplateGroups请求参数结构体
 */
export interface DescribeAddressTemplateGroupsRequest {
    /**
      * 过滤条件。
<li>address-template-group-name - String - （过滤条件）IP地址模板集合名称。</li>
<li>address-template-group-id - String - （过滤条件）IP地址模板实集合例ID，例如：ipmg-mdunqeb6。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * CheckNetDetectState返回参数结构体
 */
export interface CheckNetDetectStateResponse {
    /**
      * 网络探测验证结果对象数组。
      */
    NetDetectIpStateSet: Array<NetDetectIpState>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateVpcEndPointSecurityGroups返回参数结构体
 */
export interface DisassociateVpcEndPointSecurityGroupsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeVpcTaskResult返回参数结构体
 */
export interface DescribeVpcTaskResultResponse {
    /**
      * 异步任务执行结果。结果：SUCCESS、FAILED、RUNNING。3者其中之一。其中SUCCESS表示任务执行成功，FAILED表示任务执行失败，RUNNING表示任务执行中。
      */
    Status: string;
    /**
      * 异步任务执行输出。
      */
    Output: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssociateNatGatewayAddress返回参数结构体
 */
export interface AssociateNatGatewayAddressResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * RemoveBandwidthPackageResources请求参数结构体
 */
export interface RemoveBandwidthPackageResourcesRequest {
    /**
      * 带宽包唯一标识ID，形如'bwp-xxxx'
      */
    BandwidthPackageId?: string;
    /**
      * 资源类型，包括‘Address’, ‘LoadBalance’
      */
    ResourceType?: string;
    /**
      * 资源ID，可支持资源形如'eip-xxxx', 'lb-xxxx'
      */
    ResourceIds?: Array<string>;
}
/**
 * VPN网关云联网路由信息
 */
export interface VpngwCcnRoutes {
    /**
      * 路由信息ID
      */
    RouteId: string;
    /**
      * 路由信息是否启用
ENABLE：启用该路由
DISABLE：不启用该路由
      */
    Status?: string;
}
/**
 * ModifyVpnConnectionAttribute请求参数结构体
 */
export interface ModifyVpnConnectionAttributeRequest {
    /**
      * VPN通道实例ID。形如：vpnx-f49l6u0z。
      */
    VpnConnectionId: string;
    /**
      * VPN通道名称，可任意命名，但不得超过60个字符。
      */
    VpnConnectionName?: string;
    /**
      * 预共享密钥。
      */
    PreShareKey?: string;
    /**
      * SPD策略组，例如：{"10.0.0.5/24":["172.123.10.5/16"]}，10.0.0.5/24是vpc内网段172.123.10.5/16是IDC网段。用户指定VPC内哪些网段可以和您IDC中哪些网段通信。
      */
    SecurityPolicyDatabases?: Array<SecurityPolicyDatabase>;
    /**
      * IKE配置（Internet Key Exchange，因特网密钥交换），IKE具有一套自我保护机制，用户配置网络安全协议。
      */
    IKEOptionsSpecification?: IKEOptionsSpecification;
    /**
      * IPSec配置，腾讯云提供IPSec安全会话设置。
      */
    IPSECOptionsSpecification?: IPSECOptionsSpecification;
    /**
      * 是否启用通道健康检查
      */
    EnableHealthCheck?: boolean;
    /**
      * 本端通道探测ip
      */
    HealthCheckLocalIp?: string;
    /**
      * 对端通道探测ip
      */
    HealthCheckRemoteIp?: string;
    /**
      * 协商类型，默认为active（主动协商）。可选值：active（主动协商），passive（被动协商），flowTrigger（流量协商）
      */
    NegotiationType?: string;
    /**
      * DPD探测开关。默认为0，表示关闭DPD探测。可选值：0（关闭），1（开启）
      */
    DpdEnable?: number;
    /**
      * DPD超时时间。即探测确认对端不存在需要的时间。dpdEnable为1（开启）时有效。默认30，单位为秒
      */
    DpdTimeout?: string;
    /**
      * DPD超时后的动作。默认为clear。dpdEnable为1（开启）时有效。可取值为clear（断开）和restart（重试）
      */
    DpdAction?: string;
}
/**
 * DeleteNetworkInterface请求参数结构体
 */
export interface DeleteNetworkInterfaceRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
}
/**
 * InquiryPriceResetVpnGatewayInternetMaxBandwidth返回参数结构体
 */
export interface InquiryPriceResetVpnGatewayInternetMaxBandwidthResponse {
    /**
      * 商品价格。
      */
    Price?: Price;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 路由表对象
 */
export interface RouteTable {
    /**
      * VPC实例ID。
      */
    VpcId: string;
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
    /**
      * 路由表名称。
      */
    RouteTableName: string;
    /**
      * 路由表关联关系。
      */
    AssociationSet: Array<RouteTableAssociation>;
    /**
      * IPv4路由策略集合。
      */
    RouteSet: Array<Route>;
    /**
      * 是否默认路由表。
      */
    Main: boolean;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * 标签键值对。
      */
    TagSet: Array<Tag>;
    /**
      * local路由是否发布云联网。
注意：此字段可能返回 null，表示取不到有效值。
      */
    LocalCidrForCcn: Array<CidrForCcn>;
}
/**
 * DescribeVpcEndPointServiceWhiteList请求参数结构体
 */
export interface DescribeVpcEndPointServiceWhiteListRequest {
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 单页返回数量，默认为20，最大值为100。
      */
    Limit?: number;
    /**
      * 过滤条件。
<li> user-uin String - （过滤条件）用户UIN。</li>
<li> end-point-service-id String - （过滤条件）终端节点服务ID。</li>
      */
    Filters?: Array<Filter>;
}
/**
 * DeleteAddressTemplateGroup返回参数结构体
 */
export interface DeleteAddressTemplateGroupResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNetworkInterfaceQos请求参数结构体
 */
export interface ModifyNetworkInterfaceQosRequest {
    /**
      * 弹性网卡ID，支持批量修改。
      */
    NetworkInterfaceIds: Array<string>;
    /**
      * 服务质量，可选值：PT、AU、AG、DEFAULT，分别代表白金、金、银、默认四个等级。
      */
    QosLevel: string;
}
/**
 * ModifyLocalGateway请求参数结构体
 */
export interface ModifyLocalGatewayRequest {
    /**
      * 本地网关名称
      */
    LocalGatewayName: string;
    /**
      * CDC实例ID
      */
    CdcId: string;
    /**
      * 本地网关实例ID
      */
    LocalGatewayId: string;
    /**
      * VPC实例ID
      */
    VpcId?: string;
}
/**
 * 专线网关云联网路由（IDC网段）对象
 */
export interface DirectConnectGatewayCcnRoute {
    /**
      * 路由ID。
      */
    RouteId: string;
    /**
      * IDC网段。
      */
    DestinationCidrBlock: string;
    /**
      * `BGP`的`AS-Path`属性。
      */
    ASPath: Array<string>;
    /**
      * 备注
      */
    Description: string;
    /**
      * 最后更新时间
      */
    UpdateTime: string;
}
/**
 * DeleteHaVip请求参数结构体
 */
export interface DeleteHaVipRequest {
    /**
      * `HAVIP`唯一`ID`，形如：`havip-9o233uri`。
      */
    HaVipId: string;
}
/**
 * CreateLocalGateway返回参数结构体
 */
export interface CreateLocalGatewayResponse {
    /**
      * 本地网关信息
      */
    LocalGateway: LocalGateway;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 协议端口模板信息
 */
export interface ServicesInfo {
    /**
      * 协议端口。
      */
    Service: string;
    /**
      * 备注。
注意：此字段可能返回 null，表示取不到有效值。
      */
    Description?: string;
}
/**
 * MigratePrivateIpAddress请求参数结构体
 */
export interface MigratePrivateIpAddressRequest {
    /**
      * 当内网IP绑定的弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    SourceNetworkInterfaceId: string;
    /**
      * 待迁移的目的弹性网卡实例ID。
      */
    DestinationNetworkInterfaceId: string;
    /**
      * 迁移的内网IP地址，例如：10.0.0.6。
      */
    PrivateIpAddress: string;
}
/**
 * DescribeServiceTemplates请求参数结构体
 */
export interface DescribeServiceTemplatesRequest {
    /**
      * 过滤条件。
<li>service-template-name - 协议端口模板名称。</li>
<li>service-template-id - 协议端口模板实例ID，例如：ppm-e6dy460g。</li>
<li>service-port- 协议端口。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * RefreshDirectConnectGatewayRouteToNatGateway返回参数结构体
 */
export interface RefreshDirectConnectGatewayRouteToNatGatewayResponse {
    /**
      * IDC子网信息
      */
    DirectConnectSubnetSet: Array<DirectConnectSubnet>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteRouteTable请求参数结构体
 */
export interface DeleteRouteTableRequest {
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
}
/**
 * CreateVpnGateway请求参数结构体
 */
export interface CreateVpnGatewayRequest {
    /**
      * VPC实例ID。可通过[DescribeVpcs](https://cloud.tencent.com/document/product/215/15778)接口返回值中的VpcId获取。
      */
    VpcId: string;
    /**
      * VPN网关名称，最大长度不能超过60个字节。
      */
    VpnGatewayName: string;
    /**
      * 公网带宽设置。可选带宽规格：5, 10, 20, 50, 100；单位：Mbps
      */
    InternetMaxBandwidthOut: number;
    /**
      * VPN网关计费模式，PREPAID：表示预付费，即包年包月，POSTPAID_BY_HOUR：表示后付费，即按量计费。默认：POSTPAID_BY_HOUR，如果指定预付费模式，参数InstanceChargePrepaid必填。
      */
    InstanceChargeType?: string;
    /**
      * 预付费模式，即包年包月相关参数设置。通过该参数可以指定包年包月实例的购买时长、是否设置自动续费等属性。若指定实例的付费模式为预付费则该参数必传。
      */
    InstanceChargePrepaid?: InstanceChargePrepaid;
    /**
      * 可用区，如：ap-guangzhou-2。
      */
    Zone?: string;
    /**
      * VPN网关类型。值“CCN”云联网类型VPN网关，值SSL为SSL-VPN
      */
    Type?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
    /**
      * CDC实例ID
      */
    CdcId?: string;
    /**
      * SSL-VPN 最大CLIENT 连接数。可选 [5, 10, 20, 50, 100]。仅SSL-VPN 需要选这个参数。
      */
    MaxConnection?: number;
}
/**
 * DescribeVpcInstances请求参数结构体
 */
export interface DescribeVpcInstancesRequest {
    /**
      * 过滤条件，参数不支持同时指定RouteTableIds和Filters。
<li>vpc-id - String - （过滤条件）VPC实例ID，形如：vpc-f49l6u0z。</li>
<li>instance-id - String - （过滤条件）云主机实例ID。</li>
<li>instance-name - String - （过滤条件）云主机名称。</li>
      */
    Filters: Array<Filter>;
    /**
      * 偏移量。
      */
    Offset?: number;
    /**
      * 请求对象个数。
      */
    Limit?: number;
}
/**
 * DeleteVpcEndPointServiceWhiteList返回参数结构体
 */
export interface DeleteVpcEndPointServiceWhiteListResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateBandwidthPackage返回参数结构体
 */
export interface CreateBandwidthPackageResponse {
    /**
      * 带宽包唯一ID。
      */
    BandwidthPackageId: string;
    /**
      * 带宽包唯一ID列表(申请数量大于1时有效)。
      */
    BandwidthPackageIds: Array<string>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ResetVpnConnection请求参数结构体
 */
export interface ResetVpnConnectionRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * VPN通道实例ID。形如：vpnx-f49l6u0z。
      */
    VpnConnectionId: string;
}
/**
 * ReleaseAddresses返回参数结构体
 */
export interface ReleaseAddressesResponse {
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AuditCrossBorderCompliance返回参数结构体
 */
export interface AuditCrossBorderComplianceResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * InquiryPriceResetVpnGatewayInternetMaxBandwidth请求参数结构体
 */
export interface InquiryPriceResetVpnGatewayInternetMaxBandwidthRequest {
    /**
      * VPN网关实例ID。
      */
    VpnGatewayId: string;
    /**
      * 公网带宽设置。可选带宽规格：5, 10, 20, 50, 100；单位：Mbps。
      */
    InternetMaxBandwidthOut: number;
}
/**
 * ReplaceSecurityGroupPolicy返回参数结构体
 */
export interface ReplaceSecurityGroupPolicyResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * EnableGatewayFlowMonitor请求参数结构体
 */
export interface EnableGatewayFlowMonitorRequest {
    /**
      * 网关实例ID，目前我们支持的网关实例有，
专线网关实例ID，形如，`dcg-ltjahce6`；
Nat网关实例ID，形如，`nat-ltjahce6`；
VPN网关实例ID，形如，`vpn-ltjahce6`。
      */
    GatewayId: string;
}
/**
 * ModifyPrivateIpAddressesAttribute返回参数结构体
 */
export interface ModifyPrivateIpAddressesAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ReplaceRoutes返回参数结构体
 */
export interface ReplaceRoutesResponse {
    /**
      * 原路由策略信息。
      */
    OldRouteSet: Array<Route>;
    /**
      * 修改后的路由策略信息。
      */
    NewRouteSet: Array<Route>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyHaVipAttribute返回参数结构体
 */
export interface ModifyHaVipAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 用于描述云联网地域间限速带宽实例的信息。
 */
export interface CcnBandwidthInfo {
    /**
      * 带宽所属的云联网ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CcnId: string;
    /**
      * 实例的创建时间。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CreatedTime: string;
    /**
      * 实例的过期时间
注意：此字段可能返回 null，表示取不到有效值。
      */
    ExpiredTime: string;
    /**
      * 带宽实例的唯一ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    RegionFlowControlId: string;
    /**
      * 带宽是否自动续费的标记。
注意：此字段可能返回 null，表示取不到有效值。
      */
    RenewFlag: string;
    /**
      * 描述带宽的地域和限速上限信息。在地域间限速的情况下才会返回参数，出口限速模式不返回。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CcnRegionBandwidthLimit: CcnRegionBandwidthLimit;
    /**
      * 云市场实例ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    MarketId: string;
}
/**
 * DescribeCrossBorderCcnRegionBandwidthLimits返回参数结构体
 */
export interface DescribeCrossBorderCcnRegionBandwidthLimitsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteSecurityGroup返回参数结构体
 */
export interface DeleteSecurityGroupResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateNetworkInterface返回参数结构体
 */
export interface CreateNetworkInterfaceResponse {
    /**
      * 弹性网卡实例。
      */
    NetworkInterface: NetworkInterface;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeAddressQuota请求参数结构体
 */
export declare type DescribeAddressQuotaRequest = null;
/**
 * LockCcns返回参数结构体
 */
export interface LockCcnsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * RemoveBandwidthPackageResources返回参数结构体
 */
export interface RemoveBandwidthPackageResourcesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssignIpv6Addresses返回参数结构体
 */
export interface AssignIpv6AddressesResponse {
    /**
      * 分配给弹性网卡的`IPv6`地址列表。
      */
    Ipv6AddressSet: Array<Ipv6Address>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateRoutes返回参数结构体
 */
export interface CreateRoutesResponse {
    /**
      * 新增的实例个数。
      */
    TotalCount: number;
    /**
      * 路由表对象。
      */
    RouteTableSet: Array<RouteTable>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroups返回参数结构体
 */
export interface DescribeSecurityGroupsResponse {
    /**
      * 安全组对象。
注意：此字段可能返回 null，表示取不到有效值。
      */
    SecurityGroupSet: Array<SecurityGroup>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateVpcEndPointServiceWhiteList请求参数结构体
 */
export interface CreateVpcEndPointServiceWhiteListRequest {
    /**
      * UIN。
      */
    UserUin: string;
    /**
      * 终端节点服务ID。
      */
    EndPointServiceId: string;
    /**
      * 白名单描述。
      */
    Description?: string;
}
/**
 * DeleteNatGatewaySourceIpTranslationNatRule请求参数结构体
 */
export interface DeleteNatGatewaySourceIpTranslationNatRuleRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * NAT网关的SNAT ID列表，形如：`snat-df43254`。
      */
    NatGatewaySnatIds: Array<string>;
}
/**
 * ModifyVpnGatewayCcnRoutes请求参数结构体
 */
export interface ModifyVpnGatewayCcnRoutesRequest {
    /**
      * VPN网关实例ID
      */
    VpnGatewayId: string;
    /**
      * 云联网路由（IDC网段）列表
      */
    Routes: Array<VpngwCcnRoutes>;
}
/**
 * DescribeGatewayFlowQos请求参数结构体
 */
export interface DescribeGatewayFlowQosRequest {
    /**
      * 网关实例ID，目前我们支持的网关实例类型有，
专线网关实例ID，形如，`dcg-ltjahce6`；
Nat网关实例ID，形如，`nat-ltjahce6`；
VPN网关实例ID，形如，`vpn-ltjahce6`。
      */
    GatewayId: string;
    /**
      * 限流的云服务器内网IP。
      */
    IpAddresses?: Array<string>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: number;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: number;
}
/**
 * ReplaceDirectConnectGatewayCcnRoutes返回参数结构体
 */
export interface ReplaceDirectConnectGatewayCcnRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifySecurityGroupPolicies返回参数结构体
 */
export interface ModifySecurityGroupPoliciesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyNatGatewayDestinationIpPortTranslationNatRule请求参数结构体
 */
export interface ModifyNatGatewayDestinationIpPortTranslationNatRuleRequest {
    /**
      * NAT网关的ID，形如：`nat-df45454`。
      */
    NatGatewayId: string;
    /**
      * 源NAT网关的端口转换规则。
      */
    SourceNatRule: DestinationIpPortTranslationNatRule;
    /**
      * 目的NAT网关的端口转换规则。
      */
    DestinationNatRule: DestinationIpPortTranslationNatRule;
}
/**
 * 协议端口模板
 */
export interface ServiceTemplateSpecification {
    /**
      * 协议端口ID，例如：ppm-f5n1f8da。
      */
    ServiceId: string;
    /**
      * 协议端口组ID，例如：ppmg-f5n1f8da。
      */
    ServiceGroupId: string;
}
/**
 * DetachNetworkInterface请求参数结构体
 */
export interface DetachNetworkInterfaceRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
    /**
      * CVM实例ID。形如：ins-r8hr2upy。
      */
    InstanceId: string;
}
/**
 * IPV6转换规则
 */
export interface Ip6Rule {
    /**
      * IPV6转换规则唯一ID，形如rule6-xxxxxxxx
      */
    Ip6RuleId: string;
    /**
      * IPV6转换规则名称
      */
    Ip6RuleName: string;
    /**
      * IPV6地址
      */
    Vip6: string;
    /**
      * IPV6端口号
      */
    Vport6: number;
    /**
      * 协议类型，支持TCP/UDP
      */
    Protocol: string;
    /**
      * IPV4地址
      */
    Vip: string;
    /**
      * IPV4端口号
      */
    Vport: number;
    /**
      * 转换规则状态，限于CREATING,RUNNING,DELETING,MODIFYING
      */
    RuleStatus: string;
    /**
      * 转换规则创建时间
      */
    CreatedTime: string;
}
/**
 * AttachClassicLinkVpc返回参数结构体
 */
export interface AttachClassicLinkVpcResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DownloadVpnGatewaySslClientCert请求参数结构体
 */
export interface DownloadVpnGatewaySslClientCertRequest {
    /**
      * SSL-VPN-CLIENT 实例ID。
      */
    SslVpnClientId: string;
}
/**
 * CreateAddressTemplate请求参数结构体
 */
export interface CreateAddressTemplateRequest {
    /**
      * IP地址模板名称。
      */
    AddressTemplateName: string;
    /**
      * 地址信息，支持 IP、CIDR、IP 范围。Addresses与AddressesExtra必填其一。
      */
    Addresses?: Array<string>;
    /**
      * 地址信息，支持携带备注，支持 IP、CIDR、IP 范围。Addresses与AddressesExtra必填其一。
      */
    AddressesExtra?: Array<AddressInfo>;
}
/**
 * DescribeRouteConflicts请求参数结构体
 */
export interface DescribeRouteConflictsRequest {
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId: string;
    /**
      * 要检查的与之冲突的目的端列表
      */
    DestinationCidrBlocks: Array<string>;
}
/**
 * 查询nat路由的返回路由对象
 */
export interface NatDirectConnectGatewayRoute {
    /**
      * 子网的 `IPv4` `CIDR`
      */
    DestinationCidrBlock: string;
    /**
      * 下一跳网关的类型，目前此接口支持的类型有：
DIRECTCONNECT：专线网关
      */
    GatewayType: string;
    /**
      * 下一跳网关ID
      */
    GatewayId: string;
    /**
      * 路由的创建时间
      */
    CreateTime: string;
    /**
      * 路由的更新时间
      */
    UpdateTime: string;
}
/**
 * 子网对象
 */
export interface Subnet {
    /**
      * `VPC`实例`ID`。
      */
    VpcId: string;
    /**
      * 子网实例`ID`，例如：subnet-bthucmmy。
      */
    SubnetId: string;
    /**
      * 子网名称。
      */
    SubnetName: string;
    /**
      * 子网的 `IPv4` `CIDR`。
      */
    CidrBlock: string;
    /**
      * 是否默认子网。
      */
    IsDefault: boolean;
    /**
      * 是否开启广播。
      */
    EnableBroadcast: boolean;
    /**
      * 可用区。
      */
    Zone: string;
    /**
      * 路由表实例ID，例如：rtb-l2h8d7c2。
      */
    RouteTableId: string;
    /**
      * 创建时间。
      */
    CreatedTime?: string;
    /**
      * 可用`IPv4`数。
      */
    AvailableIpAddressCount: number;
    /**
      * 子网的 `IPv6` `CIDR`。
      */
    Ipv6CidrBlock: string;
    /**
      * 关联`ACL`ID
      */
    NetworkAclId: string;
    /**
      * 是否为 `SNAT` 地址池子网。
      */
    IsRemoteVpcSnat: boolean;
    /**
      * 子网`IPv4`总数。
      */
    TotalIpAddressCount: number;
    /**
      * 标签键值对。
      */
    TagSet: Array<Tag>;
    /**
      * CDC实例ID。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CdcId: string;
    /**
      * 是否是CDC所属子网。0:否 1:是
注意：此字段可能返回 null，表示取不到有效值。
      */
    IsCdcSubnet: number;
}
/**
 * AttachNetworkInterface请求参数结构体
 */
export interface AttachNetworkInterfaceRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
    /**
      * CVM实例ID。形如：ins-r8hr2upy。
      */
    InstanceId: string;
    /**
      * 网卡的挂载类型：0 标准型，1扩展型，默认值0。
      */
    AttachType?: number;
}
/**
 * DescribeCcnRoutes返回参数结构体
 */
export interface DescribeCcnRoutesResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount: number;
    /**
      * CCN路由策略对象。
      */
    RouteSet: Array<CcnRoute>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AllocateIp6AddressesBandwidth请求参数结构体
 */
export interface AllocateIp6AddressesBandwidthRequest {
    /**
      * 需要开通公网访问能力的IPV6地址
      */
    Ip6Addresses: Array<string>;
    /**
      * 带宽，单位Mbps。默认是1Mbps
      */
    InternetMaxBandwidthOut?: number;
    /**
      * 网络计费模式。IPV6当前对标准账户类型支持"TRAFFIC_POSTPAID_BY_HOUR"，对传统账户类型支持"BANDWIDTH_PACKAGE"。默认网络计费模式是"TRAFFIC_POSTPAID_BY_HOUR"。
      */
    InternetChargeType?: string;
    /**
      * 带宽包id，上移账号，申请带宽包计费模式的ipv6地址需要传入.
      */
    BandwidthPackageId?: string;
}
/**
 * 安全组对象
 */
export interface SecurityGroup {
    /**
      * 安全组实例ID，例如：sg-ohuuioma。
      */
    SecurityGroupId: string;
    /**
      * 安全组名称，可任意命名，但不得超过60个字符。
      */
    SecurityGroupName: string;
    /**
      * 安全组备注，最多100个字符。
      */
    SecurityGroupDesc: string;
    /**
      * 项目id，默认0。可在qcloud控制台项目管理页面查询到。
      */
    ProjectId?: string;
    /**
      * 是否是默认安全组，默认安全组不支持删除。
      */
    IsDefault?: boolean;
    /**
      * 安全组创建时间。
      */
    CreatedTime?: string;
    /**
      * 标签键值对。
      */
    TagSet?: Array<Tag>;
    /**
      * 安全组更新时间。
注意：此字段可能返回 null，表示取不到有效值。
      */
    UpdateTime?: string;
}
/**
 * UnlockCcns返回参数结构体
 */
export interface UnlockCcnsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisableGatewayFlowMonitor返回参数结构体
 */
export interface DisableGatewayFlowMonitorResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisassociateAddress返回参数结构体
 */
export interface DisassociateAddressResponse {
    /**
      * 异步任务TaskId。可以使用[DescribeTaskResult](https://cloud.tencent.com/document/api/215/36271)接口查询任务状态。
      */
    TaskId: string;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * IDC子网信息
 */
export interface DirectConnectSubnet {
    /**
      * 专线网关ID
      */
    DirectConnectGatewayId: string;
    /**
      * IDC子网网段
      */
    CidrBlock: string;
}
/**
 * DescribeVpnGatewayRoutes请求参数结构体
 */
export interface DescribeVpnGatewayRoutesRequest {
    /**
      * VPN网关的ID
      */
    VpnGatewayId: string;
    /**
      * 过滤条件,  条件包括(DestinationCidr, InstanceId,InstanceType)
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量, 默认0
      */
    Offset?: number;
    /**
      * 单页个数, 默认20, 最大值100
      */
    Limit?: number;
}
/**
 * GetCcnRegionBandwidthLimits返回参数结构体
 */
export interface GetCcnRegionBandwidthLimitsResponse {
    /**
      * 云联网（CCN）各地域出带宽带宽详情。
注意：此字段可能返回 null，表示取不到有效值。
      */
    CcnBandwidthSet?: Array<CcnBandwidthInfo>;
    /**
      * 符合条件的对象数。
注意：此字段可能返回 null，表示取不到有效值。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteRoutes请求参数结构体
 */
export interface DeleteRoutesRequest {
    /**
      * 路由表实例ID。
      */
    RouteTableId: string;
    /**
      * 路由策略对象，删除路由策略时，仅需使用Route的RouteId字段。
      */
    Routes: Array<Route>;
}
/**
 * AssociateAddress请求参数结构体
 */
export interface AssociateAddressRequest {
    /**
      * 标识 EIP 的唯一 ID。EIP 唯一 ID 形如：`eip-11112222`。
      */
    AddressId: string;
    /**
      * 要绑定的实例 ID。实例 ID 形如：`ins-11112222`。可通过登录[控制台](https://console.cloud.tencent.com/cvm)查询，也可通过 [DescribeInstances](https://cloud.tencent.com/document/api/213/15728) 接口返回值中的`InstanceId`获取。
      */
    InstanceId?: string;
    /**
      * 要绑定的弹性网卡 ID。 弹性网卡 ID 形如：`eni-11112222`。`NetworkInterfaceId` 与 `InstanceId` 不可同时指定。弹性网卡 ID 可通过登录[控制台](https://console.cloud.tencent.com/vpc/eni)查询，也可通过[DescribeNetworkInterfaces](https://cloud.tencent.com/document/api/215/15817)接口返回值中的`networkInterfaceId`获取。
      */
    NetworkInterfaceId?: string;
    /**
      * 要绑定的内网 IP。如果指定了 `NetworkInterfaceId` 则也必须指定 `PrivateIpAddress` ，表示将 EIP 绑定到指定弹性网卡的指定内网 IP 上。同时要确保指定的 `PrivateIpAddress` 是指定的 `NetworkInterfaceId` 上的一个内网 IP。指定弹性网卡的内网 IP 可通过登录[控制台](https://console.cloud.tencent.com/vpc/eni)查询，也可通过[DescribeNetworkInterfaces](https://cloud.tencent.com/document/api/215/15817)接口返回值中的`privateIpAddress`获取。
      */
    PrivateIpAddress?: string;
    /**
      * 指定绑定时是否设置直通。弹性公网 IP 直通请参见 [EIP 直通](https://cloud.tencent.com/document/product/1199/41709)。取值：True、False，默认值为 False。当绑定 CVM 实例、EKS 弹性集群时，可设定此参数为 True。此参数目前处于内测中，如需使用，请提交 [工单申请](https://console.cloud.tencent.com/workorder/category?level1_id=6&level2_id=163&source=0&data_title=%E8%B4%9F%E8%BD%BD%E5%9D%87%E8%A1%A1%20CLB&level3_id=1071&queue=96&scene_code=34639&step=2)。
      */
    EipDirectConnection?: boolean;
}
/**
 * 云联网（CCN）地域出带宽上限
 */
export interface CcnRegionBandwidthLimit {
    /**
      * 地域，例如：ap-guangzhou
      */
    Region: string;
    /**
      * 出带宽上限，单位：Mbps
      */
    BandwidthLimit: number;
    /**
      * 是否黑石地域，默认`false`。
      */
    IsBm?: boolean;
    /**
      * 目的地域，例如：ap-shanghai
注意：此字段可能返回 null，表示取不到有效值。
      */
    DstRegion?: string;
    /**
      * 目的地域是否为黑石地域，默认`false`。
      */
    DstIsBm?: boolean;
}
/**
 * UnlockCcnBandwidths返回参数结构体
 */
export interface UnlockCcnBandwidthsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateDefaultSecurityGroup返回参数结构体
 */
export interface CreateDefaultSecurityGroupResponse {
    /**
      * 安全组对象。
      */
    SecurityGroup?: SecurityGroup;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 私有网络和基础网络互通设备
 */
export interface ClassicLinkInstance {
    /**
      * VPC实例ID
      */
    VpcId: string;
    /**
      * 云服务器实例唯一ID
      */
    InstanceId: string;
}
/**
 * DeleteLocalGateway返回参数结构体
 */
export interface DeleteLocalGatewayResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 弹性网卡绑定关系
 */
export interface NetworkInterfaceAttachment {
    /**
      * 云主机实例ID。
      */
    InstanceId: string;
    /**
      * 网卡在云主机实例内的序号。
      */
    DeviceIndex: number;
    /**
      * 云主机所有者账户信息。
      */
    InstanceAccountId: string;
    /**
      * 绑定时间。
      */
    AttachTime: string;
}
/**
 * ModifyNetworkInterfaceAttribute请求参数结构体
 */
export interface ModifyNetworkInterfaceAttributeRequest {
    /**
      * 弹性网卡实例ID，例如：eni-pxir56ns。
      */
    NetworkInterfaceId: string;
    /**
      * 弹性网卡名称，最大长度不能超过60个字节。
      */
    NetworkInterfaceName?: string;
    /**
      * 弹性网卡描述，可任意命名，但不得超过60个字符。
      */
    NetworkInterfaceDescription?: string;
    /**
      * 指定绑定的安全组，例如:['sg-1dd51d']。
      */
    SecurityGroupIds?: Array<string>;
}
/**
 * RemoveIp6Rules返回参数结构体
 */
export interface RemoveIp6RulesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyHaVipAttribute请求参数结构体
 */
export interface ModifyHaVipAttributeRequest {
    /**
      * `HAVIP`唯一`ID`，形如：`havip-9o233uri`。
      */
    HaVipId: string;
    /**
      * `HAVIP`名称，可任意命名，但不得超过60个字符。
      */
    HaVipName: string;
}
/**
 * ModifyAddressTemplateGroupAttribute返回参数结构体
 */
export interface ModifyAddressTemplateGroupAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 私有网络配额
 */
export interface VpcLimit {
    /**
      * 私有网络配额描述
      */
    LimitType: string;
    /**
      * 私有网络配额值
      */
    LimitValue: number;
}
/**
 * DetachClassicLinkVpc返回参数结构体
 */
export interface DetachClassicLinkVpcResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * UnassignPrivateIpAddresses请求参数结构体
 */
export interface UnassignPrivateIpAddressesRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
    /**
      * 指定的内网IP信息，单次最多指定10个。
      */
    PrivateIpAddresses: Array<PrivateIpAddressSpecification>;
    /**
      * 网卡绑定的子机实例ID，该参数仅用于指定网卡退还IP并解绑子机的场景，如果不涉及解绑子机，请勿填写。
      */
    InstanceId?: string;
}
/**
 * DeleteVpnGatewayRoutes请求参数结构体
 */
export interface DeleteVpnGatewayRoutesRequest {
    /**
      * VPN网关实例ID
      */
    VpnGatewayId: string;
    /**
      * 路由ID信息列表
      */
    RouteIds: Array<string>;
}
/**
 * DescribeProductQuota请求参数结构体
 */
export interface DescribeProductQuotaRequest {
    /**
      * 查询的网络产品名称，可查询的产品有：vpc、ccn、vpn、dc、dfw、clb、eip。
      */
    Product: string;
}
/**
 * ModifyNetDetect返回参数结构体
 */
export interface ModifyNetDetectResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateHaVip请求参数结构体
 */
export interface CreateHaVipRequest {
    /**
      * `HAVIP`所在私有网络`ID`。
      */
    VpcId: string;
    /**
      * `HAVIP`所在子网`ID`。
      */
    SubnetId: string;
    /**
      * `HAVIP`名称。
      */
    HaVipName: string;
    /**
      * 指定虚拟IP地址，必须在`VPC`网段内且未被占用。不指定则自动分配。
      */
    Vip?: string;
}
/**
 * IPv6子网段对象。
 */
export interface Ipv6SubnetCidrBlock {
    /**
      * 子网实例`ID`。形如：`subnet-pxir56ns`。
      */
    SubnetId: string;
    /**
      * `IPv6`子网段。形如：`3402:4e00:20:1001::/64`
      */
    Ipv6CidrBlock?: string;
}
/**
 * EnableFlowLogs返回参数结构体
 */
export interface EnableFlowLogsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * LockCcnBandwidths返回参数结构体
 */
export interface LockCcnBandwidthsResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeAddressQuota返回参数结构体
 */
export interface DescribeAddressQuotaResponse {
    /**
      * 账户 EIP 配额信息。
      */
    QuotaSet?: Array<Quota>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateCustomerGateway请求参数结构体
 */
export interface CreateCustomerGatewayRequest {
    /**
      * 对端网关名称，可任意命名，但不得超过60个字符。
      */
    CustomerGatewayName: string;
    /**
      * 对端网关公网IP。
      */
    IpAddress: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
}
/**
 * DeleteSecurityGroup请求参数结构体
 */
export interface DeleteSecurityGroupRequest {
    /**
      * 安全组实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupId: string;
}
/**
 * DescribeDhcpIps返回参数结构体
 */
export interface DescribeDhcpIpsResponse {
    /**
      * 实例详细信息列表。
      */
    DhcpIpSet: Array<DhcpIp>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateRouteTable返回参数结构体
 */
export interface CreateRouteTableResponse {
    /**
      * 路由表对象。
      */
    RouteTable?: RouteTable;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCrossBorderCcnRegionBandwidthLimits请求参数结构体
 */
export declare type DescribeCrossBorderCcnRegionBandwidthLimitsRequest = null;
/**
 * GetCcnRegionBandwidthLimits请求参数结构体
 */
export interface GetCcnRegionBandwidthLimitsRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
    /**
      * 过滤条件。
<li>sregion - String - （过滤条件）源地域，形如：ap-guangzhou。</li>
<li>dregion - String - （过滤条件）目的地域，形如：ap-shanghai-bm</li>
      */
    Filters?: Array<Filter>;
    /**
      * 排序条件，目前支持带宽（BandwidthLimit）和过期时间（ExpireTime）
      */
    SortedBy?: string;
    /**
      * 偏移量
      */
    Offset?: number;
    /**
      * 返回数量
      */
    Limit?: number;
    /**
      * 排序方式，'ASC':升序,'DESC':降序。
      */
    OrderBy?: string;
}
/**
 * DescribeDirectConnectGatewayCcnRoutes返回参数结构体
 */
export interface DescribeDirectConnectGatewayCcnRoutesResponse {
    /**
      * 符合条件的对象数。
      */
    TotalCount: number;
    /**
      * 云联网路由（IDC网段）列表。
      */
    RouteSet: Array<DirectConnectGatewayCcnRoute>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifyPrivateIpAddressesAttribute请求参数结构体
 */
export interface ModifyPrivateIpAddressesAttributeRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
    /**
      * 指定的内网IP信息。
      */
    PrivateIpAddresses: Array<PrivateIpAddressSpecification>;
}
/**
 * ResetNatGatewayConnection返回参数结构体
 */
export interface ResetNatGatewayConnectionResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssociateNetworkInterfaceSecurityGroups请求参数结构体
 */
export interface AssociateNetworkInterfaceSecurityGroupsRequest {
    /**
      * 弹性网卡实例ID。形如：eni-pxir56ns。每次请求的实例的上限为100。
      */
    NetworkInterfaceIds: Array<string>;
    /**
      * 安全组实例ID，例如：sg-33ocnj9n，可通过DescribeSecurityGroups获取。每次请求的实例的上限为100。
      */
    SecurityGroupIds: Array<string>;
}
/**
 * DeleteVpnGatewayRoutes返回参数结构体
 */
export interface DeleteVpnGatewayRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * CreateSecurityGroup请求参数结构体
 */
export interface CreateSecurityGroupRequest {
    /**
      * 安全组名称，可任意命名，但不得超过60个字符。
      */
    GroupName: string;
    /**
      * 安全组备注，最多100个字符。
      */
    GroupDescription: string;
    /**
      * 项目ID，默认0。可在qcloud控制台项目管理页面查询到。
      */
    ProjectId?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]
      */
    Tags?: Array<Tag>;
}
/**
 * ModifyCcnAttribute返回参数结构体
 */
export interface ModifyCcnAttributeResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeSecurityGroupLimits请求参数结构体
 */
export declare type DescribeSecurityGroupLimitsRequest = null;
/**
 * DescribeClassicLinkInstances请求参数结构体
 */
export interface DescribeClassicLinkInstancesRequest {
    /**
      * 过滤条件。
<li>vpc-id - String - （过滤条件）VPC实例ID。</li>
<li>vm-ip - String - （过滤条件）基础网络云服务器IP。</li>
      */
    Filters?: Array<FilterObject>;
    /**
      * 偏移量
      */
    Offset?: string;
    /**
      * 返回数量
      */
    Limit?: string;
}
/**
 * ReleaseIp6AddressesBandwidth请求参数结构体
 */
export interface ReleaseIp6AddressesBandwidthRequest {
    /**
      * IPV6地址。Ip6Addresses和Ip6AddressIds必须且只能传一个
      */
    Ip6Addresses?: Array<string>;
    /**
      * IPV6地址对应的唯一ID，形如eip-xxxxxxxx。Ip6Addresses和Ip6AddressIds必须且只能传一个。
      */
    Ip6AddressIds?: Array<string>;
}
/**
 * CreateServiceTemplate返回参数结构体
 */
export interface CreateServiceTemplateResponse {
    /**
      * 协议端口模板对象。
      */
    ServiceTemplate: ServiceTemplate;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNetworkInterface返回参数结构体
 */
export interface DeleteNetworkInterfaceResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DisableCcnRoutes返回参数结构体
 */
export interface DisableCcnRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeCcnRegionBandwidthLimits请求参数结构体
 */
export interface DescribeCcnRegionBandwidthLimitsRequest {
    /**
      * CCN实例ID。形如：ccn-f49l6u0z。
      */
    CcnId: string;
}
/**
 * InquiryPriceCreateVpnGateway请求参数结构体
 */
export interface InquiryPriceCreateVpnGatewayRequest {
    /**
      * 公网带宽设置。可选带宽规格：5, 10, 20, 50, 100；单位：Mbps。
      */
    InternetMaxBandwidthOut: number;
    /**
      * VPN网关计费模式，PREPAID：表示预付费，即包年包月，POSTPAID_BY_HOUR：表示后付费，即按量计费。默认：POSTPAID_BY_HOUR，如果指定预付费模式，参数InstanceChargePrepaid必填。
      */
    InstanceChargeType?: string;
    /**
      * 预付费模式，即包年包月相关参数设置。通过该参数可以指定包年包月实例的购买时长、是否设置自动续费等属性。若指定实例的付费模式为预付费则该参数必传。
      */
    InstanceChargePrepaid?: InstanceChargePrepaid;
    /**
      * SSL VPN连接数设置，可选规格：5, 10, 20, 50, 100；单位：个。
      */
    MaxConnection?: number;
    /**
      * 查询的VPN类型，支持IPSEC和SSL两种类型，为SSL类型时，MaxConnection参数必传。
      */
    Type?: string;
}
/**
 * CreateAssistantCidr返回参数结构体
 */
export interface CreateAssistantCidrResponse {
    /**
      * 辅助CIDR数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    AssistantCidrSet: Array<AssistantCidr>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 对端网关厂商信息对象。
 */
export interface CustomerGatewayVendor {
    /**
      * 平台。
      */
    Platform: string;
    /**
      * 软件版本。
      */
    SoftwareVersion: string;
    /**
      * 供应商名称。
      */
    VendorName: string;
}
/**
 * DescribeAddressTemplates请求参数结构体
 */
export interface DescribeAddressTemplatesRequest {
    /**
      * 过滤条件。
<li>address-template-name - IP地址模板名称。</li>
<li>address-template-id - IP地址模板实例ID，例如：ipm-mdunqeb6。</li>
<li>address-ip - IP地址。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * 冲突资源信息。
 */
export interface ConflictSource {
    /**
      * 冲突资源ID
      */
    ConflictSourceId: string;
    /**
      * 冲突资源
      */
    SourceItem: string;
    /**
      * 冲突资源条目信息
      */
    ConflictItemSet: Array<ConflictItem>;
}
/**
 * CreateDhcpIp请求参数结构体
 */
export interface CreateDhcpIpRequest {
    /**
      * 私有网络`ID`。
      */
    VpcId: string;
    /**
      * 子网`ID`。
      */
    SubnetId: string;
    /**
      * `DhcpIp`名称。
      */
    DhcpIpName: string;
    /**
      * 新申请的内网IP地址个数。总数不能超过64个。
      */
    SecondaryPrivateIpAddressCount?: number;
}
/**
 * DescribeVpnConnections返回参数结构体
 */
export interface DescribeVpnConnectionsResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * VPN通道实例。
      */
    VpnConnectionSet?: Array<VpnConnection>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteCustomerGateway请求参数结构体
 */
export interface DeleteCustomerGatewayRequest {
    /**
      * 对端网关ID，例如：cgw-2wqq41m9，可通过DescribeCustomerGateways接口查询对端网关。
      */
    CustomerGatewayId: string;
}
/**
 * DescribeAddressTemplates返回参数结构体
 */
export interface DescribeAddressTemplatesResponse {
    /**
      * 符合条件的实例数量。
      */
    TotalCount: number;
    /**
      * IP地址模板。
      */
    AddressTemplateSet: Array<AddressTemplate>;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 描述配额信息
 */
export interface Quota {
    /**
      * 配额名称，取值范围：<br><li>`TOTAL_EIP_QUOTA`：用户当前地域下EIP的配额数；<br><li>`DAILY_EIP_APPLY`：用户当前地域下今日申购次数；<br><li>`DAILY_PUBLIC_IP_ASSIGN`：用户当前地域下，重新分配公网 IP次数。
      */
    QuotaId?: string;
    /**
      * 当前数量
      */
    QuotaCurrent?: number;
    /**
      * 配额数量
      */
    QuotaLimit?: number;
}
/**
 * WithdrawNotifyRoutes返回参数结构体
 */
export interface WithdrawNotifyRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeNetworkInterfaces返回参数结构体
 */
export interface DescribeNetworkInterfacesResponse {
    /**
      * 实例详细信息列表。
      */
    NetworkInterfaceSet?: Array<NetworkInterface>;
    /**
      * 符合条件的实例数量。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DeleteNetworkAcl返回参数结构体
 */
export interface DeleteNetworkAclResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AssignPrivateIpAddresses请求参数结构体
 */
export interface AssignPrivateIpAddressesRequest {
    /**
      * 弹性网卡实例ID，例如：eni-m6dyj72l。
      */
    NetworkInterfaceId: string;
    /**
      * 指定的内网IP信息，单次最多指定10个。与SecondaryPrivateIpAddressCount至少提供一个。
      */
    PrivateIpAddresses?: Array<PrivateIpAddressSpecification>;
    /**
      * 新申请的内网IP地址个数，与PrivateIpAddresses至少提供一个。内网IP地址个数总和不能超过配额数，详见<a href="/document/product/576/18527">弹性网卡使用限制</a>。
      */
    SecondaryPrivateIpAddressCount?: number;
}
/**
 * DescribeServiceTemplateGroups请求参数结构体
 */
export interface DescribeServiceTemplateGroupsRequest {
    /**
      * 过滤条件。
<li>service-template-group-name - String - （过滤条件）协议端口模板集合名称。</li>
<li>service-template-group-id - String - （过滤条件）协议端口模板集合实例ID，例如：ppmg-e6dy460g。</li>
      */
    Filters?: Array<Filter>;
    /**
      * 偏移量，默认为0。
      */
    Offset?: string;
    /**
      * 返回数量，默认为20，最大值为100。
      */
    Limit?: string;
}
/**
 * CreateSecurityGroupWithPolicies请求参数结构体
 */
export interface CreateSecurityGroupWithPoliciesRequest {
    /**
      * 安全组名称，可任意命名，但不得超过60个字符。
      */
    GroupName: string;
    /**
      * 安全组备注，最多100个字符。
      */
    GroupDescription: string;
    /**
      * 项目ID，默认0。可在qcloud控制台项目管理页面查询到。
      */
    ProjectId?: string;
    /**
      * 安全组规则集合。
      */
    SecurityGroupPolicySet?: SecurityGroupPolicySet;
}
/**
 * CreateVpc请求参数结构体
 */
export interface CreateVpcRequest {
    /**
      * vpc名称，最大长度不能超过60个字节。
      */
    VpcName: string;
    /**
      * vpc的cidr，仅能在10.0.0.0/16，172.16.0.0/16，192.168.0.0/16这三个内网网段内。
      */
    CidrBlock: string;
    /**
      * 是否开启组播。true: 开启, false: 不开启。
      */
    EnableMulticast?: string;
    /**
      * DNS地址，最多支持4个。
      */
    DnsServers?: Array<string>;
    /**
      * DHCP使用的域名。
      */
    DomainName?: string;
    /**
      * 指定绑定的标签列表，例如：[{"Key": "city", "Value": "shanghai"}]。
      */
    Tags?: Array<Tag>;
}
/**
 * DisableFlowLogs请求参数结构体
 */
export interface DisableFlowLogsRequest {
    /**
      * 流日志Id。
      */
    FlowLogIds: Array<string>;
}
/**
 * DeleteServiceTemplate请求参数结构体
 */
export interface DeleteServiceTemplateRequest {
    /**
      * 协议端口模板实例ID，例如：ppm-e6dy460g。
      */
    ServiceTemplateId: string;
}
/**
 * DescribeSecurityGroupAssociationStatistics请求参数结构体
 */
export interface DescribeSecurityGroupAssociationStatisticsRequest {
    /**
      * 安全实例ID，例如sg-33ocnj9n，可通过DescribeSecurityGroups获取。
      */
    SecurityGroupIds: Array<string>;
}
/**
 * NotifyRoutes返回参数结构体
 */
export interface NotifyRoutesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 路由策略对象
 */
export interface Route {
    /**
      * 目的网段，取值不能在私有网络网段内，例如：112.20.51.0/24。
      */
    DestinationCidrBlock: string;
    /**
      * 下一跳类型，目前我们支持的类型有：
CVM：公网网关类型的云服务器；
VPN：VPN网关；
DIRECTCONNECT：专线网关；
PEERCONNECTION：对等连接；
HAVIP：高可用虚拟IP；
NAT：NAT网关;
NORMAL_CVM：普通云服务器；
EIP：云服务器的公网IP；
LOCAL_GATEWAY：本地网关。
      */
    GatewayType: string;
    /**
      * 下一跳地址，这里只需要指定不同下一跳类型的网关ID，系统会自动匹配到下一跳地址。
特别注意：当 GatewayType 为 EIP 时，GatewayId 固定值 '0'
      */
    GatewayId: string;
    /**
      * 路由策略ID。IPv4路由策略ID是有意义的值，IPv6路由策略是无意义的值0。后续建议完全使用字符串唯一ID `RouteItemId`操作路由策略。
该字段在删除时必填，其他字段无需填写。
      */
    RouteId?: number;
    /**
      * 路由策略描述。
      */
    RouteDescription?: string;
    /**
      * 是否启用
      */
    Enabled?: boolean;
    /**
      * 路由类型，目前我们支持的类型有：
USER：用户路由；
NETD：网络探测路由，创建网络探测实例时，系统默认下发，不可编辑与删除；
CCN：云联网路由，系统默认下发，不可编辑与删除。
用户只能添加和操作 USER 类型的路由。
      */
    RouteType?: string;
    /**
      * 路由表实例ID，例如：rtb-azd4dt1c。
      */
    RouteTableId?: string;
    /**
      * 目的IPv6网段，取值不能在私有网络网段内，例如：2402:4e00:1000:810b::/64。
      */
    DestinationIpv6CidrBlock?: string;
    /**
      * 路由唯一策略ID。
      */
    RouteItemId?: string;
    /**
      * 路由策略是否发布到云联网。
注意：此字段可能返回 null，表示取不到有效值。
      */
    PublishedToVbc?: boolean;
    /**
      * 路由策略创建时间
      */
    CreatedTime?: string;
}
/**
 * EnableVpnGatewaySslClientCert返回参数结构体
 */
export interface EnableVpnGatewaySslClientCertResponse {
    /**
      * 异步任务实例ID。
      */
    TaskId: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * ModifySubnetAttribute请求参数结构体
 */
export interface ModifySubnetAttributeRequest {
    /**
      * 子网实例ID。形如：subnet-pxir56ns。
      */
    SubnetId: string;
    /**
      * 子网名称，最大长度不能超过60个字节。
      */
    SubnetName?: string;
    /**
      * 子网是否开启广播。
      */
    EnableBroadcast?: string;
}
/**
 * ModifyVpcEndPointServiceWhiteList返回参数结构体
 */
export interface ModifyVpcEndPointServiceWhiteListResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * DescribeBandwidthPackageQuota请求参数结构体
 */
export declare type DescribeBandwidthPackageQuotaRequest = null;
/**
 * DeleteVpc返回参数结构体
 */
export interface DeleteVpcResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * 预付费（包年包月）计费对象。
 */
export interface InstanceChargePrepaid {
    /**
      * 购买实例的时长，单位：月。取值范围：1, 2, 3, 4, 5, 6, 7, 8, 9, 12, 24, 36。
      */
    Period: number;
    /**
      * 自动续费标识。取值范围： NOTIFY_AND_AUTO_RENEW：通知过期且自动续费， NOTIFY_AND_MANUAL_RENEW：通知过期不自动续费。默认：NOTIFY_AND_MANUAL_RENEW
      */
    RenewFlag?: string;
}
/**
 * DescribeTemplateLimits请求参数结构体
 */
export declare type DescribeTemplateLimitsRequest = null;
/**
 * AddTemplateMember请求参数结构体
 */
export interface AddTemplateMemberRequest {
    /**
      * 参数模板实例ID，支持IP地址、协议端口、IP地址组、协议端口组四种参数模板的实例ID。
      */
    TemplateId: string;
    /**
      * 需要添加的参数模板成员信息，支持IP地址、协议端口、IP地址组、协议端口组四种类型，类型需要与TemplateId参数类型一致。
      */
    TemplateMember: Array<MemberInfo>;
}
/**
 * DescribeVpcEndPointServiceWhiteList返回参数结构体
 */
export interface DescribeVpcEndPointServiceWhiteListResponse {
    /**
      * 白名单对象数组。
      */
    VpcEndpointServiceUserSet: Array<VpcEndPointServiceUser>;
    /**
      * 符合条件的白名单个数。
      */
    TotalCount: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * AcceptAttachCcnInstances返回参数结构体
 */
export interface AcceptAttachCcnInstancesResponse {
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
/**
 * IP地址模板信息
 */
export interface AddressInfo {
    /**
      * ip地址。
      */
    Address: string;
    /**
      * 备注。
注意：此字段可能返回 null，表示取不到有效值。
      */
    Description?: string;
}
/**
 * AuditCrossBorderCompliance请求参数结构体
 */
export interface AuditCrossBorderComplianceRequest {
    /**
      * 服务商, 可选值：`UNICOM`。
      */
    ServiceProvider: string;
    /**
      * 表单唯一`ID`。
      */
    ComplianceId: number;
    /**
      * 通过：`APPROVED `，拒绝：`DENY`。
      */
    AuditBehavior: string;
}
/**
 * DescribeNetDetects返回参数结构体
 */
export interface DescribeNetDetectsResponse {
    /**
      * 符合条件的网络探测对象数组。
注意：此字段可能返回 null，表示取不到有效值。
      */
    NetDetectSet?: Array<NetDetect>;
    /**
      * 符合条件的网络探测对象数量。
注意：此字段可能返回 null，表示取不到有效值。
      */
    TotalCount?: number;
    /**
      * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
      */
    RequestId?: string;
}
